<?php
/*
 * Template Name: Job Template
 */
get_header();
landpagy_get_banner();

global $landpagy_opt;
$title              = landpagy_opt('job_mailchimp_title');
$subtitle           = landpagy_opt('job_mailchimp_subtitle');
$email_placeholder  = landpagy_opt('job_mailchimp_email_placeholder');
$submit_btn         = landpagy_opt('job_mailchimp_submit_btn');
$job_column         = is_active_sidebar( 'bjl_job_sidebar' ) ? '8' : '12';

global $wp_query;

$orderby = isset($_GET['orderby']) ? sanitize_text_field($_GET['orderby']) : '';
$order = isset($_GET['order']) ? sanitize_text_field($_GET['order']) : '';
$paged = ( get_query_var('page') ) ? get_query_var('page') : 1;

$args = array(
    'post_type' => 'bjl_post',
    'posts_per_page' => 2,
    'max_num_pages' => -1,
    'paged' => $paged,
    'orderby' => $orderby,
    'order' => $order
);

$jobs = new WP_Query($args);

//Sidebar Title
$args = array(
    'title' => __('Search for jobs', 'landpagy'),
);

$sidebar = is_active_sidebar( 'job_sidebar_widgets' ) ? '8' : '12';
?>

    <section class="pt-110 pb-130 job-post-wrapper">
        <div class="container blog-grid-container">
            <div class="row">

                <!-- left sidebar -->
                <?php get_sidebar( 'bjl_post', $args ); ?>

                <!-- Right bar -->
                <div class="col-lg-<?php echo esc_attr($job_column) ?>">
                    <div class="job-post-widget">
                        <div class="sidebar-header d-flex justify-content-between align-items-center mt-4 mt-lg-0">
                            <div class="sidebar-title">
                                <h4 class="wow fadeInRight"><?php Landpagy_Helper()->the_job_posts_count(); ?></h4>
                            </div>
                            <form action="" method="get">
                                <div class="sorting-select wow fadeInLeft me-1">
                                    <select id="sort-select" class="nice-select-common" name="orderby" onchange="document.location.href='?'+this.options[this.selectedIndex].value;">
                                        <option value="" selected><?php esc_html_e( 'SortBy Default', 'landpagy' ); ?></option>
                                        <option value="orderby=date&order=desc"><?php esc_html_e( 'Newest to Oldest', 'landpagy' ); ?></option>
                                        <option value="orderby=date&order=asc"><?php esc_html_e( 'Oldest to Newest', 'landpagy' ); ?></option>
                                        <option value="orderby=title&order=asc"><?php esc_html_e( 'Title Ascending ', 'landpagy' ); ?></option>
                                        <option value="orderby=title&order=desc"><?php esc_html_e( 'Title Descending', 'landpagy' ); ?></option>
                                    </select>
                                </div>
                            </form>
                        </div>

                        <?php
                        $data_wow_delay = 0.1;
                        while($jobs->have_posts()): $jobs->the_post();
                            ?>
                            <div class="single-job-post me-1 wow fadeInUp mt-25" data-wow-delay="<?php echo esc_attr($data_wow_delay) ?>s">
                                <div class="post-header">
                                    <div>
                                        <h6 class="job-title">
                                            <a href="<?php the_permalink(); ?>"><?php the_title() ?></a>
                                        </h6>
                                        <div class="d-flex flex-wrap">
                                            <div class="job-location me-lg-3 me-2">
                                                <i class="icon_pin_alt"></i>
                                                <?php Landpagy_Helper()->first_taxonomy('bjl_location'); ?>
                                            </div>
                                            <div class="job-catagory">
                                                <span><?php Landpagy_Helper()->first_taxonomy('bjl_category'); ?></span>
                                                | <?php Landpagy_Helper()->first_taxonomy('bjl_type'); ?>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="timestamp"><?php the_time(get_option('date_format')); ?></div>
                                </div>
                                <div class="post-content">
                                    <?php echo wpautop(wp_trim_words(get_the_content(), 26, '...' )) ?>
                                </div>
                            </div>
                            <?php
                            $data_wow_delay = $data_wow_delay + 0.1;
                        endwhile;
                        wp_reset_postdata();
                        ?>

                        <?php
                        if ( $jobs->max_num_pages > 0 ) {
                            ?>
                            <div class="text-center mt-70 wow fadeInUp load_more">
                                <a href="javascript:void(0)" class="btn load_more_btn" data-page="1">
                                    <?php esc_html_e( 'More jobs', 'landpagy' ); ?>
                                </a>
                            </div>
                            <?php
                        }
                        ?>
                    </div>

                    <div class="email-alert-widget bg_white mt-100 wow fadeInUp">
                        <?php
                        if ( $title ) { ?>
                            <h4><?php echo esc_html($title) ?></h4>
                            <?php
                        }
                        if ( $subtitle ) { ?>
                            <p><?php echo esc_html($subtitle) ?></p>
                            <?php
                        }
                        ?>
                        <form action="" method="post" class="form-group position-relative mt-4">
                            <input type="email" placeholder="<?php echo esc_attr($email_placeholder) ?>" />
                            <button type="submit" class="btn btn-red"><?php echo esc_html($submit_btn) ?></button>
                        </form>
                    </div>
                </div>


            </div>
        </div>
    </section>
    <?php
get_footer();
