<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package landpagy
 */
global $post;
$opt = get_option( 'landpagy_opt' );
$is_preloader = landpagy_opt('is_preloader');

//mega menu setting
$theme_locations = get_nav_menu_locations();
$menu_id = '';
if (array_key_exists('main_menu', $theme_locations) ) {
    $menu_id = $theme_locations['main_menu'];
}

$menu = wp_get_nav_menu_object( $menu_id );
$mega_menu_style = function_exists( 'get_field' ) ? get_field('mega_menu_stype', $menu) : '';
$megamenu_full = ($mega_menu_style == 'full') ? 'mega-menu-wrapper navbar navbar-expand-lg navbar-light' : 'navbar navbar-expand-lg navbar-light';
$megamenu_box = ($mega_menu_style == 'box') ? 'mega-menu-wrapper container-fluid' : 'container-fluid';
$megamenu_wide = ($mega_menu_style == 'wide') ? 'mega-menu-wrapper navbar-nav mr-auto menu ml-auto' : 'navbar-nav mr-auto menu ml-auto';

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
    <head>
        <meta charset="<?php bloginfo('charset' ); ?>">
        <!-- For IE -->
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <!-- For Resposive Device -->
        <meta name="viewport" content="width=device-width, initial-scale=1.0">

        <?php wp_head(); ?>
    </head>

    <body <?php body_class(); ?> data-scroll-animation="true">

    <!--------------Body Wrapper -------------->
    <div class="body_wrapper position-relative overflow-hidden">
        <?php
        if ( function_exists('wp_body_open') ) {
            wp_body_open();
        }

        /**
         * Pre-loader
         */
        $is_preloader = isset($opt['is_preloader']) ? $opt['is_preloader'] : '';
        $preloader_pages = !empty($opt['preloader_pages']) ? $opt['preloader_pages'] : 'all';

        if ( $is_preloader == '1' && $preloader_pages == 'all' ) {
            get_template_part( 'template-parts/header-elements/pre-loader' );
        }

        $preloader_page_ids = !empty($opt['preloader_page_ids']) ? explode(',', $opt['preloader_page_ids']) : '';
        if ( $is_preloader == '1' && $preloader_pages == 'specific_pages' && !empty($preloader_page_ids) ) {
            if ( is_object( $post ) && in_array($post->ID, $preloader_page_ids) ) {
                get_template_part('template-parts/header-elements/pre-loader');
            }
        }

        $header_id = '';

        if ( isset( $post->ID) || is_search() || is_404() ) {
            $header_id = Landpagy_Helper()->header_footer_template_id('landpagy-header', get_the_ID());
        }

        if ( $header_id != '' && class_exists( '\Elementor\Plugin' ) ) {
            echo \Elementor\Plugin::instance()->frontend->get_builder_content_for_display( $header_id );
        } else {
            ?>
            <header class="header-area">
                <nav class="navbar navbar-expand-lg menu_three sticky-nav">
                    <div class="container-fluid">

                        <?php Landpagy_helper()->logo(); ?>

                        <button class="navbar-toggler collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#navbarText" aria-controls="navbarText" aria-expanded="false"
                                aria-label="<?php esc_attr_e('Toggle navigation', 'landpagy' ); ?>">
                        <span class="menu_toggle">
                            <span class="hamburger">
                                <span></span>
                                <span></span>
                                <span></span>
                            </span>
                            <span class="hamburger-cross">
                                <span></span>
                                <span></span>
                            </span>
                        </span>
                        </button>
                        <div class="collapse navbar-collapse justify-content-end" id="navbarText">
                            <?php
                            if ( has_nav_menu( 'main_menu' ) ) {
                                wp_nav_menu( array (
                                    'menu' => 'main_menu',
                                    'theme_location' => 'main_menu',
                                    'container' => null,
                                    'menu_class' => 'navbar-nav menu mx-auto',
                                    'walker' => new Landpagy_Nav_Walker(),
                                    'depth' => 3
                                ));
                            }
                            // Action Button
                            get_template_part( 'template-parts/header-elements/action-button' );
                            ?>
                        </div>
                    </div>
                </nav>
            </header>
            <?php
        }
