<?php
/**
 * Landpagy theme helper functions and resources
 */

class Landpagy_Helper {
    /**
     * Hold an instance of Landpagy_Helper_Class class.
     * @var Landpagy_Helper
     */
    protected static $instance = null;

    /**
     * Main Landpagy_Helper_Class instance.
     * @return Landpagy_Helper - Main instance.
     */
    public static function instance() {

        if (null == self::$instance) {
            self::$instance = new Landpagy_Helper();
        }

        return self::$instance;
    }


    /**
     * Website Logo
     */
    public function logo () {
        ?>
        <a href="<?php echo esc_url( home_url( '/') ) ?>" class="navbar-brand header_logo">
            <?php
            $main_logo_url = LANDPAGY_DIR_IMG . '/logo/logo.svg';
            $main_retina_url = LANDPAGY_DIR_IMG . '/logo/logo.svg';
            $sticky_logo_url = LANDPAGY_DIR_IMG . '/logo/logo.svg';
            $sticky_retina_url = LANDPAGY_DIR_IMG . '/logo/logo.svg';

            if ( landpagy_opt('main_logo') ) {

                $main_logo = landpagy_opt('main_logo');
                $main_retina_logo = landpagy_opt('main_retina_logo');
                $sticky_logo = landpagy_opt('sticky_logo');
                $sticky_retina_logo = landpagy_opt('retina_sticky_logo');

                //Normal Logo
                $main_logo_url = ( isset($main_logo['url']) && $main_logo['url'] != '' ) ? $main_logo['url'] : '';
                $main_retina_url = ( isset($main_retina_logo['url'] ) && $main_retina_logo['url'] != '' ) ? $main_retina_logo['url'] : '';

                //Sticky Logo
                $sticky_logo_url = (isset($sticky_logo['url']) && $sticky_logo['url'] != '' ) ? $sticky_logo['url'] : '';
                $sticky_retina_url = (isset($sticky_retina_logo['url'] ) && $sticky_retina_logo['url'] != '' ) ? $sticky_retina_logo['url'] : '';

            }

            // Retina logo srcset
            $main_retina_srcset = ($main_retina_url != '' ) ? "srcset='$main_retina_url 2x'" : '';
            $sticky_retina_srcset = ($sticky_retina_url != '' ) ? "srcset='$sticky_retina_url 2x'" : '';

            if ($main_logo_url != '' ) { ?>
                <img class="main_logo" src="<?php echo esc_url($main_logo_url) ?>" alt="<?php bloginfo('name') ?>" <?php echo landpagy_kses_post($main_retina_srcset) ?>>
                <img class="sticky_logo" src="<?php echo esc_url($sticky_logo_url) ?>" alt="<?php bloginfo('name') ?>" <?php echo landpagy_kses_post($sticky_retina_srcset) ?>>
                <?php
            } else { ?>
                <h3 class="text_logo"><?php echo get_bloginfo('name') ?></h3>
                <?php
            }
            ?>
        </a>
        <?php
    }


    /**
     * Website Logo
     */
    public function footer_logo() {
        ?>
        <a href="<?php echo esc_url( home_url( '/') ) ?>">
            <?php
            $footer_logo = landpagy_opt('footer_logo');
            $retina_logo = landpagy_opt('footer_retina_logo');
            $retina_logo_url = $retina_logo['url'];
            $logo_srcset = !empty($retina_logo_url) ?  "srcset='$retina_logo_url 2x'" : '';

            if ( isset( $footer_logo['url'] ) ) {
                ?>
                <img class="main" src="<?php echo esc_url($footer_logo['url']); ?>" <?php echo wp_kses_post($logo_srcset) ?> alt="<?php bloginfo( 'name' ); ?>">
                <?php
            } else {
                echo '<h3>' . get_bloginfo( 'name' ) . '</h3>';
            }
            ?>
        </a>
        <?php

    }


    // Banner Title
    function banner_title() {
        if ( is_home() ) {
            $blog_title = landpagy_opt('blog_title', esc_html__('Blog', 'landpagy'));
            echo esc_html($blog_title);
        } elseif ( is_page() || is_single() ) {
            the_title();
        } elseif( is_category() ) {
            single_cat_title();
        } elseif( is_archive() ) {
            the_archive_title();
        } elseif( is_search() ) {
            esc_html_e( 'Search result for: “', 'landpagy' ); echo get_search_query().'”';
        } else {
            the_title();
        }
    }

    /**
     * Social Links
     **/
    function social_links() {

        if ( landpagy_opt('facebook') ) { ?>
            <li><a href="<?php echo esc_url(landpagy_opt('facebook')) ?>"><i class="fab fa-facebook-f"></i></a></li>
            <?php
        }
        if ( landpagy_opt('twitter') ) { ?>
            <li><a href="<?php echo esc_url(landpagy_opt('twitter')); ?>"><i class="fab fa-twitter"></i></a></li>
            <?php
        }
        if ( landpagy_opt('instagram') ) { ?>
            <li><a href="<?php echo esc_url(landpagy_opt('instagram')); ?>"><i class="fab fa-instagram"></i></a></li>
            <?php
        }
        if ( landpagy_opt('linkedin') ) { ?>
            <li><a href="<?php echo esc_url(landpagy_opt('linkedin')); ?>"><i class="fab fa-linkedin-in"></i></a></li>
            <?php
        }
    }

    /**
     * Pagination
     **/
    function pagination() {
        the_posts_pagination(array(
            'screen_reader_text' => ' ',
            'prev_text'          => '<i class="arrow_carrot-left"></i>',
            'next_text'          => '<i class="arrow_carrot-right"></i>'
        ));
    }

    /**
     * Day link to archive page
     **/
    function day_link() {
        $archive_year   = get_the_time( 'Y' );
        $archive_month  = get_the_time( 'm' );
        $archive_day    = get_the_time( 'd' );
        echo get_day_link( $archive_year, $archive_month, $archive_day);
    }

    /**
     * estimated reading time
     **/
    function reading_time() {
        $content = get_post_field( 'post_content', get_the_ID() );
        $word_count = str_word_count( strip_tags( $content ) );
        $readingtime = ceil($word_count / 200);
        if ($readingtime == 1) {
            $timer = esc_html__( " minute read", 'landpagy' );
        } else {
            $timer = esc_html__( " minutes read", 'landpagy' );
        }
        $totalreadingtime = $readingtime . $timer;
        echo esc_html($totalreadingtime);
    }

    /**
     * Post's excerpt text
     * @param $settings_key
     * @param bool $echo
     * @return string
     **/
    function excerpt($settings_key = '', $echo = true) {
        $excerpt_limit = landpagy_opt($settings_key, 40);
        $post_excerpt = get_the_excerpt();
        $excerpt = (strlen(trim($post_excerpt)) != 0) ? wp_trim_words(get_the_excerpt(), $excerpt_limit, '') : wp_trim_words(get_the_content(), $excerpt_limit, '');
        if(  $echo == true ) {
            echo wp_kses_post(wpautop($excerpt));
        } else {
            return wp_kses_post(wpautop($excerpt));
        }
    }

    /**
     * Post author avatar
     **/
    function post_author_avatar( $size = 50, $attr = '' ) {
        $post_author_id = get_post_field( 'post_author', get_the_ID() );
        echo get_avatar($post_author_id, $size, '', '', '');
    }

    /**
     * Get the first category name
     * @param string $term
     */
    function first_taxonomy( $term = 'category' ) {
        $cats = get_the_terms(get_the_ID(), $term);
        $cat  = is_array($cats) ? $cats[0]->name : '';
        echo esc_html($cat);
    }

    /**
     * Get the first category link
     * @param string $term
     */
    function first_taxonomy_link($term='category') {
        $cats = get_the_terms(get_the_ID(), $term);
        $cat  = is_array($cats) ? get_category_link($cats[0]->term_id) : '';
        echo esc_url($cat);
    }

    /**
     * Limit latter
     * @param $string
     * @param $limit_length
     * @param string $suffix
     */
    function limit_latter($string, $limit_length, $suffix = '...' ) {
        if (strlen($string) > $limit_length) {
            echo strip_shortcodes(substr($string, 0, $limit_length) . $suffix);
        }
        else {
            echo strip_shortcodes(esc_html($string));
        }
    }

    /**
     * Image from Theme Settings
     * @param $settins_key
     * @param string $class
     * @param string $alt
     */
    function image_from_settings( $settings_key = '', $class = '', $alt = '' ) {
        $page_image = function_exists('get_field') ? get_field($settings_key) : '';
        $image = empty($page_image) ? landpagy_opt($settings_key) : $page_image;
        if ( !empty($image['id']) ) {
            echo wp_get_attachment_image($image['id'], 'full', '', array('class' => $class));
        }
        elseif ( !empty($image['url']) && empty($image['id']) ) {
            $class = !empty($class) ? "class='$class'" : '';
            echo "<img src='{$image['url']}' $class alt='$alt'>";
        }
    }


    // Get comment count text
    function comment_count( $post_id ) {
        $comments_number = get_comments_number($post_id);
        if ( $comments_number == 0) {
            $comment_text = esc_html__( 'No Comment', 'landpagy' );
        } elseif( $comments_number == 1) {
            $comment_text = esc_html__( '1 Comment', 'landpagy' );
        } elseif( $comments_number > 1) {
            $comment_text = $comments_number.esc_html__( ' Comments', 'landpagy' );
        }
        echo esc_html($comment_text);
    }

    // Get author role
    function get_author_role() {
        global $authordata;
        $author_roles = $authordata->roles;
        $author_role = array_shift($author_roles);
        return esc_html($author_role);
    }


    // Banner Subtitle
    function banner_subtitle() {

        if ( class_exists('WooCommerce') ) {
            echo '';
        } else {
            if (is_home() ) {
                $blog_subtitle = landpagy_opt('blog_subtitle', get_bloginfo('description'));
                echo esc_html($blog_subtitle);
            }
            elseif (is_page() || is_single() ) {
                if (has_excerpt() ) {
                    while (have_posts() ) {
                        the_post();
                        echo nl2br(get_the_excerpt(get_the_ID() ));
                    }
                }
            }
            elseif ( is_archive() ) {
                echo '';
            }
        }
    }


    /**
     * Post title array
     */
    function get_postTitleArray($postType = 'post' ) {
        $post_type_query  = new WP_Query(
            array (
                'post_type'      => $postType,
                'posts_per_page' => -1
            )
        );
        // we need the array of posts
        $posts_array      = $post_type_query->posts;
        // the key equals the ID, the value is the post_title
        if (  is_array($posts_array) ) {
            $post_title_array = wp_list_pluck($posts_array, 'post_title', 'ID' );
        } else {
            $post_title_array['default'] = esc_html__( 'Default', 'landpagy' );
        }

        return $post_title_array;
    }


    /**
     * Get a specific html tag from content
     * @return a specific HTML tag from the loaded content
     */
    function get_html_tag( $tag = 'blockquote', $html = '' ) {
        $dom = new \DOMDocument();

        //Handle errors internally
        libxml_use_internal_errors(true);

        $dom->loadHTML(mb_convert_encoding($html, 'HTML-ENTITIES', 'UTF-8'));
        $divs = $dom->getElementsByTagName( $tag );

        //Clear errors
        libxml_clear_errors();

        $i = 0;
        foreach ( $divs as $div ) {
            if ( $i == 1 ) {
                break;
            }
            echo "<h4 class='c_head'>{$div->nodeValue}</h4>";
            ++$i;
        }
    }

    // Arrow icon left right position
    function arrow_left_right() {
        $arrow_icon = is_rtl() ? 'arrow_left' : 'arrow_right';
        echo esc_attr($arrow_icon);
    }


    function social_share() {
        ?>
        <li><a href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>"><i class="fab fa-facebook-f"></i></a></li>
        <li><a href="https://www.linkedin.com/shareArticle?mini=true&url=<?php the_permalink(); ?>"><i class="fab fa-linkedin-in"></i></a></li>
        <li><a href="https://pinterest.com/pin/create/button/?url=<?php the_permalink() ?>"><i class="fab fa-pinterest"></i></a></li>
        <li><a href="https://twitter.com/intent/tweet?url=<?php the_permalink(); ?>"><i class="fab fa-twitter"></i></a></li>
        <?php
    }


    /**
     * @param bool $is_button
     */
    function the_search_form( $is_button = true ) {
        ?>
        <div class="landpagy-search">
            <form class="form-wrapper" action="<?php echo esc_url(home_url( '/')); ?>">
                <label for="search">
                    <input type="text" id="search" name="s" placeholder="<?php esc_attr_e( 'Search ...', 'landpagy' ); ?>">
                </label>
                <button type="submit" class="btn"><i class="fa fa-search"></i></button>
            </form>
            <?php if ( $is_button == true ) { ?>
                <a href="<?php echo esc_url(home_url( '/')); ?>" class="home_btn"> <?php esc_html_e( 'Back to home Page', 'landpagy' ); ?> </a>
            <?php } ?>
        </div>
        <?php
    }



    /***
     * Get header template id
     * @package header builder id generate
     *
     * @param $posttype
     * @param $post_id
     * @return int|string
     */
    function header_footer_template_id( $posttype, $post_id ) {

        $template_id = '';
        $header_arg = [
            'post_type' => $posttype,
            'posts_per_page' => -1,
            'post_status' => 'publish',
            'order' => 'ASC',
            'orderby'=> 'date',
        ];

        $headers = get_posts($header_arg);

        foreach ($headers as $header) {
            if ( !get_post_meta( $header->ID, 'active_header_footer', true  ) ) {
                continue;
            }
            if ( get_post_meta($header->ID, 'entire_site', true) ) {
                $template_id = $header->ID;
            } elseif (get_post_meta($header->ID, 'select_page_menu', true)) {
                if (in_array($post_id, get_post_meta($header->ID, 'select_page_menu', true))) {
                    $template_id = $header->ID;
                }
            } else {
                $template_id = '';
            }
        }

        return $template_id;
    }


    function the_job_posts_count() {

        $count_posts = wp_count_posts('bjl_post');
        $total_posts = $count_posts->publish;
        $default_zero = esc_html__('0', 'landpagy');

        if ($total_posts == 0) {
            $text_post = esc_html__('No job offer', 'landpagy');
        } elseif ($total_posts <= 9) {
            $text_post = $default_zero . $total_posts . esc_html__(' job offers', 'landpagy');
        } elseif ($total_posts > 9) {
            $text_post = $total_posts . esc_html__(' job offers', 'landpagy');
        }

        echo esc_html($text_post);

    }



}


/**
 * Instance of Landpagy_Helper class
 */
function Landpagy_Helper() {
    return Landpagy_Helper::instance();
}