<?php

/**
 * Register Google fonts.
 *
 * @return string Google fonts URL for the theme.
 */
function landpagy_fonts_url() {
    $fonts_url = '';
    $fonts     = array();
    $subsets   = '';

    /* Inter font */
    if (  'off' !== 'on'  ) {
        $fonts[] = "Inter:300,400,500,600,700";
    }

    /* Poppins font */
    if (  'off' !== 'on'  ) {
        $fonts[] = "Poppins:300,400,500,600,700,800,900";
    }

    /* Kalam font */
    if (  'off' !== 'on'  ) {
        $fonts[] = "Kalam:700";
    }

    $is_ssl = is_ssl() ? 'https' : 'http';

    if ( $fonts ) {
        $fonts_url = add_query_arg( array(
            'family' => urlencode( implode( '|', $fonts  ) ),
            'subset' => urlencode( $subsets ),
        ), "$is_ssl://fonts.googleapis.com/css" );
    }

    return $fonts_url;
}

/**
 * Enqueue site scripts and styles
 */
function landpagy_scripts() {

    /**
     * Registering site's styles
     */
    wp_register_style( 'landpagy-fonts', landpagy_fonts_url(), array(), null);
    wp_register_style( 'nice-select',  LANDPAGY_DIR_VEND . '/nice-select/nice-select.css' );


    /**
     * Registering site's scripts
     */
    wp_register_script( 'nice-select', LANDPAGY_DIR_VEND . '/nice-select/jquery.nice-select.min.js', array( 'jquery' ), '1.0', true );


    /**
     * Enqueue site's styles
     */
    wp_enqueue_style( 'landpagy-fonts' );
    wp_enqueue_style( 'bootstrap',  LANDPAGY_DIR_VEND . '/bootstrap/css/bootstrap.min.css' );
    wp_enqueue_style( 'elegant-icon',  LANDPAGY_DIR_VEND . '/elegant-icon/style.css' );
    wp_enqueue_style( 'fontawesome',  LANDPAGY_DIR_VEND . '/font-awesome/fontawesome.min.css' );
    wp_enqueue_style( 'animation',  LANDPAGY_DIR_VEND . '/animation/animate.min.css' );
    wp_enqueue_style( 'landpagy-blog', LANDPAGY_DIR_CSS . '/blog.css', array( 'landpagy-main' ) );
    wp_enqueue_style( 'landpagy-main', LANDPAGY_DIR_CSS . '/style.css' );
    wp_enqueue_style( 'landpagy-root', get_stylesheet_uri() );
    wp_enqueue_style( 'landpagy-responsive', LANDPAGY_DIR_CSS . '/responsive.css');

    if (class_exists('EazyDocs')) {
        wp_enqueue_style('landpagy-eazy-docs', LANDPAGY_DIR_CSS . '/eazy-docs.css');
    }


    wp_enqueue_style( 'nice-select' );
    wp_enqueue_script( 'nice-select' );

    /**
     * WooCommerce Stylesheets
     */
    if ( class_exists( 'WooCommerce' ) ) {
        if ( is_shop() || is_singular('product') || is_cart() ) {
            wp_enqueue_style( 'landpagy-shop', LANDPAGY_DIR_CSS . '/shop.css' );
            wp_enqueue_style('nice-select');
            wp_enqueue_script('nice-select');
        }
        if ( is_checkout() ) {
            wp_enqueue_style( 'landpagy-checkout', LANDPAGY_DIR_CSS . '/checkout.css' );
        }
        if ( is_account_page() ) {
            wp_enqueue_style( 'landpagy-shop-my-account', LANDPAGY_DIR_CSS . '/shop-my_account.css' );
        }
    }


    // Inline CSS Render File
    require_once get_template_directory() . '/inc/landpagy_css_render.php';



    /**
     * Enqueue site's scripts
     */
    wp_enqueue_script( 'popper', LANDPAGY_DIR_VEND . '/bootstrap/js/popper.min.js', array( 'jquery' ), '2.9.2', true );
    wp_enqueue_script( 'bootstrap', LANDPAGY_DIR_VEND . '/bootstrap/js/bootstrap.min.js', array( 'jquery' ), '5.0.2', true );
    wp_enqueue_script( 'wow', LANDPAGY_DIR_VEND . '/wow/wow.min.js', array( 'jquery' ), '1.1.2', true );
    wp_enqueue_script( 'landpagy-preloader', LANDPAGY_DIR_VEND . '/pre-loader/preloader.js', array( 'jquery' ), '1.0.0', true );
    wp_enqueue_script( 'paroller', LANDPAGY_DIR_VEND . '/paroller/jquery.paroller.js', array( 'jquery' ), '1.4.7', true );
    wp_enqueue_script( 'landpagy-custom', LANDPAGY_DIR_JS . '/wp-custom.js', array( 'jquery' ), '1.0.0', true );
    wp_enqueue_script( 'landpagy-job-listing', LANDPAGY_DIR_JS . '/job-listing.js', array( 'jquery' ), '1.0.0', true );


    /**
     * Inline Scripts
     */
    $dynamic_js = '';

    /**
     * Ajax Call - Job listing Page
     */
    wp_localize_script( 'landpagy-job-listing', 'load_more_btn', array(
        'ajax_url' => admin_url( 'admin-ajax.php' ),
    ));

    wp_add_inline_script( 'landpagy-custom', $dynamic_js);

    if (  is_singular() && comments_open() && get_option( 'thread_comments'  )  ) {
        wp_enqueue_script( 'comment-reply' );
    }
}
add_action( 'wp_enqueue_scripts', 'landpagy_scripts' );

// Admin dashboard style and scripts
add_action( 'admin_enqueue_scripts', function() {
    wp_enqueue_style( 'landpagy-admin', LANDPAGY_DIR_CSS. '/admin.css' );
});