<?php
//Add Image Size
add_image_size('landpagy_360x240', 360, 240, true); // Blog Related thumbnails
add_image_size('landpagy_270x320', 270, 320, true); // Product Grid
add_image_size('landpagy_300x320', 300, 320, true); // Product Grid
add_image_size('landpagy_450x420', 450, 420, true); // Product List
add_image_size('landpagy_75x75', 75, 75, true); // Product Cart Image
add_image_size('landpagy_80x90', 80, 90, true); // Product Widgets thumbnails


// add category nicknames in body and post class
function landpagy_post_class( $classes ) {
    global $post;
    if ( !has_post_thumbnail() ) {
        $classes[] = 'no-post-thumbnail';
    }
    if ( is_sticky() && !in_array('sticky', $classes) ) {
        $classes[] = 'sticky';
    }
    return $classes;
}
add_filter( 'post_class', 'landpagy_post_class' );



// filter to replace class on reply link
add_filter('comment_reply_link', function($class){
    $class = str_replace("class='comment-reply-link", "class='comment_reply", $class);
    return $class;
});

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function landpagy_pingback_header() {
    if ( is_singular() && pings_open() ) {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'landpagy_pingback_header' );

// Move the comment field to bottom
add_filter( 'comment_form_fields', function ( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
});

// Remove WordPress admin bar default CSS
add_action('get_header', function() {
    remove_action('wp_head', '_admin_bar_bump_cb' );
});


// Elementor post type support
function landpagy_add_cpt_support() {

    //if exists, assign to $cpt_support var
    $cpt_support = get_option( 'elementor_cpt_support' );

    //check if option DOESN'T exist in db
    if ( ! $cpt_support ) {
        $cpt_support = [ 'page', 'post' ]; //create array of our default supported post types
        update_option( 'elementor_cpt_support', $cpt_support ); //write it to the database
    }

    //otherwise do nothing, portfolio already exists in elementor_cpt_support option
}
add_action( 'after_switch_theme', 'landpagy_add_cpt_support' );


// Wrap up the category count in span tag
add_filter( 'wp_list_categories', function($links) {
    $links = str_replace('</a> (', '<span>(', $links);
    $links = str_replace(')', ')</span> </a>', $links);
    return $links;
});

// Wrap up the Archive count in span tag
add_filter( 'get_archives_link', function($links) {
    $links = str_replace('</a>&nbsp;(', '<span>(', $links);
    $links = str_replace(')', ')</span> </a>', $links);
    return $links;
});

// Remove auto p from Contact Form 7 shortcode output
add_filter( 'wpcf7_autop_or_not', function() {
    return false;
});
