<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some functionality here could be replaced by core features.
 *
 * @package landpagy
 */
/**
 * @param string  $content   Text content to filter.
 * @return string Filtered content containing only the allowed HTML.
 * */
if ( ! function_exists( 'landpagy_kses_post' ) ) {
    function landpagy_kses_post($content) {
        $allowed_tag = array(
            'strong' => [],
            'br' => [],
            'p' => [
                'class' => [],
                'style' => [],
            ],
            'i' => [
                'class' => [],
                'style' => [],
            ],
            'ul' => [
                'class' => [],
                'style' => [],
            ],
            'li' => [
                'class' => [],
                'style' => [],
            ],
            'span' => [
                'class' => [],
                'style' => [],
            ],
            'a' => [
                'href' => [],
                'class' => [],
                'title' => []
            ],
            'div' => [
                'class' => [],
                'style' => [],
            ],
            'h1' => [
                'class' => [],
                'style' => []
            ],
            'h2' => [
                'class' => [],
                'style' => []
            ],
            'h3' => [
                'class' => [],
                'style' => []
            ],
            'h4' => [
                'class' => [],
                'style' => []
            ],
            'h5' => [
                'class' => [],
                'style' => []
            ],
            'h6' => [
                'class' => [],
                'style' => []
            ],
            'img' => [
                'class' => [],
                'style' => [],
                'height' => [],
                'width' => [],
                'src' => [],
                'srcset' => [],
                'alt' => [],
            ],

        );
        return wp_kses($content, $allowed_tag);
    }
}


/**
 * Banner Style Settings
 * @param string $settings_key themes and meta options key
 * @return string
 * */
function landpagy_banner_options ( $settings_key ) {
    $style_opt = landpagy_opt($settings_key,'2' );
    $style_page = ( function_exists('get_field') && '' != get_field( $settings_key ) &&  get_field( $settings_key ) != 'default' ) ? get_field($settings_key) : $style_opt;
    return $style_page;
}

/**
 * Get landpagy Banner
 * @package Banner
 * @return @style
 */
function landpagy_get_banner() {

    //================== Page Banner
    if ( is_home() ) {
        get_template_part( 'template-parts/header-elements/banner', landpagy_banner_options('blog_title_bar_style') );
    }
    elseif ( ! is_singular('post') ) {
        get_template_part( 'template-parts/header-elements/banner', landpagy_banner_options('banner_style') );
    }

    //================= Post Banner
    if ( is_singular( 'post') ) {
        get_template_part('template-parts/header-elements/banner_single' );
    }

}


// Banner Shop
if ( !function_exists('landpagy_get_shop_banner') ) {
    function landpagy_get_shop_banner() {
        if ( class_exists('WooCommerce') ) {
            if ( is_shop() || is_cart()  || is_checkout() || is_tax( 'product_cat' ) || is_tax( 'product_tag' ) || is_account_page() ) {
                get_template_part( 'template-parts/header-elements/banner', landpagy_banner_options('shop_title_bar_style') );
            }
        }
    }
}

/**
 * @param $section_id
 * @param $default
 *
 * Get Customizer
 */
if ( !function_exists('landpagy_opt' ) ) {
    function landpagy_opt ( $section_id, $default = '' ) {

        $landpagy_option_data = $default;

        if ( class_exists( 'Redux' ) ) {

            global $landpagy_opt;
            $landpagy_option_data = (isset($landpagy_opt[$section_id])) && ( !empty($landpagy_opt[$section_id]) ) ? $landpagy_opt[$section_id] : $default;

        }
        return $landpagy_option_data;
    }
}


/**
 * @param $page_title_name
 * @return int|string|void
 * Page Title to id
 */
function landpagy_get_page_title( $page_title_name ){
    $args = array(
        'post_type' => 'page',
        'posts_per_page' => -1,
        'post_status' => 'publish'
    );
    $page_title = get_posts($args);
    if( !empty( $page_title ) ){
        $title_name_id = '';
        foreach( $page_title as $title ){
            if( $page_title_name == $title->post_title ){
                $title_name_id = $title->ID;
            }
        }
        return $title_name_id;
    }
}
