<?php
/**
 * Plugin Name: Landpagy Core
 * Plugin URI: https://themeforest.net/user/spider-themes/portfolio
 * Description: This plugin adds the core features to the Landpagy WordPress theme. You must have to install this plugin to get all the features included with the Landpagy theme.
 * Version: 1.8.5
 * Requires at least: 5.0
 * Tested up to: 6.4
 * Requires PHP: 7.4
 * Author: spider-themes
 * Author URI: https://themeforest.net/user/spider-themes/portfolio
 * Text domain: landpagy-core
 */

if ( !defined( 'ABSPATH') )
    die( '-1');

// Landpagy Core (short-form - LC) Directories
define( 'LC_VERSION', '1.8.5' );
define( 'LC__FILE__', __FILE__ );
define( 'LC_DIR_PATH', plugin_dir_path( LC__FILE__ ) );
define( 'LC_IMAGES', plugins_url( 'assets/img', __FILE__));
define( 'LC_DIR_CSS', plugins_url( 'assets/css/', __FILE__));
define( 'LC_DIR_JS', plugins_url( 'assets/js/', __FILE__));
define( 'LC_DIR_VEND', plugins_url( 'assets/vendors/', __FILE__));

// Make sure the same class is not loaded twice in free/premium versions.
if ( !class_exists( 'Landpagy_core' ) ) {
	/**
	 * Main Landpagy Core Class
	 *
	 * The main class that initiates and runs the Landpagy Core plugin.
	 *
	 * @since 1.7.0
	 */
	class Landpagy_core {
		/**
		 * Landpagy Core Version
		 *
		 * Holds the version of the plugin.
		 *
		 * @since 1.7.0
		 * @since 1.7.1 Moved from property with that name to a constant.
		 *
		 * @var string The plugin version.
		 */
		const VERSION = '1.8.5' ;

		/**
		 * Minimum Elementor Version
		 *
		 * Holds the minimum Elementor version required to run the plugin.
		 *
		 * @since 1.7.0
		 * @since 1.7.1 Moved from property with that name to a constant.
		 *
		 * @var string Minimum Elementor version required to run the plugin.
		 */
		const MINIMUM_ELEMENTOR_VERSION = '3.0.0';

		/**
		 * Minimum PHP Version
		 *
		 * Holds the minimum PHP version required to run the plugin.
		 *
		 * @since 1.7.0
		 * @since 1.7.1 Moved from property with that name to a constant.
		 *
		 * @var string Minimum PHP version required to run the plugin.
		 */
		const  MINIMUM_PHP_VERSION = '7.4' ;

        /**
         * Plugin's directory paths
         * @since 1.0
         */
        const CSS = null;
        const JS = null;
        const IMG = null;
        const VEND = null;

		/**
		 * Instance
		 *
		 * Holds a single instance of the `Landpagy_Core` class.
		 *
		 * @since 1.7.0
		 *
		 * @access private
		 * @static
		 *
		 * @var Landpagy_Core A single instance of the class.
		 */
		private static  $_instance = null ;

		/**
		 * Instance
		 *
		 * Ensures only one instance of the class is loaded or can be loaded.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 * @static
		 *
		 * @return Landpagy_Core An instance of the class.
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * Clone
		 *
		 * Disable class cloning.
		 *
		 * @since 1.7.0
		 *
		 * @access protected
		 *
		 * @return void
		 */
		public function __clone() {
			// Cloning instances of the class is forbidden
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'landpagy-core' ), '1.7.0' );
		}

		/**
		 * Wakeup
		 *
		 * Disable unserializing the class.
		 *
		 * @since 1.7.0
		 *
		 * @access protected
		 *
		 * @return void
		 */
		public function __wakeup() {
			// Unserializing instances of the class is forbidden.
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'landpagy-core' ), '1.7.0' );
		}

		/**
		 * Constructor
		 *
		 * Initialize the Landpagy Core plugins.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 */
        public function __construct() {
            $opt = get_option('landpagy_opt');
            $this->init_hooks();
            $this->core_includes();
            do_action( 'landpagy_core_loaded' );

            add_filter( 'elementor/icons_manager/additional_tabs', [ $this, 'landpagy_elegant_icons']);
            //self :: generate_custom_font_icons();

        }

        public function landpagy_elegant_icons( $custom_fonts ) {

            $css_data = LC_DIR_VEND . '/elegant-icon/style.css';
            $json_data = plugins_url( 'assets/fonts/elegant.json', __FILE__ );

            $custom_fonts['elegant_icons'] = [
                'name'          => 'elegant_icons',
                'label'         => esc_html__( 'Elegant Icons', 'landpagy-core' ),
                'url'           => $css_data,
                'prefix'        => '',
                'displayPrefix' => '',
                'labelIcon'     => 'icon_star_alt',
                'ver'           => '',
                'fetchJson'     => $json_data,
                'native'        => true,
            ];

            return $custom_fonts;
        }


        public static function generate_custom_font_icons(){
            $css_source = '';
            global $wp_filesystem;
            require_once ( ABSPATH . '/wp-admin/includes/file.php' );
            WP_Filesystem();
            $css_file =  LC_DIR_PATH . '/assets/fonts/style.css';
            if ( $wp_filesystem->exists( $css_file ) ) {
                $css_source = $wp_filesystem->get_contents( $css_file );
            }
            preg_match_all( "/\.(arrow_.*?):\w*?\s*?{/", $css_source, $matches, PREG_SET_ORDER, 0 );
            $iconList = [];
            foreach ( $matches as $match ) {
                $icon = str_replace('', '', $match[1]);
                $icons = explode(' ', $icon);
                $iconList[] = current($icons);
            }

            preg_match_all( "/\.(icon_.*?):\w*?\s*?{/", $css_source, $matches1, PREG_SET_ORDER, 0 );
            foreach ( $matches1 as $match ) {
                $icon = str_replace('', '', $match[1]);
                $icons = explode(' ', $icon);
                $iconList[] = current($icons);
            }

            preg_match_all( "/\.(social_.*?):\w*?\s*?{/", $css_source, $matches1, PREG_SET_ORDER, 0 );
            foreach ( $matches1 as $match ) {
                $icon = str_replace('', '', $match[1]);
                $icons = explode(' ', $icon);
                $iconList[] = current($icons);
            }

            $icons = new \stdClass();
            $icons->icons = $iconList;
            $icon_data = json_encode($icons);
            $file = LC_DIR_PATH . '/assets/fonts/elegant.json';
            global $wp_filesystem;
            require_once ( ABSPATH . '/wp-admin/includes/file.php' );
            WP_Filesystem();
            if ( $wp_filesystem->exists( $file ) ) {
                $content =  $wp_filesystem->put_contents( $file, $icon_data) ;
            }
        }


        /**
		 * Include Files
		 *
		 * Load core files required to run the plugin.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 */
		public function core_includes() {
		    $opt = get_option('landpagy_opt');

		    // Extra functions
			require_once __DIR__ . '/inc/extra.php';

			//Filter Actions
			require_once __DIR__ . '/inc/filter_actions.php';

            /**
             * Plugin's Helper Class
             */
            require_once __DIR__ . '/inc/classes/class-plugin-helper.php';

			//Custom post types
            require_once __DIR__ . '/post-type/portfolio.pt.php';
            require_once __DIR__ . '/post-type/faqs.pt.php';
            require_once __DIR__ . '/post-type/header_footer.pt.php';

            /**
             * Register widget area.
             *
             * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
             */
			require_once __DIR__ . '/wp-widgets/widgets.php';


            /**
             * Saving automatically the ACF group fields json files
             */
            add_filter('acf/settings/save_json', function ( $path ) {

                // update path
                $path = LC_DIR_PATH . '/inc/acf-json';

                // return
                return $path;

            });

            /**
             * Loading the saved ACF fields
             */
            add_filter('acf/settings/load_json', function ( $paths ) {

                // append path
                $paths[] = LC_DIR_PATH . 'inc/acf-json';

                // return
                return $paths;
            });

		}

		/**
		 * Init Hooks
		 *
		 * Hook into actions and filters.
		 *
		 * @since 1.7.0
		 *
		 * @access private
		 */
		private function init_hooks() {
			add_action( 'init', [ $this, 'i18n' ] );
			add_action( 'plugins_loaded', [ $this, 'init' ] );
		}

		/**
		 * Load Textdomain
		 *
		 * Load plugin localization files.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 */
		public function i18n() {
			load_plugin_textdomain( 'landpagy-core', false, plugin_basename( dirname( __FILE__ ) ) . '/languages' );
		}

		/**
		 * Init Landpagy Core
		 *
		 * Load the plugin after Elementor (and other plugins) are loaded.
		 *
		 * @since 1.0.0
		 * @since 1.7.0 The logic moved from a standalone function to this class method.
		 *
		 * @access public
		 */
		public function init() {

			if ( !did_action( 'elementor/loaded' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
				return;
			}

			// Check for required Elementor version
			if ( !version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
				return;
			}

			// Check for required PHP version
			if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
				return;
			}

			// Add new Elementor Categories
			add_action( 'elementor/init', [ $this, 'add_elementor_category' ] );

            // Register Widget Scripts
            add_action( 'elementor/frontend/after_register_scripts', [ $this, 'register_widget_scripts' ] );
            add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'register_widget_scripts' ] );

            // Enqueue Widgets Script
            add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'enqueue_elementor_scripts' ], 5 );
            add_action( 'elementor/frontend/after_enqueue_scripts', [ $this, 'enqueue_elementor_scripts' ], 5 );

            // Register Widget Scripts
            add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'enqueue_elementor_editor_styles' ] );
            add_action( 'elementor/frontend/after_enqueue_styles', [ $this, 'enqueue_widget_styles' ] );

			// Register New Widgets
			add_action( 'elementor/widgets/widgets_registered', [ $this, 'on_widgets_registered' ] );

		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have Elementor installed or activated.
		 *
		 * @since 1.1.0
		 * @since 1.7.0 Moved from a standalone function to a class method.
		 *
		 * @access public
		 */
		public function admin_notice_missing_main_plugin() {
			$message = sprintf(
			/* translators: 1: Landpagy Core 2: Elementor */
				esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'landpagy-core' ),
				'<strong>' . esc_html__( 'Landpagy core', 'landpagy-core' ) . '</strong>',
				'<strong>' . esc_html__( 'Elementor', 'landpagy-core' ) . '</strong>'
			);
			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have a minimum required PHP version.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 */
		public function admin_notice_minimum_php_version() {
			$message = sprintf(
			/* translators: 1: Landpagy Core 2: PHP 3: Required PHP version */
				esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'landpagy-core' ),
				'<strong>' . esc_html__( 'Landpagy Core', 'landpagy-core' ) . '</strong>',
				'<strong>' . esc_html__( 'PHP', 'landpagy-core' ) . '</strong>',
				self::MINIMUM_PHP_VERSION
			);
			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
		}

		/**
		 * Add new Elementor Categories
		 *
		 * Register new widget categories for Landpagy Core widgets.
		 *
		 * @since 1.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */
		public function add_elementor_category() {
			\Elementor\Plugin::instance()->elements_manager->add_category( 'landpagy-elements', [
				'title' => __( 'Landpagy Elements', 'landpagy-core' ),
			], 1 );
		}


		/**
		 * Register Widget Styles
		 *
		 * Register custom styles required to run Landpagy Core.
		 *
		 * @since 1.7.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */

		public function enqueue_widget_styles() {
            wp_register_style( 'landpagy-swiper', LC_DIR_VEND . 'swiper/swiper.min.css' );
            wp_register_style( 'slick', LC_DIR_VEND . 'slick/css/slick.css' );
            wp_register_style( 'slick-theme', LC_DIR_VEND . 'slick/css/slick-theme.css' );
            wp_register_style( 'fancybox', LC_DIR_VEND . 'fancybox/css/jquery.fancybox.min.css' );
            wp_register_style( 'nice-select', LC_DIR_VEND . 'nice-select/nice-select.css' );
			wp_register_style( 'elegant-icon', LC_DIR_VEND . 'elegant-icon/style.css' );

            wp_enqueue_style( 'landpagy-mega-menu', LC_DIR_CSS . 'mega-menu.css' );
            wp_enqueue_style( 'landpagy-core-custom', LC_DIR_CSS . 'custom.css' );
            wp_enqueue_style( 'landpagy-core-override-elementor', LC_DIR_CSS . 'override-elementor.css' );
        }

        /**
         * Register Widget Scripts
         *
         * Register custom scripts required to run Landpagy Core.
         *
         * @since 1.6.0
         * @since 1.7.1 The method moved to this class.
         *
         * @access public
         */
        public function register_widget_scripts() {
            wp_register_script( 'tippy', LC_DIR_VEND . 'tippy/tippy.min.js', 'jquery', LC_VERSION, true );
            wp_register_script( 'squareCountDownClock', LC_DIR_VEND . 'countdown/squareCountDownClock.js', 'jquery', LC_VERSION, true );
            wp_register_script( 'landpagy-swiper', LC_DIR_VEND . 'swiper/swiper.min.js', 'jquery', '6.5.0', true );
            wp_register_script( 'ScrollMagic', LC_DIR_VEND . 'ScrollMagic/ScrollMagic.js', 'jquery', '2.0.5', true );
            wp_register_script( 'TweenMax', LC_DIR_VEND . 'TweenMax/TweenMax.min.js', 'jquery', '1.18.0', true );
            wp_register_script( 'addIndicators', LC_DIR_VEND . 'addIndicators/debug.addIndicators.min.js', 'jquery', LC_VERSION, true );
            wp_register_script( 'animation-gsap', LC_DIR_VEND . 'animation/animation.gsap.js', 'jquery', '2.0.5', true );
            wp_register_script( 'nice-select', LC_DIR_VEND . 'nice-select/jquery.nice-select.min.js', 'jquery', '1.0', true );
            wp_register_script( 'parallaxie', LC_DIR_VEND . 'parallax/parallaxie.js', 'jquery', '0.5', true );
            wp_register_script( 'parallax-scroll', LC_DIR_VEND . 'parallax/jquery.parallax-scroll.js', 'jquery', LC_VERSION, true );
            wp_register_script( 'parallax', LC_DIR_VEND . 'parallax/parallax.js', 'jquery', '1.0.0', true );
            wp_register_script( 'ajax-chimp', LC_DIR_VEND . 'ajax/ajax-chimp.js', 'jquery', LC_VERSION, true );
            wp_register_script( 'slick', LC_DIR_VEND . 'slick/js/slick.min.js', 'jquery', LC_VERSION, true );
            wp_register_script( 'fancybox', LC_DIR_VEND . 'fancybox/js/jquery.fancybox.min.js', 'jquery', '3.5.7', true );
            wp_register_script( 'isotope', LC_DIR_VEND . 'isotope/isotope.pkgd.min.js', 'jquery', '3.0.6', true );
            wp_register_script( 'jquery-ui', LC_DIR_VEND . 'jquery-ui/jquery-ui.min.js', 'jquery', '1.12.1', true );
            wp_register_script( 'counterup', LC_DIR_VEND . 'counterup/jquery.counterup.min.js', 'jquery', '1.0', true );
            wp_register_script( 'waypoints', LC_DIR_VEND . 'counterup/jquery.waypoints.min.js', 'jquery', '4.0.0', true );
        }

        /**
         * Enqueue and dequeue scripts and styles
         */
        public function enqueue_elementor_scripts() {
            wp_enqueue_script( 'landpagy-elementor', LC_DIR_JS . 'landpagy-elementor.js', [ 'jquery', 'elementor-frontend'], LC_VERSION, true );
        }


        /**
         * Enqueue Elementor Editor Preview Styles
         */
        public function enqueue_elementor_editor_styles() {

            wp_enqueue_style( 'landpagy-elementor-editor', LC_DIR_CSS . 'elementor-editor.css' );

        }

		/**
		 * Register New Widgets
		 *
		 * Include Landpagy Core widgets files and register them in Elementor.
		 *
		 * @since 1.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */
		public function on_widgets_registered() {
			$this->include_widgets();
			$this->register_widgets();
		}

		/**
		 * Include Widgets Files
		 *
		 * Load Landpagy Core widgets files.
		 *
		 * @since 1.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access private
		 */
		private function include_widgets() {
            require_once __DIR__ . '/vendor/autoload.php';
        }

		/**
		 * Register Widgets
		 *
		 * Register Landpagy Core widgets.
		 *
		 * @since 1.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access private
		 */
		private function register_widgets() {

            // Site Elements
            $widgets = array(
                'Hero', 'Heading', 'Clients_Logo', 'Mailchimp', 'Tabs', 'Testimonials', 'Accordion', 'Call_to_Action','Image_Box',
                'Parallax', 'Locations', 'Timeline', 'Promotional_Offer', 'Pricing_Table_Tabs', 'Pricing_Table_Switcher', 'Dots', 'Illustrations',
                'Portfolio', 'States_Features', 'Features', 'Circle_steps', 'Buttons', 'Images', 'Faqs', 'Testimonials_Carousel', 'Featured_video',
                'Blog', 'Integrations', 'Nav_Menu', 'Screen_features', 'Timeline_Carousel', 'Counter', 'Highlight_Boxes', 'Processes', 'WPML',
                'Banner', 'SignUp', 'SignIn', 'Contact_form', 'Jobs', 'Mega_Menu', 'Table_Content', 'Team', 'Search_form', 'Docs',
                'Info_Boxes', 'Available_Job_Posts', 'Countdown','Search_form_job'
            );

            foreach ( $widgets as $widget ) {
                $classname = "\\LandpagyCore\\Widgets\\$widget";
                \Elementor\Plugin::instance()->widgets_manager->register( new $classname() );
            }
        }
	}
}

// Make sure the same function is not loaded twice in free/premium versions.

if ( !function_exists( 'landpagy_core_load' ) ) {
    /**
     * Load Banca Core
     *
     * Main instance of Banca_Core.
     *
     * @since 1.0.0
     * @since 1.7.0 The logic moved from this function to a class method.
     */
    function landpagy_core_load() {
        return Landpagy_core::instance();
    }

    // Run Banca Core
    landpagy_core_load();
}