<?php
namespace LandpagyCore\Widgets;

use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Accordion extends Widget_Base {

    public function get_name() {
        return 'landpagy_accordion';
    }

    public function get_title() {
        return __( 'Accordion (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-accordion';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }

    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //============================ Select Style ===========================//
        $this->start_controls_section(
            'style_sec', [
                'label' => esc_html__( 'Preset Skins', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Style', 'landpagy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( 'Style 01', 'landpagy-core' ),
                    '2' => esc_html__( 'Style 02', 'landpagy-core' ),
                    '3' => esc_html__( 'Style 03', 'landpagy-core' ),
                    '4' => esc_html__( 'Style 04', 'landpagy-core' ),
                    '5' => esc_html__( 'Style 05', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section(); //End Style


        //=========================== Accordion ============================//
        $this->start_controls_section(
            'accordion_sec', [
                'label' => __( 'Accordion', 'landpagy-core' ),
            ]
        );

        //========= Accordion Style 01, 02
        $accordion_1 = new Repeater();
        $accordion_1->add_control(
            'tab_title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __( 'Accordion Title', 'landpagy-core' ),
                'dynamic' => [
                    'active' => true,
                ],
                'label_block' => true,
            ]
        );

        $accordion_1->add_control(
            'tab_content', [
                'label' => __( 'Content', 'landpagy-core' ),
                'type' => Controls_Manager::WYSIWYG,
                'default' => __( 'Accordion Content', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'tabs', [
                'label' => __( 'Accordion Items', 'landpagy-core' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $accordion_1->get_controls(),
                'title_field' => '{{{ tab_title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => [ '1', '2', '4', '5' ]
                ]
            ]
        ); //End Accordion style 01, 02


        //========= Accordion Style 03
        $accordion_2 = new Repeater();
        $accordion_2->add_control(
            'tab_title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Desktop App',
            ]
        );

        $accordion_2->add_control(
            'tab_content', [
                'label' => __( 'Content', 'landpagy-core' ),
                'type' => Controls_Manager::WYSIWYG,
            ]
        );

        $accordion_2->add_control(
            'btn_title', [
                'label' => __( 'Button Title', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Learn more',
            ]
        );

        $accordion_2->add_control(
            'btn_url', [
                'label' => __( 'Button URL', 'landpagy-core' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ]
            ]
        );

        $this->add_control(
            'tabs2', [
                'label' => __( 'Accordion Items', 'landpagy-core' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $accordion_2->get_controls(),
                'title_field' => '{{{ tab_title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '3'
                ]
            ]
        );//End Accordion style 03


        $this->end_controls_section(); //End Accordion

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {

        // ======================= Accordion Style ======================== //
        $this->start_controls_section(
         'accordion_style', [
                'label' => esc_html__( 'Accordion', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->end_controls_section();
        
    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $tabs = $this->get_settings_for_display( 'tabs' );
        $id_int = substr( $this->get_id_int(), 0, 1 );

	    include( "template/accordion/accordion-{$settings['style']}.php" );

    }
}