<?php
namespace LandpagyCore\Widgets;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Banner extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_banner';
    }

    public function get_title() {
        return __( 'Banner (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-banner';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        // =========================Title ====================== //
        $this->start_controls_section(
            'sec_title', [
                'label' => __( 'Banner Contents', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Feel free to contact us or just say hi!'
            ]
        );

        $this->end_controls_section(); //End Title


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {

        // =================== Banner Content Style =============== //
            $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Contents', 'textdomain' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);


        $this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .section-title-center h2' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .section-title-center h2',
			]
		);

		$this->end_controls_section(); // ===== End banner content style =========//



        // ========================= Shape Images ====================== //
        $this->start_controls_section(
            'shape_images', [
                'label' => __( 'Shape Images', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'shape1', [
                'label' => __( 'Shape', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape2', [
                'label' => __( 'Shape 2', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape3', [
                'label' => __( 'Shape 3', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_section(); //End Shape Images


        // ========================= Floating Object Images ====================== //
        $this->start_controls_section(
            'floating_obj_images', [
                'label' => __( 'Object Images', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'obj1', [
                'label' => __( 'Object', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'obj2', [
                'label' => __( 'Object 2', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_section(); //End Shape Images

    }


    /**
     * Name: render()
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        ?>
        <section class="banner-area contact-banner-area">
            <div class="container">
                <div class="row">
                    <div class="col-12">
                        <div class="section-title-center">
                            <h2 class="font-bold mt-n3"><?php echo esc_html($settings['title']) ?></h2>
                        </div>
                    </div>
                </div>
            </div>
            <?php
            echo wp_get_attachment_image($settings['shape1']['id'], 'full', '', array( 'class' => 'shape13' ));
            echo wp_get_attachment_image($settings['shape2']['id'], 'full', '', array( 'class' => 'shape14' ));
            echo wp_get_attachment_image($settings['shape3']['id'], 'full', '', array( 'class' => 'shape15' ));
            echo wp_get_attachment_image($settings['obj1']['id'], 'full', '',
                array(
                    'class' => 'shape16 object-element',
                    'data-paroller-factor' => '0.05',
                    'data-paroller-type' => 'foreground',
                    'data-paroller-direction' => 'horizontal',
                    'data-paroller-transition' => 'transform .2s linear',
                ));
            echo wp_get_attachment_image($settings['obj2']['id'], 'full', '', array( 'class' => 'pricing-shape-11' ));
            ?>
        </section>
        <?php

    }
}