<?php
namespace LandpagyCore\Widgets;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Blog extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_blog';
    }

    public function get_title() {
        return __( 'Blog Posts (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-post';
    }

    /**
     * @return string[]
     * Get Style's
     */
    public function get_style_depends() {
        return [ 'slick-theme', 'slick' ];
    }

    /**
     * @return string[]
     * Get Script's
     */
    public function get_script_depends() {
        return [ 'slick' ];
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //============================= Style ================================//
        $this->start_controls_section(
            'select_style', [
                'label' => __('Style', 'banca-core'),
            ]
        );

        $this->add_control(
            'style', [
                'label' => __( 'Style', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '1'  => __( 'Style 01', 'banca-core' ),
                    '2'  => __( 'Style 02', 'banca-core' ),
                    '3'  => __( 'Style 03 with Pagination', 'banca-core' ),
                    '4'  => __( '04: Blog Grid', 'banca-core' ),
                    '5'  => __( '05: Blog List', 'banca-core' ),
                    '6'  => __( '06: Sticky Post', 'banca-core' ),
                    '7'  => __( '07: Blog Category', 'banca-core' ),
                    '8'  => __( '08: Blog Grid', 'banca-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section(); //End Style



        //============================= Filter Options ================================//
        $this->start_controls_section(
            'filter_sec', [
                'label' => __('Filter', 'banca-core'),
            ]
        );

        $this->add_control(
            'cats', [
                'label' => esc_html__('Category', 'banca-core'),
                'description' => esc_html__( 'Display blog by categories', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'options' => Landpagy_Core_Helper()->get_the_categories(),
                'multiple' => true,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'show_count', [
                'label' => esc_html__('Show Posts Count', 'banca-core'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 3
            ]
        );

        $this->add_control(
            'order', [
                'label' => esc_html__('Order', 'banca-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'ASC' => 'ASC',
                    'DESC' => 'DESC'
                ],
                'default' => 'ASC'
            ]
        );

        $this->add_control(
            'orderby', [
                'label' => esc_html__( 'Order By', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'none' => 'None',
                    'ID' => 'ID',
                    'author' => 'Author',
                    'title' => 'Title',
                    'name' => 'Name (by post slug)',
                    'date' => 'Date',
                    'rand' => 'Random',
                ],
                'default' => 'none'
            ]
        );

        $this->add_control(
            'title_length', [
                'label' => esc_html__('Title Length', 'banca-core'),
                'type' => \Elementor\Controls_Manager::NUMBER,
            ]
        );

        $this->add_control(
            'excerpt_length', [
                'label' => esc_html__('Excerpt Word Length', 'banca-core'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 15,
            ]
        );

        $this->add_control(
            'exclude', [
                'label' => esc_html__( 'Exclude Blog', 'banca-core' ),
                'description' => esc_html__( 'Enter the portfolio post IDs to hide/exclude. Input the multiple ID with comma separated', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Image_Size::get_type(), [
                'name' => 'thumbnail_size', // // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
                'include' => [],
                'default' => 'full',
            ]
        );

        // View Button
        $this->add_control(
            'read_more_btn', [
                'label' => esc_html__( 'Read More Button', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Read More',
            ]
        );

        $this->end_controls_section(); //End Filter Options


        //============================= Column Options ================================//
        $this->start_controls_section(
            'sec_column', [
                'label' => __('Column', 'banca-core'),
                'condition' => [
                    'style' => [ '1', '3', '4', '7', '8' ]
                ]
            ]
        );

        $this->add_control(
            'column', [
                'label' => esc_html__( 'Column', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '6' => __('Two', 'landpagy-core'),
                    '4' => __('Three', 'landpagy-core'),
                    '3' => __('Four', 'landpagy-core'),
                    '2' => __('Six', 'landpagy-core'),
                ],
                'default' => '4',
            ]
        );

        $this->end_controls_section(); //End Column Options


    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============================= Style Contents ================================//
        $this->start_controls_section(
            'style_contents', [
                'label' => __('Title Options', 'banca-core'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => esc_html__( 'Text Color', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .__title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title_hover_color', [
                'label' => esc_html__( 'Hover Color', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .__title:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .__title',
			]
		);

        $this->end_controls_section(); //End Style Contents


        //=== Content Options
        $this->start_controls_section(
            'contents_sec', [
                'label' => __('Content Options', 'banca-core'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'content_color', [
                'label' => esc_html__( 'Text Color', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .post-para' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'selector' => '{{WRAPPER}} .post-para',
			]
		);

        $this->end_controls_section(); //==== End Content Options


        //===================== Meta Options =========================//
         $this->start_controls_section(
            'meta_sec', [
                'label' => __('Meta', 'banca-core'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '7', ]
                  ]
            ]
        );

        // === Author Options
        $this->add_control(
			'author_option',
			[
				'label' => esc_html__( 'Author Options', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_control(
            'author_name_color', [
                'label' => esc_html__( 'Text Color', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .author_text h4' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'author_name_typo',
				'selector' => '{{WRAPPER}} .author_text h4',
			]
		); //=== End Author

        // === Meta Option
        $this->add_control(
			'meta_option',
			[
				'label' => esc_html__( 'Meta Options', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_control(
            'meta_color', [
                'label' => esc_html__( 'Text Color', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .__meta' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'meta_typo',
				'selector' => '{{WRAPPER}} .__meta',
			]
		);
        $this->end_controls_section(); //==== End Meta Options

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        $paged = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;
        $sticky = get_option( 'sticky_posts' );

        $args = [
            'post_type' => 'post',
            'post_status' => 'publish',
            'paged' => $paged,
        ];

        if ( !empty($show_count) ) {
            $args['posts_per_page'] = $show_count;
        }

        if ( !empty($order) ) {
            $args['order'] = $order;
        }

        if ( !empty($orderby) ) {
            $args['orderby'] = $orderby;
        }

        if ( !empty($exclude) ) {
            $args['post__not_in'] = $exclude;
        }

        if ( !empty($cats) ) {
            $args['tax_query'] = [
                [
                    'taxonomy' => 'category',
                    'field'    => 'id',
                    'terms'    => $cats

                ]
            ];
        }

        $posts = new \WP_Query( $args );

        //==================== Template Parts =======================//
        include "template/blog/blog-{$settings['style']}.php";

    }
}