<?php
namespace LandpagyCore\Widgets;


// Exit if accessed directly
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Call_to_Action extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_c2a';
    }

    public function get_title() {
        return __( 'Call to Action (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-call-to-action';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    public function get_script_depends() {
        return [ 'parallax-scroll' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //============================== Select Style ===============================//
        $this->start_controls_section(
            'select_style', [
                'label' => __( 'Preset Skins', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Style', 'landpagy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( 'Style 01', 'landpagy-core' ),
                    '2' => esc_html__( 'Style 02 (Parallax Shape)', 'landpagy-core' ),
                    '3' => esc_html__( 'Style 03', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section(); //End Style


        //============================== Contents ===============================//
        $this->start_controls_section(
            'contents_sec', [
                'label' => __( 'Contents', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => 'Get started now. It’s free.'
            ]
        );

        $this->add_control(
            'contents', [
                'label' => __( 'Contents', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->end_controls_section(); //End Contents


        //============================== Buttons ===============================//
        $this->start_controls_section(
            'buttons_sec', [
                'label' => __( 'Button', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'btn_label', [
                'label' => __( 'Button Label', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Get Started'
            ]
        );

        $this->add_control(
            'btn_url', [
                'label' => __( 'Button URL', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ]
            ]
        );

        $this->end_controls_section(); //End Buttons

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============================== Start Section Contents ===============================//
        $this->start_controls_section(
            'sec_contents_style', [
                'label' => __( 'Contents', 'plugin-name' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '1', '3' ]
                ]
            ]
        );

        //====== Title Options
        $this->add_control(
            'heading_options', [
                'label' => esc_html__( 'Title Options', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'title_type',
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => esc_html__( 'Title Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section(); //End Section Contents


        //============================== Shape Images ===============================//
        $this->start_controls_section(
            'shape_images_sec', [
                'label' => __( 'Shape Images', 'plugin-name' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '1', '2' ]
                ]
            ]
        );

        $this->add_control(
            'shape1', [
                'label' => __( 'Shape', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape2', [
                'label' => __( 'Shape 2', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape3', [
                'label' => __( 'Shape 3', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->end_controls_section(); //End Shape Images


        //============================= Section Background ============================== //
        $this->start_controls_section(
            'sec_bg_style', [
                'label' => __( 'Section Background', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy-c2a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy-c2a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sec_background',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .landpagy-c2a',
            ]
        );

        $this->end_controls_section(); //End Section Background


    }


    /*
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();


        //Include Templating Files
        include "template/call-to-action/c2a-{$settings['style']}.php";

    }
}