<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Clients_Logo extends Widget_Base {
    public function get_name() {
        return 'landpagy_clients_logo';
    }

    public function get_title() {
        return __( 'Client Logo', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-image-rollover';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    public function get_keywords() {
        return [ 'logo', 'brand', 'clients' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //===================== Select Preset ===========================//
        $this->start_controls_section(
            'select_preset', [
                'label' => esc_html__( 'Preset Skins', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Style', 'landpagy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( '01: Hover Image', 'landpagy-core' ),
                    '2' => esc_html__( '02: Slider Image', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section();//End Select Style


        //================================= Clients Logo 01, 02 ====================================//
        $this->start_controls_section(
            'clients_logo_sec', [
                'label' => __( 'Clients Logo', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'image', [
                'label' => __( 'Image 01', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_control(
            'image2', [
                'label' => __( 'Image 02', 'landpagy-core' ),
                'description' => __( 'This image appears on hover. If you leave this field empty, Image 01 will replace the image 02.', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_control(
            'url', [
                'label' => __( 'URL', 'landpagy-core' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ],
                'condition' => [
                    'style' => '1'
                ]
            ]
        );


        //================= Client Logos
        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'align_items', [
                'type' => \Elementor\Controls_Manager::HIDDEN,
            ]
        );

        $repeater->add_control(
            'logo', [
                'label' => esc_html__( 'Logo', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'clients_logo', [
                'label' => esc_html__( 'Add Logo', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ align_items }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '2'
                ]
            ]
        );


        $this->end_controls_section(); // End Clients Logo

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============================= Image Style ==============================//
        $this->start_controls_section(
            'style_images', [
                'label' => __( 'Images', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_control(
            'align', [
                'label' => __( 'Alignment', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => landpagy_get_el_text_alignment(),
                'default' => 'center',
                'toggle' => true,
            ]
        );

        $this->add_responsive_control(
            'width',
            [
                'label' => __( 'Width', 'elementor' ),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'unit' => '%',
                ],
                'tablet_default' => [
                    'unit' => '%',
                ],
                'mobile_default' => [
                    'unit' => '%',
                ],
                'size_units' => [ '%', 'px', 'vw' ],
                'range' => [
                    '%' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                    'vw' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} img' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'image1_opacity', [
                'label' => __( 'Image 01 Opacity', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 1,
                        'min' => 0.10,
                        'step' => 0.01,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .startup_clients_logo .img1' => 'opacity: {{SIZE}};',
                ],
            ]
        );

        $this->add_control(
            'image2_opacity', [
                'label' => __( 'Image 02 Opacity', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 1,
                        'min' => 0.10,
                        'step' => 0.01,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .startup_clients_logo .img2' => 'opacity: {{SIZE}};',
                ],
            ]
        );

        $this->add_control(
            'image_contrast', [
                'label' => __( 'Image 01 Contrast', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ '%' ],
                'range' => [
                    '%' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                ],
                'selectors' => [
                    '{{WRAPPER}} .startup_clients_logo .img1' => 'filter: contrast({{SIZE}}{{UNIT}});',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'image_contrast_hover', [
                'label' => __( 'Image 02 Contrast', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ '%' ],
                'range' => [
                    '%' => [
                        'min' => 1,
                        'max' => 500,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                ],
                'selectors' => [
                    '{{WRAPPER}} .startup_clients_logo .img2' => 'filter: brightness({{SIZE}}{{UNIT}});',
                ],
            ]
        );

        $this->add_responsive_control(
            'padding', [
                'label' => esc_html__( 'Padding', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .startup_clients_logo' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => [
                    'unit' => 'px', // The selected CSS Unit. 'px', '%', 'em',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'margin', [
                'label' => esc_html__( 'Margin', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .startup_clients_logo' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => [
                    'unit' => 'px', // The selected CSS Unit. 'px', '%', 'em',
                ],
            ]
        );

        $this->end_controls_section();


        //----------------------------------- Style Section --------------------------------------//
        $this->start_controls_section(
            'style_sec_bg', [
                'label' => __( 'Section Background', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .__landpagy_sec' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .__landpagy_sec' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'background',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .__landpagy_sec',
            ]
        );

        $this->end_controls_section();

    }


    /*
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        if ( !empty( $settings['url']['url'] ) ) {
            $this->add_link_attributes( 'button', $settings['url'] );
        }
        $this->add_render_attribute( 'button', 'class', 'startup_clients_logo' );
        $this->add_render_attribute( 'button', 'class', "justify-content-{$settings['align']}" );


        if ( !empty( $settings['style'] == '1' ) ) {
            ?>
            <a <?php echo $this->get_render_attribute_string('button') ?>>
                <?php echo !empty($settings['image']['id']) ? wp_get_attachment_image( $settings['image']['id'], 'full' ) : ''; ?>
                <?php echo empty($settings['image2']['id']) && !empty($settings['image']['id']) ? wp_get_attachment_image( $settings['image']['id'], 'full', '' ) : ''; ?>
                <?php echo !empty($settings['image2']['id']) && !empty($settings['image']['id']) ? wp_get_attachment_image( $settings['image2']['id'], 'full' ) : ''; ?>
            </a>
            <?php
        }
        elseif ( !empty( $settings['style'] == '2' ) ) {
            ?>

            <div class="product-integrations-wrapper __landpagy_sec">

                <div class="product-integrations-cards">

                    <div class="product-integrations-card-line hide-tablet">
                        <div class="product-integrations-inside-line">

                            <?php
                            if ( !empty($settings['clients_logo']) ) {
                                foreach ( $settings['clients_logo'] as $logo ) {
                                    ?>
                                    <div class="product-integrations-card-item">
                                        <div class="product-integrations-card-image">
                                            <?php echo wp_get_attachment_image($logo['logo']['id'], 'full' ) ?>
                                        </div>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                        </div>
                        <div class="product-integrations-inside-line">
                            <?php
                            if ( !empty($settings['clients_logo']) ) {
                                foreach ( $settings['clients_logo'] as $logo ) {
                                    ?>
                                    <div class="product-integrations-card-item">
                                        <div class="product-integrations-card-image">
                                            <?php echo wp_get_attachment_image($logo['logo']['id'], 'full' ) ?>
                                        </div>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                        </div>
                    </div>
                    <div class="product-integrations-card-line">
                        <div class="product-integrations-inside-line">
                            <?php
                            if ( !empty($settings['clients_logo']) ) {
                                foreach ( $settings['clients_logo'] as $logo ) {
                                    ?>
                                    <div class="product-integrations-card-item">
                                        <div class="product-integrations-card-image">
                                            <?php echo wp_get_attachment_image($logo['logo']['id'], 'full' ) ?>
                                        </div>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                        </div>
                        <div class="product-integrations-inside-line">
                            <?php
                            if ( !empty($settings['clients_logo']) ) {
                                foreach ( $settings['clients_logo'] as $logo ) {
                                    ?>
                                    <div class="product-integrations-card-item">
                                        <div class="product-integrations-card-image">
                                            <?php echo wp_get_attachment_image($logo['logo']['id'], 'full' ) ?>
                                        </div>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                        </div>
                    </div>
                    <div class="product-integrations-card-line">
                        <div class="product-integrations-inside-line">
                            <?php
                            if ( !empty($settings['clients_logo']) ) {
                                foreach ( $settings['clients_logo'] as $logo ) {
                                    ?>
                                    <div class="product-integrations-card-item">
                                        <div class="product-integrations-card-image">
                                            <?php echo wp_get_attachment_image($logo['logo']['id'], 'full' ) ?>
                                        </div>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                        </div>
                        <div class="product-integrations-inside-line">
                            <?php
                            if ( !empty($settings['clients_logo']) ) {
                                foreach ( $settings['clients_logo'] as $logo ) {
                                    ?>
                                    <div class="product-integrations-card-item">
                                        <div class="product-integrations-card-image">
                                            <?php echo wp_get_attachment_image($logo['logo']['id'], 'full' ) ?>
                                        </div>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                        </div>
                    </div>

                </div>

            </div>
            <?php
        }
    }
}