<?php
namespace LandpagyCore\Widgets;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Contact_form extends Widget_Base {

    public function get_name() {
        return 'landpagy_contact_form';
    }

    public function get_title() {
        return __( 'Contact Form', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-mail';
    }

    public function get_style_depends() {
        return [ 'nice-select' ];
    }

    public function get_script_depends() {
        return [ 'nice-select' ];
    }


    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //===================== Select Preset ===========================//
        $this->start_controls_section(
            'style_sec', [
                'label' => esc_html__( 'Preset Skins', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Hero Style', 'landpagy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( '01: Contact Form', 'landpagy-core' ),
                    '2' => esc_html__( '02: Contact Form Tabs', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section();//End Select Style


        //=========================== Contact Form ============================//
        $this->start_controls_section(
            'contact_form_sec', [
                'label' => __( 'Contact Form', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'contact_form_7', [
                'label' => __( 'Shortcode', 'landpagy-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'description' => 'Enter your shortcode',
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        //======= Contact Form 02
        $repeaters = new \Elementor\Repeater();
        $repeaters->add_control(
            'tab_title', [
                'label' => __( 'Tab Title', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => __( 'Tab Title', 'landpagy-core' ),
                'separator' => 'after',
            ]
        );

        $repeaters->add_control(
            'icon', [
                'label' => __( 'Icon Image', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
            ]
        );

        $repeaters->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => __( 'General Contact', 'landpagy-core' ),
            ]
        );

        $repeaters->add_control(
            'content', [
                'label' => __( 'Contents', 'landpagy-core' ),
                'type' => Controls_Manager::TEXTAREA,
            ]
        );

        $repeaters->add_control(
            'cf7_id', [
                'label' => __( 'Select A Form', 'landpagy-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => Landpagy_Core_Helper()->get_contact_form7(),
                'description' => 'Select your contact form 7',
            ]
        );

        $this->add_control(
            'form_tabs', [
                'label' => __( 'Tab List', 'landpagy-core' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeaters->get_controls(),
                'title_field' => '{{{ tab_title }}}',
                'condition' => [
                    'style' => '2'
                ]
            ]
        );


        $this->end_controls_section();//


    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


    }


    /*
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        $form_tabs = $this->get_settings_for_display( 'form_tabs' );
        $id_int = substr( $this->get_id_int(), 0, 1 );


        //================= Select Template ======================//
        include "template/contact-form/contact-form-{$settings['style']}.php";

    }
}