<?php
namespace LandpagyCore\Widgets;

// Exit if accessed directly
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package BancaCore\Widgets
 */
class Countdown extends \Elementor\Widget_Base {
    public function get_name() {
        return 'landpagy_countdown';
    }

    public function get_title() {
        return __( 'Countdown (Landpagy)', 'banca-core' );
    }

    public function get_icon() {
        return 'eicon-countdown';
    }

    public function get_script_depends() {
        return [ 'squareCountDownClock' ];
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //============ Section Contents ==================//
        $this->start_controls_section(
            'sec_content', [
                'label' => __( 'Contents', 'autohive-core' ),
            ]
        );

        $this->add_control(
            'title', [
                'label' => esc_html__( 'Title', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__( 'Something great is coming soon', 'textdomain' ),
            ]
        );

        $this->add_control(
            'subtitle', [
                'label' => esc_html__( 'Subtitle', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__( 'Subscribe to the newslater to stay in the latest updates.', 'textdomain' ),
            ]
        );

        $this->end_controls_section(); // End Content Section


        //============ Countdown Section ==================//
        $this->start_controls_section(
            'countdown_sec', [
                'label' => __( 'Content', 'autohive-core' ),
            ]
        );

        $this->add_control(
            'due_date', [
                'label' => esc_html__( 'Due Date', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::DATE_TIME,
                'picker_options' => array( 'm/d/Y H:i:s' )
            ]
        );

        $this->end_controls_section(); // End Countdown Section


        // ------------------------------ Featured Image ------------------------------
        $this->start_controls_section(
            'sec_featured_img', [
                'label' => __( 'Featured Image', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'fimage', [
                'label' => esc_html__( 'Featured Image', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'logo', [
                'label' => esc_html__( 'Logo', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );

        $this->end_controls_section();  // End Featured Image


        // ------------------------------ MailChimp form ------------------------------
        $this->start_controls_section(
            'form_settings', [
                'label' => __( 'Form settings', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'email_placeholder', [
                'label' => esc_html__( 'Email Placeholder', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Email Address',
            ]
        );

        $this->add_control(
            'action_url', [
                'label' => esc_html__( 'Action URL', 'landpagy-core' ),
                'description' => __( 'Enter here your MailChimp action URL. <a href="#" target="_blank"> How to </a>', 'landpagy-core' ),
                'type' => Controls_Manager::TEXTAREA,
            ]
        );

        $this->add_control(
            'submit_btn', [
                'label' => esc_html__( 'Submit Button', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Subscribe',
            ]
        );

        $this->end_controls_section(); //End Mailchimp



        //=============================== Social Links ===============================//
        $this->start_controls_section(
            'sec_social_links', [
                'label' => __( 'Social Links', 'landpagy-core' ),
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'social_icon', [
                'label' => esc_html__( 'Social Icon', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fa fa-circle',
                    'library' => 'fa-solid',
                ],
            ]
        );

        $repeater->add_control(
            'social_url', [
                'label' => esc_html__( 'Social Link', 'landpagy-core' ),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'default' => [
                    'url' => '#',
                ],
            ]
        );

        $this->add_control(
            'social_links', [
                'label' => esc_html__( 'Social Links', 'landpagy-core' ),
                'type' => Controls_Manager::REPEATER,
                'title_field' => '{{{ social_icon }}}',
                'fields' => $repeater->get_controls(),
            ]
        );

        $this->end_controls_section(); // End Social Links

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============================ Style Title =================================//
        $this->start_controls_section(
            'style_title', [
                'label' => __( 'Title', 'banca-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => __( 'Text Color', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .statistics-widget-2 .widget-content p' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .statistics-widget-1 p' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'title_typo',
                'selector' => '{{WRAPPER}} .statistics-widget-2 .widget-content p',
            ]
        );

        $this->end_controls_section(); // End title


        //============================ Counter Style =============================//
        $this->start_controls_section(
            'style_counter', [
                'label' => __( 'Counter Text', 'banca-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'counter_text_color', [
                'label' => __( 'Text Color', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .statistics-widget-2 .widget-content h1' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .statistics-widget-1 .counter' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'counter_text_typo',
                'selector' => '{{WRAPPER}} .statistics-widget-2 .widget-content h1',
            ]
        );

        $this->end_controls_section(); // End Counter Style


        //============================ Section Background =============================//
        $this->start_controls_section(
            'sec_background', [
                'label' => __( 'Background', 'banca-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .statistics-widget-2 .widget-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'after',
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .statistics-widget-2 .widget-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sec_bg',
                'label' => __( 'Background', 'banca-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .statistics-widget-2 .widget-content',
            ]
        );

        $this->end_controls_section(); // End Counter Style

    }


    /*
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); // Array to Variable Conversation
        ?>
        <section class="comming-soon-wrapper comming-soon-4 pt-100">
            <div class="bg-shapes">
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/shape11.svg" alt="Shape" />
                </div>
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/shape12.svg" alt="Shape" />
                </div>
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/shape13.svg" alt="Shape" />
                </div>
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/shape14.svg" alt="Shape" />
                </div>
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/shape15.svg" alt="Shape" />
                </div>
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/shape16.svg" alt="Shape" />
                </div>
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/shape17.svg" alt="Shape" />
                </div>
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/shape18.svg" alt="Shape" />
                </div>
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/shape19.svg" alt="Shape" />
                </div>
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/shape20.svg" alt="Shape" />
                </div>
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/star.svg" alt="Shape" />
                </div>
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/star.svg" alt="Shape" />
                </div>
                <div class="shape">
                    <img src="<?php echo LC_IMAGES ?>/coming-soon/star.svg" alt="Shape" />
                </div>
            </div>
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-8">
                        <div class="comming-soon-inner">
                            <a href="<?php echo home_url('/') ?>" class="logo">
                                <?php echo wp_get_attachment_image($settings['logo']['id'], 'full') ?>
                            </a>
                            <?php
                            if ( !empty( $title ) ) {
                                echo '<h1 class="page-title __title">'.esc_html( $title ).'</h1>';
                            }
                            if ( !empty( $subtitle ) ) {
                                echo '<p class="title-text __subtitle">'.esc_html( $subtitle ).'</p>';
                            }
                            ?>
                            <div class="comming-countdown" id="timer" data-endtime="<?php echo esc_attr(($due_date)) ?>"></div>
                            <form action="javascript:void(0)" class="form-group position-relative mailchimp" data-action-url="<?php echo esc_url($settings['action_url']); ?>" method="post">
                                <input type="email" class="memail" name="email" placeholder="<?php echo esc_attr($settings['email_placeholder']) ?>" />
                                <button type="submit" class="btn btn-red"><?php echo esc_html($settings['submit_btn']); ?></button>
                            </form>
                            <p class="mchimp-errmessage text-center mt-3" style="display: none;"></p>
                            <p class="mchimp-sucmessage text-center mt-3" style="display: none;"></p>

                            <ul class="social-list">
                                <?php
                                if ( !empty( $settings['social_links'] ) ) {
                                    foreach ( $settings['social_links'] as $social ) { ?>
                                        <li>
                                            <a <?php Landpagy_Core_Helper()->the_button($social['social_url']) ?>>
                                                <?php \Elementor\Icons_Manager::render_icon( $social['social_icon'] ); ?>
                                            </a>
                                        </li>
                                        <?php
                                    }
                                }
                                ?>
                            </ul>
                        </div>
                    </div>
                    <div class="col-lg-4">
                        <div class="right-img">
                            <?php echo wp_get_attachment_image($settings['fimage']['id'], 'full') ?>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <?php
    }

}