<?php
namespace LandpagyCore\Widgets;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Image_hover
 * @package BancaCore\Widgets
 */
class Counter extends \Elementor\Widget_Base {
	public function get_name() {
		return 'landpagy_counter';
	}

	public function get_title() {
		return __( 'Counter (Theme)', 'banca-core' );
	}

	public function get_icon() {
		return 'eicon-counter';
	}

	public function get_style_depends() {
        return [ 'slick', 'slick-theme'];
    }

    public function get_script_depends() {
		return [ 'counterup', 'waypoints', 'slick' ];
	}

	public function get_categories() {
		return [ 'landpagy-elements' ];
	}

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //========================== Counter =========================== //
        $this->start_controls_section(
            'counters_sec', [
                'label' => __( 'Counters', 'banca-core' ),
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'counter_text', [
                'label' => __( 'Counter Text', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '10,000',
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => __( 'We employ 15,000 people around the world' , 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'counters', [
                'label' => __( 'Add Counter', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
            ]
        );

        $this->end_controls_section(); // End Counter Style

	}


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============================ Style Title =================================//
        $this->start_controls_section(
            'style_title', [
                'label' => __( 'Title', 'banca-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => __( 'Text Color', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .statistics-widget-2 .widget-content p' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .statistics-widget-1 p' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'title_typo',
                'selector' => '{{WRAPPER}} .statistics-widget-2 .widget-content p',
            ]
        );

        $this->end_controls_section(); // End title


        //============================ Counter Style =============================//
        $this->start_controls_section(
            'style_counter', [
                'label' => __( 'Counter Text', 'banca-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'counter_text_color', [
                'label' => __( 'Text Color', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .statistics-widget-2 .widget-content h1' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .statistics-widget-1 .counter' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'counter_text_typo',
                'selector' => '{{WRAPPER}} .statistics-widget-2 .widget-content h1',
            ]
        );

        $this->end_controls_section(); // End Counter Style


        //============================ Section Background =============================//
        $this->start_controls_section(
            'sec_background', [
                'label' => __( 'Background', 'banca-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .statistics-widget-2 .widget-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'after',
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .statistics-widget-2 .widget-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sec_bg',
                'label' => __( 'Background', 'banca-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .statistics-widget-2 .widget-content',
            ]
        );

        $this->end_controls_section(); // End Counter Style

    }


    /*
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
	protected function render() {
		$settings = $this->get_settings_for_display();
		extract($settings); // Array to Variable Conversation

        ?>
        <div class="statistics-widget-2 wow fadeInUp">
            <div class="statistics-slider">
                <?php
                if ( !empty($settings['counters']) ) {
                    foreach ( $settings['counters'] as $counter ) {
                        ?>
                        <div class="widget-content  widget-1">
                            <h1 class="stat-counter"><?php echo esc_html($counter['counter_text']) ?></h1>
                            <p><?php echo esc_html($counter['title']) ?></p>
                        </div>
                        <?php
                    }
                }
                ?>
            </div>
        </div>
        <?php
	}

}