<?php
namespace LandpagyCore\Widgets;

use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use WP_Query;
use WP_Post;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Docs
 * @package LandpagyCore\Widgets
 */
class Docs extends Widget_Base {

	public function get_name() {
		return 'Landpagy_docs';
	}

	public function get_title() {
		return __( 'Docs (Theme)', 'landpagy-core' );
	}

	public function get_icon() {
		return 'eicon-document-file';
	}

	public function get_categories() {
		return [ 'landpagy-elements' ];
	}

    public function get_keywords() {
        return [ 'docs', 'documentation', 'knowledge base' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }

    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        // =========================== Filter Options ===========================//
        $this->start_controls_section(
            'document_filter', [
                'label' => __( 'Filter Options', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'doc', [
                'label' => __( 'Select Doc', 'docly-core' ),
                'description' => __( 'Select the Doc tab by default.', 'docly-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => Landpagy_Core_Helper()->get_the_docs(),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'ppp_sections', [
                'label'       => esc_html__( 'Sections', 'docy-core' ),
                'description' => esc_html__( 'Number of section to show', 'docy-core' ),
                'type'        => Controls_Manager::NUMBER,
                'default'     => 6
            ]
        );

        $this->add_control(
            'ppp_doc_items', [
                'label'       => esc_html__( 'Articles', 'docy-core' ),
                'description' => esc_html__( 'Number of articles to show under every sections', 'docy-core' ),
                'type'        => Controls_Manager::NUMBER,
                'default'     => 4,

            ]
        );

        $this->add_control(
            'order', [
                'label' => esc_html__( 'Order', 'landpagy-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => 'ASC',
                    'DESC' => 'DESC'
                ],
                'default' => 'ASC',
            ]
        );

        $this->end_controls_section();
        // end Document Setting Section

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {}



    /*
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
	protected function render() {
		$settings = $this->get_settings_for_display();


        /**
         * Get the parent docs with query
         */
        if ( ! empty( $settings['doc'] ) ) {
            $sections = get_children( array(
                'post_parent'    => $settings['doc'],
                'post_type'      => 'docs',
                'post_status'    => 'publish',
                'orderby'        => 'menu_order',
                'order'          => $settings['order'],
                'posts_per_page' => ! empty( $settings['ppp_sections'] ) ? $settings['ppp_sections'] : 8,
            ) );
        }
        ?>
        <section class="secondary-menu-area">
            <ul class="secondary-menu">
                <?php
                foreach ( $sections as $section ) {
                    ?>
                    <li class="dropdown">
                        <a href="<?php the_permalink($section->ID); ?>">
                            <?php echo esc_html($section->post_title) ?>
                            <i class="fas fa-angle-down"></i>
                        </a>
                        <ul class="sub-menu">
                            <?php
                            $doc_items = get_children( array(
                                'post_parent'    => $section->ID,
                                'post_type'      => 'docs',
                                'post_status'    => 'publish',
                                'orderby'        => 'menu_order',
                                'order'          => 'ASC',
                                'posts_per_page' => !empty($settings['ppp_doc_items']) ? $settings['ppp_doc_items'] : -1,
                            ));
                            foreach ( $doc_items as $doc_item ) {
                                ?>
                                <li>
                                    <a href="<?php echo get_permalink($doc_item->ID) ?>">
                                        <img class="before-icon" src="<?php echo LC_IMAGES . '/icon/menu.svg' ?>" alt="icon" />
                                        <img class="after-icon" src="<?php echo LC_IMAGES . '/icon/hover-menu.svg' ?>" alt="icon" />
                                        <?php echo esc_html($doc_item->post_title) ?>
                                    </a>
                                </li>
                                <?php
                            }
                            ?>
                        </ul>
                    </li>
                    <?php
                }
                ?>
            </ul>
        </section>
        <?php
    }
}