<?php
namespace LandpagyCore\Widgets;

use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Gallery
 * @package LandpagyCore\Widgets
 */
class Dots extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_dots';
    }

    public function get_title() {
        return __( 'Landpagy Dots', 'landpagy-core' );
    }

    public function get_icon() {
        return ' eicon-ellipsis-h';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    public function get_script_depends()
    {
        return [ 'parallax-scroll' ];
    }

    public function get_keywords() {
        return [ 'Dots', 'Circle' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        // ------------------------------  Animation Circle  ------------------------------ //
        $this->start_controls_section(
            'animation_circle_sec', [
                'label' => __( 'Shape Circle', 'landpagy-core' ),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'align_item', [
                'type' => \Elementor\Controls_Manager::HIDDEN,
            ]
        );

        $repeater->add_responsive_control(
            'size',
            [
                'label' => __( 'Size', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'width: {{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $repeater->add_group_control(
            \Elementor\Group_Control_Border::get_type(), [
                'name' => 'border_style',
                'label' => __( 'Border', 'landpagy-core' ),
                'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
            ]
        );


        $repeater->add_responsive_control(
            'border_radius', [
                'label' => __( 'Border Radius', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        //=========== Offset
        $repeater->add_control(
            'offset', [
                'label'        => __('Offset', 'landpagy-core'),
                'type'         => Controls_Manager::POPOVER_TOGGLE,
                'label_on'     => __('Custom', 'landpagy-core'),
                'label_off'    => __('None', 'landpagy-core'),
                'return_value' => 'yes',
            ]
        );

        $repeater->add_responsive_control(
            'horizontal_position', [
                'label' => __( 'Horizontal Position', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'left: {{SIZE}}{{UNIT}}; right: {{SIZE}}{{UNIT}};',
                ],
                'condition'   => [
                    'offset' => 'yes',
                ],
            ]
        );

        $repeater->add_responsive_control(
            'vertical_position', [
                'label' => __( 'Vertical Position', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'top: {{SIZE}}{{UNIT}} !important; bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition'   => [
                    'offset' => 'yes',
                ],
            ]
        ); //End Offset

        $repeater->add_responsive_control(
            'z_index', [
                'label' => __( 'Z-Index', 'landpagy-core' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'step' => 1,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'z-index: {{VALUE}};',
                ],
            ]
        );

        //Background Color
        $repeater->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'bg_color',
                'label' => __( 'Circle   Color', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'animation_circle', [
                'label' => __( 'Add Circle', 'landpagy-core' ),
                'type' => Controls_Manager::REPEATER,
                'title_field' => '{{{ align_item }}}',
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
            ]
        );

        $this->end_controls_section(); // End Animation Circle

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $animation_circle = !empty( $settings['animation_circle'] ) ? $settings['animation_circle'] : '';
        ?>
        <div class="shape_circle">
            <?php
            if ( $animation_circle ) {
                foreach ( $animation_circle as $circle ) {
                    ?>
                    <span class="shape elementor-repeater-item-<?php echo $circle['_id'] ?>"></span>
                    <?php
                }
            }
            ?>
        </div>
        <?php
    }
}