<?php
namespace LandpagyCore\Widgets;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Gallery
 * @package LandpagyCore\Widgets
 */
class Faqs extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_faqs';
    }

    public function get_title() {
        return __( 'FAQs (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-post-content';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //============================= Select Preset ==================================//
        $this->start_controls_section(
            'style_sec', [
                'label' => esc_html__( 'Preset Skins', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Style', 'landpagy-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( '01: Horizontal Tabs', 'landpagy-core' ),
                    '2' => esc_html__( '02: Vertical Tabs', 'landpagy-core' ),
                    '3' => esc_html__( '03: Vertical Tabs', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section();//End Select Style


        //================================ Section Title ============================//
        $this->start_controls_section(
            'sec_title', [
                'label' => __( 'Title', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'title', [
                'label' => esc_html__( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'FAQ topics'
            ]
        );

        $this->end_controls_section(); //End Section


        //================================ Query Filter ============================//
        $this->start_controls_section(
            'portfolio_filter', [
                'label' => __( 'Filter', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'cats', [
                'label' => esc_html__( 'Categories', 'landpagy-core' ),
                'description' => esc_html__( 'Display portfolios by categories', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'options' => Landpagy_Core_Helper()->get_the_categories('faq_cat'),
                'label_block' => true,
                'multiple' => true,
            ]
        );

        $this->add_control(
            'show_count', [
                'label' => esc_html__( 'Show count', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 9
            ]
        );

        $this->add_control(
            'order', [
                'label' => esc_html__( 'Order', 'landpagy-core' ),
                'description' => esc_html__( '‘ASC‘ – ascending order from lowest to highest values (1, 2, 3; a, b, c). ‘DESC‘ – descending order from highest to lowest values (3, 2, 1; c, b, a).', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'ASC' => 'ASC',
                    'DESC' => 'DESC'
                ],
                'default' => 'ASC'
            ]
        );

        $this->add_control(
            'orderby', [
                'label' => esc_html__( 'Order By', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'none' => 'None',
                    'ID' => 'ID',
                    'author' => 'Author',
                    'title' => 'Title',
                    'name' => 'Name (by post slug)',
                    'date' => 'Date',
                    'rand' => 'Random',
                    'comment_count' => 'Comment Count',
                ],
                'default' => 'none'
            ]
        );

        $this->add_control(
            'exclude', [
                'label' => esc_html__( 'Exclude FAQs', 'landpagy-core' ),
                'description' => esc_html__( 'Enter the faqs post ID to hide. Input the multiple ID with comma separated', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
            ]
        );

        $this->end_controls_section(); //End Query filter

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        $cats = get_terms(array(
            'taxonomy' => 'faq_cat',
            'hide_empty' => true
        ));

        //==== Include Template Parts
        include "template/faqs/faq-{$settings['style']}.php";

    }
}