<?php
namespace LandpagyCore\Widgets;

// Exit if accessed directly
use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Gallery
 * @package LandpagyCore\Widgets
 */
class Featured_video extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_featured_video';
    }

    public function get_title() {
        return __( 'Featured Video', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-video-camera';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    public function get_style_depends() {
        return [ 'fancybox' ];
    }

    public function get_script_depends() {
        return [ 'fancybox' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //===================== Select Preset ===========================//
        $this->start_controls_section(
            'style_sec', [
                'label' => esc_html__( 'Preset Skins', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Style', 'landpagy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( '01: Video', 'landpagy-core' ),
                    '2' => esc_html__( '02: Video with Poster Image', 'landpagy-core' ),
                    '3' => esc_html__( '03: Video with Poster Image', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section();//End Select Style


        //=========================== Featured Video ============================//
        $this->start_controls_section(
            'featured_video_sec', [
                'label' => __( 'Featured Video', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'poster_image', [
                'label' => __( 'Poster Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '2', '3' ]
                ]
            ]
        );

        $this->add_control(
            'video_url', [
                'label' => __( 'Video URL', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => '#'
            ]
        );


        $this->add_responsive_control(
            'alignment', [
                'label' => __( 'Alignment', 'elementor' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => landpagy_get_el_text_alignment(),
                'selectors' => [
                    '{{WRAPPER}} .landpagy-single-video' => 'text-align: {{VALUE}};',
                ],
                'default' => 'left',
                'separator' => 'before',
            ]
        );


        $this->end_controls_section(); //End Featured Video

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {

        //======================== Video Icon ========================//
        $this->start_controls_section(
            'style_video_icon', [
                'label' => esc_html__( 'Video Icon', 'plugin-name' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => esc_html__( 'Title Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .landpagy-single-video .play-btn i' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(), [
                'name' => 'background',
                'label' => esc_html__( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .landpagy-single-video .play-btn',
                'fields_options' => [
                    'background' => [
                        'default' => 'classic',
                    ],
                ],
            ]
        );

        $this->end_controls_section(); //End Video Icon

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings);

        //==== Template File's
        include "template/video/video-{$settings['style']}.php";

    }
}