<?php
namespace LandpagyCore\Widgets;

use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Gallery
 * @package LandpagyCore\Widgets
 */
class Features extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_features';
    }

    public function get_title() {
        return __( 'Features (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-featured-image';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    public function get_script_depends() {
        return [ 'parallax-scroll' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //============================= Select Style ===============================//
        $this->start_controls_section(
            'style_sec', [
                'label' => esc_html__( 'Preset Skins', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Style', 'landpagy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( '01: Features', 'landpagy-core' ),
                    '2' => esc_html__( '02: Features', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section(); //End Style


        //============================ Features Content =====================================//
        $this->start_controls_section(
            'features_content', [
                'label' => __( 'Features Content', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Discover important insights on your dashboard',
            ]
        );

        $this->add_control(
            'contents', [
                'label' => __( 'Contents', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $this->end_controls_section(); //Features Content


        //============================ Featured Image =====================================//
        $this->start_controls_section(
            'features_images', [
                'label' => __( 'Featured Images', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'fimage', [
                'label' => __( 'Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape1', [
                'label' => __( 'Shape 1', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_control(
            'shape2', [
                'label' => __( 'Shape 2', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->end_controls_section(); //Features Content

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


            // =================== Banner Content Style =============== //
                $this->start_controls_section(
                'content_section-1',
                [
                    'label' => esc_html__( 'Contents', 'textdomain' ),
                    'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                ]
            );
    
    
            $this->add_control(
                'title_color-1',
                [
                    'label' => esc_html__( 'Text Color', 'textdomain' ),
                    'type' => \Elementor\Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .section-title-left h2' => 'color: {{VALUE}}',
                    ],
                ]
            );
    
            $this->add_group_control(
                \Elementor\Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'selector' => '{{WRAPPER}} .section-title-left h2',
                ]
            );

            $this->end_controls_section();

            $this->start_controls_section(
                'content_section-2',
                [
                    'label' => esc_html__( 'Text', 'textdomain' ),
                    'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                ]
            );
    
    
            $this->add_control(
                'title_color-2',
                [
                    'label' => esc_html__( 'Text Color', 'textdomain' ),
                    'type' => \Elementor\Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .section-title-left p' => 'color: {{VALUE}}',
                    ],
                ]
            );
    
            $this->add_group_control(
                \Elementor\Group_Control_Typography::get_type(),
                [
                    'name' => 'text_typography',
                    'selector' => '{{WRAPPER}} .section-title-left p',
                ]
            );
            
    
            $this->end_controls_section(); // ===== End banner content style =========//



        // ------------------------------  Animation Circle  ------------------------------ //
        $this->start_controls_section(
            'obj_images_sec', [
                'label' => __( 'Object Images', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '1', '2' ]
                ]
            ]
        );

        $floating_obj = new \Elementor\Repeater();
        $floating_obj->add_control(
            'align_item', [
                'type' => \Elementor\Controls_Manager::HIDDEN,
            ]
        );

        $floating_obj->add_control(
            'obj_img', [
                'label' => __( 'Size', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $floating_obj->add_responsive_control(
            'horizontal_num', [
                'label' => __( 'Horizontal Number', 'landpagy-core' ),
                'type' => Controls_Manager::NUMBER,
                'min' => -100,
                'max' => 100,
                'default' => 500,
                'separator' => 'before'
            ]
        );

        $floating_obj->add_responsive_control(
            'vertical_num', [
                'label' => __( 'Vertical Number', 'landpagy-core' ),
                'type' => Controls_Manager::NUMBER,
                'min' => -100,
                'max' => 100,
                'default' => 20,
            ]
        );

        $floating_obj->add_responsive_control(
            'rotate_num', [
                'label' => __( 'Rotate Number', 'landpagy-core' ),
                'type' => Controls_Manager::NUMBER,
                'min' => -1000,
                'max' => 1000,
                'default' => 500,
            ]
        );

        $this->add_control(
            'floating_objs', [
                'label' => __( 'Add Object Image', 'landpagy-core' ),
                'type' => Controls_Manager::REPEATER,
                'title_field' => '{{{ align_item }}}',
                'fields' => $floating_obj->get_controls(),
                'prevent_empty' => false,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );


        $this->add_control(
            'obj1', [
                'label' => __( 'Object', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->add_control(
            'obj2', [
                'label' => __( 'Object 2', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->add_control(
            'obj3', [
                'label' => __( 'Object 3', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->add_control(
            'obj4', [
                'label' => __( 'Object 4', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->end_controls_section(); //End Features


        //============================= Section Background ============================== //
        $this->start_controls_section(
            'sec_bg_style', [
                'label' => __( 'Section Background', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy-features' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy-features' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sec_background',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .landpagy-features',
            ]
        );

        $this->end_controls_section(); //End Section Background

    }


    /**
     * Name: elementor_render()
     * Desc: Render the widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to Variable conversation


        // Template part
        include "template/features/feature-{$settings['style']}.php";

    }
}