<?php
namespace LandpagyCore\Widgets;

use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class Heading extends Widget_Base {

    public function get_name() {
        return 'landpagy_heading';
    }

    public function get_title() {
        return __( 'Heading (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-t-letter';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }

    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        $this->start_controls_section(
            'section_title', [
                'label' => __( 'Title', 'landpagy-core' ),
            ]
        );

        // Heading Style
        $this->add_control(
            'style', [
                'label' => __( 'Heading Style', 'landpagy-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => __( 'Default', 'landpagy-core' ),
                    '2' => __( 'Highlighted', 'landpagy-core' ),
                ],
                'default' => '1',
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'description' => __( 'Highlighted text must be write in { }. Example : Welcome to { Our Website }', 'landpagy-core'),
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => __( 'Enter your title', 'landpagy-core' ),
                'default' => __( 'Add Your Heading Text Here', 'landpagy-core' ),
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        // ============== Highlighted Title
        $this->add_control(
            'before_title', [
                'label' => __( 'Before Text', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => __( 'Enter your title', 'landpagy-core' ),
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->add_control(
            'highlighted_title', [
                'label' => __( 'Highlighted Text', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->add_control(
            'is_highlighted_image', [
                'label' => esc_html__( 'Show Image', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'your-plugin' ),
                'label_off' => esc_html__( 'Hide', 'your-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'highlighted_img', [
                'label' => __( 'Highlighted Image', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
                'condition' => [
                    'is_highlighted_image' => 'yes'
                ],
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'after_title', [
                'label' => __( 'After Text', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => __( 'Enter your title', 'landpagy-core' ),
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->add_control(
            'link', [
                'label' => __( 'Link', 'landpagy-core' ),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => [
                    'url' => '',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'size', [
                'label' => __( 'Size', 'landpagy-core' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'default',
                'options' => [
                    'default' => __( 'Default', 'landpagy-core' ),
                    'small' => __( 'Small', 'landpagy-core' ),
                    'medium' => __( 'Medium', 'landpagy-core' ),
                    'large' => __( 'Large', 'landpagy-core' ),
                    'xl' => __( 'XL', 'landpagy-core' ),
                    'xxl' => __( 'XXL', 'landpagy-core' ),
                ],
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_control(
            'header_size', [
                'label' => __( 'HTML Tag', 'landpagy-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                    'div' => 'div',
                    'span' => 'span',
                    'p' => 'p',
                ],
                'default' => 'h2',
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_responsive_control(
            'align', [
                'label' => __( 'Alignment', 'landpagy-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'landpagy-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'landpagy-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'landpagy-core' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'justify' => [
                        'title' => __( 'Justified', 'landpagy-core' ),
                        'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'view', [
                'label' => __( 'View', 'landpagy-core' ),
                'type' => Controls_Manager::HIDDEN,
                'default' => 'traditional',
            ]
        );

        $this->end_controls_section();

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {

        // ========================== Title Style =========================== //
        $this->start_controls_section(
            'section_title_style', [
                'label' => __( 'Title', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'global' => [
                    'default' => Global_Colors::COLOR_PRIMARY,
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-heading-title' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .highlighted-text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'typography',
                'selector' => '
                    {{WRAPPER}} .elementor-heading-title,
                    {{WRAPPER}} .highlighted-text
                ',
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'text_shadow',
                'selector' => '
                    {{WRAPPER}} .elementor-heading-title,
                    {{WRAPPER}} .highlighted-text
                    ',
            ]
        );

        $this->add_control(
            'blend_mode', [
                'label' => __( 'Blend Mode', 'landpagy-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '' => __( 'Normal', 'landpagy-core' ),
                    'multiply' => 'Multiply',
                    'screen' => 'Screen',
                    'overlay' => 'Overlay',
                    'darken' => 'Darken',
                    'lighten' => 'Lighten',
                    'color-dodge' => 'Color Dodge',
                    'saturation' => 'Saturation',
                    'color' => 'Color',
                    'difference' => 'Difference',
                    'exclusion' => 'Exclusion',
                    'hue' => 'Hue',
                    'luminosity' => 'Luminosity',
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-heading-title' => 'mix-blend-mode: {{VALUE}}',
                    '{{WRAPPER}} .highlighted-text' => 'mix-blend-mode: {{VALUE}}',
                ],
                'separator' => 'none',
            ]
        );

        $this->end_controls_section(); // End Title Style


        //================================ Title Highlighted Colors ============================//
        $this->start_controls_section(
            'section_highlighted_style', [
                'label' => __( 'Highlighted', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'highlighted_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-heading-title span' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'highlighted_typo',
                'selector' => '{{WRAPPER}} .elementor-heading-title span',
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_control(
            'highlighted_bg_color', [
                'label' => __( 'Background Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-heading-title span::before' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_responsive_control(
            'highlighted_width', [
                'label' => __( 'Width', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-heading-title span::before' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .highlighted-text span .border-shape' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .highlighted-text span svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'highlighted_height', [
                'label' => __( 'Height', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-heading-title span' => 'line-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'margin', [
                'label' => esc_html__( 'Margin', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .highlighted-text span svg' => 'top: {{TOP}}{{UNIT}}; right: {{RIGHT}}{{UNIT}}, bottom: {{BOTTOM}}{{UNIT}}, left:{{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_responsive_control(
            'highlighted_hr_position', [
                'label' => __( 'Position Horizontal', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .highlighted-text span .border-shape' => 'left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .highlighted-text span svg' => 'left: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->add_responsive_control(
            'highlighted_vr_position', [
                'label' => __( 'Position Vertical', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .highlighted-text span .border-shape' => 'top: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .highlighted-text span svg' => 'top: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->end_controls_section(); //End Title Highlighted Colors

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();

        if ( '' === $settings['title'] ) {
            return;
        }

        $this->add_render_attribute( 'title', 'class', 'elementor-heading-title' );

        if ( ! empty( $settings['size'] ) ) {
            $this->add_render_attribute( 'title', 'class', 'elementor-size-' . $settings['size'] );
        }

        $this->add_inline_editing_attributes( 'title' );

        $title = $settings['title'];

        if ( ! empty( $settings['link']['url'] ) ) {
            $this->add_link_attributes( 'url', $settings['link'] );

            $title = sprintf( '<a %1$s>%2$s</a>', $this->get_render_attribute_string( 'url' ), $title );
        }

        if ( !empty( $settings['style'] == '1' ) ) {
            $title_html = sprintf( '<%1$s %2$s>%3$s</%1$s>', Utils::validate_html_tag( $settings['header_size'] ), $this->get_render_attribute_string( 'title' ), $title );
            echo Landpagy_Core_Helper()->kses_post(str_replace(['{', '}'], ['<span>', '</span>'], $title_html));
        }
        if ( !empty( $settings['style'] == '2' ) ) {
            ?>
            <h2 class="highlighted-text">
                <?php echo esc_html($settings['before_title']) ?>
                <span>
                    <?php echo esc_html($settings['highlighted_title']) ?>
                    <?php
                    if ( !empty( ($settings['is_highlighted_image'] == 'yes') && ($settings['highlighted_img']['id'])) ) {
                        echo wp_get_attachment_image($settings['highlighted_img']['id'], 'full', '', array( 'class' => 'border-shape' ));
                    } else { ?>
                        <svg width="208" height="73" viewBox="0 0 208 73" fill="none" xmlns="http://www.w3.org/2000/svg">
                            <path class="draw animatedes" d="M14.3309 16.756C98.2165 -21.285 245.261 19.7412 198.052 52.0475C160.938 77.4454 -7.37435 84.8951 1.70571 36.333C7.21908 6.84625 151.264 -5.33622 192.932 31.8679" stroke="#EFBA34"></path>
                        </svg>
                        <?php
                    }
                    ?>
                </span>
                <?php echo esc_html($settings['after_title']) ?>
            </h2>
            <?php
        }

    }

}
