<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Hero extends Widget_Base {

    public function get_name() {
        return 'landpagy_hero';
    }

    public function get_title() {
        return __( 'Hero Section', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-device-desktop';
    }

    public function get_script_depends() {
        return [ 'ajax-chimp', 'parallax', 'parallax-scroll' ];
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //===================== Select Preset ===========================//
        $this->start_controls_section(
            'style_sec', [
                'label' => esc_html__( 'Preset Skins', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Hero Style', 'landpagy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( '01: Project Management', 'landpagy-core' ),
                    '2' => esc_html__( '02: Software Demo Landing', 'landpagy-core' ),
                    '3' => esc_html__( '03: Software Company', 'landpagy-core' ),
                    '4' => esc_html__( '04: Payment Processing', 'landpagy-core' ),
                    '5' => esc_html__( '05: Account Billing Software', 'landpagy-core' ),
                    '6' => esc_html__( '06: Cloud Saas', 'landpagy-core' ),
                    '7' => esc_html__( '07: Mobile App Landing', 'landpagy-core' ),
                    '8' => esc_html__( '08: POS Software', 'landpagy-core' ),
                    '9' => esc_html__( '09: HRM Software', 'landpagy-core' ),
                    '10' => esc_html__( '10: Prototype', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section();//End Select Style


        // ------------------------------ Hero Content  ------------------------------ //
        $this->start_controls_section(
            'hero_content', [
                'label' => __( 'Hero Content', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'title', [
                'label' => esc_html__( 'Title', 'landpagy-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => 'All you need for your business'
            ]
        );

        $this->add_control(
            'underline_img', [
                'label' => esc_html__( 'Highlighted Underline Image', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '7'
                ]
            ]
        );

        $this->add_control(
            'subtitle', [
                'label' => esc_html__( 'Subtitle', 'landpagy-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'separator' => 'before',
                'condition' => [
                    'style!' => '5'
                ]
            ]
        );

        $this->end_controls_section(); // End Hero Content


        //============================= Featured Images ============================== //
        $this->start_controls_section(
            'featured_images', [
                'label' => __( 'Featured Images', 'landpagy-core' ),
                'condition' => [
                    'style!' => '10'
                ]
            ]
        );

        $this->add_control(
            'fimage', [
                'label' => __( 'Featured Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'fimage2', [
                'label' => __( 'Image 2', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '4', '7', '8' ],
                    'style!' => [ '3', '5', '9' ]
                ]
            ]
        );

        $this->add_control(
            'fimage3', [
                'label' => __( 'Image 3', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '4', '8' ],
                    'style!' => [ '3', '5', '9' ]
                ]
            ]
        );

        $this->add_control(
            'f_video_url', [
                'label' => __( 'Video URL', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->end_controls_section(); // End Featured Images


        //=========================== MailChimp form =================================//
        $this->start_controls_section(
            'form_settings', [
                'label' => __( 'Form settings', 'landpagy-core' ),
                'condition'     => [
                    'style'     =>  [ '1', '4', '8', '9', '10' ]
                ]
            ]
        );

        $this->add_control(
            'email_placeholder', [
                'label' => esc_html__( 'Email Placeholder', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Email Address',
            ]
        );

        $this->add_control(
            'action_url', [
                'label' => esc_html__( 'Action URL', 'landpagy-core' ),
                'description' => __( 'Enter here your MailChimp action URL. <a href="#" target="_blank"> How to </a>', 'landpagy-core' ),
                'type' => Controls_Manager::TEXTAREA,
            ]
        );

        $this->add_control(
            'submit_btn', [
                'label' => esc_html__( 'Submit Button', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Book A Demo',
            ]
        );

        $this->add_control(
            'form_content', [
                'label' => esc_html__( 'Contents', 'landpagy-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'condition' => [
                    'style' => [ '1', '4', '9' ],
                    'style!' => [ '8', '10' ]
                ],
            ]
        );

        //============= Style 08
        $bottom_content = new \Elementor\Repeater();
        $bottom_content->add_control(
            'list_item', [
                'label' => esc_html__( 'Contents', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'List Title' , 'plugin-name' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'bottom_contents', [
                'label' => esc_html__( 'Add Item', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $bottom_content->get_controls(),
                'title_field' => '{{{ list_item }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '8'
                ]
            ]
        );


        $this->end_controls_section(); //End Mailchimp Form


        //=================================== Buttons =====================================//
        $this->start_controls_section(
            'buttons_sec', [
                'label' => __( 'Buttons', 'landpagy-core' ),
                'condition' => [
                    'style' =>  [ '2', '3', '5', '6', '7' ]
                ]
            ]
        );

        //==== Repeater Button
        $button = new \Elementor\Repeater();
        $button->add_control(
            'btn_label', [
                'label' => esc_html__( 'Button Label', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Get Started',
            ]
        );

        $button->add_control(
            'btn_url', [
                'label' => esc_html__( 'Button URL', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ]
            ]
        );

        $button->add_control(
            'btn_icon', [
                'label' => esc_html__( 'Icon', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );

        // Button Style
        $button->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
            ]
        );

        $button->start_controls_tabs(
            'style_btn_tabs'
        );

        // Normal Tab
        $button->start_controls_tab(
            'btn_normal_tab', [
                'label' => esc_html__( 'Normal', 'plugin-name' ),
            ]
        );

        $button->add_control(
            'btn_normal_text_color', [
                'label' => esc_html__( 'Text Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'color: {{VALUE}}',
                ],
            ]
        );

        $button->add_control(
            'btn_normal_bg_color', [
                'label' => esc_html__( 'Background Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $button->add_control(
            'btn_normal_border_color', [
                'label' => esc_html__( 'Border Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $button->end_controls_tab();

        // Hover Tab
        $button->start_controls_tab(
            'btn_hover_tab', [
                'label' => esc_html__( 'Hover', 'plugin-name' ),
            ]
        );

        $button->add_control(
            'btn_hover_text_color', [
                'label' => esc_html__( 'Text Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $button->add_control(
            'btn_hover_bg_color', [
                'label' => esc_html__( 'Background Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $button->add_control(
            'btn_hover_border_color', [
                'label' => esc_html__( 'Border Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}:hover' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $button->end_controls_tab();

        $button->end_controls_tabs(); //End Button Style Tabs

        $this->add_control(
            'buttons', [
                'label' => esc_html__( 'Create Button', 'landpagy-core' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $button->get_controls(),
                'title_field' => '{{{ btn_label }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style!'  => '5'
                ],
            ]
        ); //End Repeater Button

        $this->add_control(
            'btn_title', [
                'label' => esc_html__( 'Button Title', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Sign up and get 10 GB for free, forever!',
                'label_block' => true,
                'condition' => [
                    'style'  => [ '5', '6' ],
                    'style!'  => '7',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'btn_url', [
                'label' => esc_html__( 'Button URL', 'landpagy-core' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ],
                'condition' => [
                    'style'  => '5'
                ],
            ]
        );

        $this->add_control(
            'btn_icon', [
                'label' => esc_html__( 'Icon', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'separator' => 'before',
                'condition' => [
                    'style'  => '5'
                ],
            ]
        );

        $this->add_control(
            'btn_contents', [
                'label' => esc_html__( 'Button Content', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'No billing information required',
                'condition' => [
                    'style'  => '6'
                ],
            ]
        );

        $this->end_controls_section(); //End Buttons

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============================= Hero Contents Style ============================== //
        $this->start_controls_section(
            'hero_content_style', [
                'label' => __( 'Hero Contents', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        // Title Options
        $this->add_control(
            'title_options', [
                'label' => esc_html__( 'Title Options', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'title_typo',
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => esc_html__( 'Text Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}}',
                ],
            ]
        );


        // Sub-Title Options
        $this->add_control(
            'subtitle_options', [
                'label' => esc_html__( 'Subtitle Options', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'style!' => '5'
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'subtitle_typo',
                'selector' => '{{WRAPPER}} .subtitle',
                'condition' => [
                    'style!' => '5'
                ]
            ]
        );

        $this->add_control(
            'subtitle_color', [
                'label' => esc_html__( 'Text Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .subtitle' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'style!' => '5'
                ]
            ]
        );

        $this->end_controls_section(); // End Hero Contents


        //============================= Form Settings ============================== //
        $this->start_controls_section(
            'form_settings_style', [
                'label' => __( 'Form Settings', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '4', '9' ]
                ]
            ]
        );

        // Title Options
        $this->add_control(
            'form_bottom_content_options', [
                'label' => esc_html__( 'Bottom Content Options', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'form_bottom_content_typo',
                'selector' => '{{WRAPPER}} .sub-content',
            ]
        );

        $this->add_control(
            'form_bottom_content_color', [
                'label' => esc_html__( 'Text Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sub-content' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section(); //Form Settings


        //============================= Floating Object ============================== //
        $this->start_controls_section(
            'floating_obj_images', [
                'label' => __( 'Floating Object', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '1', '3', '4', '5', '9' ],
                ]
            ]
        );

        $this->add_control(
            'obj1', [
                'label' => __( 'Object 1', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '1', '3', '4', '5', '9' ],
                ]
            ]
        );

        $this->add_control(
            'obj2', [
                'label' => __( 'Object 2', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '1', '3', '4', '5', '9' ],
                ]
            ]
        );

        $this->add_control(
            'obj3', [
                'label' => __( 'Object 3', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '1', '3', '4', '5', '9' ]
                ]
            ]
        );

        $this->add_control(
            'obj4', [
                'label' => __( 'Object 4', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '1', '3', '4', '5', '9' ]
                ]
            ]
        );

        $this->add_control(
            'obj5', [
                'label' => __( 'Object 5', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '1', '3', '4', '5', '9' ]
                ]
            ]
        );

        $this->add_control(
            'obj6', [
                'label' => __( 'Object 6', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '4', '5', '9' ],
                    'style!' =>  '3'
                ]
            ]
        );

        $this->add_control(
            'obj7', [
                'label' => __( 'Object 7', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '4', '5', '9' ],
                    'style!' =>  '3'
                ]
            ]
        );

        $this->add_control(
            'obj8', [
                'label' => __( 'Object 8', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '5', '9' ]
                ]
            ]
        );

        $this->add_control(
            'obj9', [
                'label' => __( 'Object 9', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '5', '9' ]
                ]
            ]
        );

        $this->add_control(
            'obj10', [
                'label' => __( 'Object 10', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '5', '9' ]
                ]
            ]
        );

        $this->add_control(
            'obj11', [
                'label' => __( 'Object 11', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '5'
                ]
            ]
        );

        $this->end_controls_section(); //End Object Images



        //=================================== Shape Images =====================================//
        $this->start_controls_section(
            'shape_images_sec', [
                'label' => __( 'Shape Images', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' =>  [ '2', '4', '6', '7', '8', '9', '10' ]
                ]
            ]
        );


        $this->add_control(
            'shape1', [
                'label' => __( 'Shape', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '2', '4', '7', '8', '9', '10' ]
                ]
            ]
        );

        $this->add_control(
            'shape2', [
                'label' => __( 'Shape 2', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '2', '4', '7', '8', '9', '10' ]
                ]
            ]
        );

        $this->add_control(
            'shape3', [
                'label' => __( 'Shape 3', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '4', '8', '9', '10' ]
                ]
            ]
        );

        $this->add_control(
            'shape4', [
                'label' => __( 'Shape 4', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '4', '8', '9', '10' ],
                    'style!' => '7'
                ]
            ]
        );

        $this->add_control(
            'shape5', [
                'label' => __( 'Shape 5', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '8', '9', '10' ],
                    'style!' => '7'
                ]
            ]
        );

        $this->add_control(
            'shape6', [
                'label' => __( 'Shape 6', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '10'
                ]
            ]
        );

        $this->add_control(
            'shape7', [
                'label' => __( 'Shape 7', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '10'
                ]
            ]
        );

        $this->add_control(
            'shape8', [
                'label' => __( 'Shape 8', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '10'
                ]
            ]
        );

        $this->add_control(
            'shape9', [
                'label' => __( 'Shape 9', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '10'
                ]
            ]
        );

        $this->add_control(
            'shape10', [
                'label' => __( 'Shape 10', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '10'
                ]
            ]
        );

        //=============== Style 06
        $shape = new \Elementor\Repeater();
        $shape->add_control(
            'align_items', [
                'type' => \Elementor\Controls_Manager::HIDDEN,
            ]
        );

        $shape->add_control(
            'shape', [
                'label' => esc_html__( 'Shape', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape_images', [
                'label' => esc_html__( 'Shape Images', 'landpagy-core' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $shape->get_controls(),
                'title_field' => '{{{ align_items }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '6'
                ]
            ]
        );

        $this->end_controls_section(); //End Shape Images



        //============================= Section Background ============================== //
        $this->start_controls_section(
            'sec_bg_style', [
                'label' => __( 'Section Background', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy-hero' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy-hero' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sec_background',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .landpagy-hero',
            ]
        );

        $this->end_controls_section(); //End Section Background

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

	    include( "template/hero/hero-{$settings['style']}.php" );

    }
}