<?php
namespace LandpagyCore\Widgets;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Highlight_Boxes extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_highlight_boxes';
    }

    public function get_title() {
        return __( 'Highlight Boxes', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-flip-box';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    public function get_keywords() {
        return [ 'highlight', 'boxes', 'flip', 'box' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //============================ Section Title =============================//
        $this->start_controls_section(
            'sec_title', [
                'label' => __( 'Highlight Boxes', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Our Culture'
            ]
        );

        $this->end_controls_section(); //End Section Title


        //============================ Highlight Boxes =============================//
        $this->start_controls_section(
            'highlight_boxes_sec', [
                'label' => __( 'Highlight Boxes', 'plugin-name' ),
            ]
        );

        $box_1 = new \Elementor\Repeater();
        $box_1->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Socially Responsible'
            ]
        );

        $box_1->add_control(
            'content', [
                'label' => __( 'Content', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $box_1->add_control(
            'btn_title', [
                'label' => __( 'Button Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Learn how'
            ]
        );

        $box_1->add_control(
            'btn_url', [
                'label' => __( 'Button URL', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'default' => [
                    'url' => '#'
                ]
            ]
        );

        $this->add_control(
            'highlight_boxes', [
                'label' => __( 'Add Box', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $box_1->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false
            ]
        );

        $this->end_controls_section(); //End Integrations

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        ?>
        <section class="culture-area">

            <div class="container">
                <?php if (!empty($settings['title'])) : ?>
                    <div class="row">
                        <div class="col-lg-5">
                            <div class="section-title-left">
                                <h2><?php echo esc_html($settings['title']) ?></h2>
                            </div>
                        </div>
                    </div>
                <?php endif; ?>
                <div class="row">
                    <div class="col-lg-12">
                        <div class="culture-right">
                            <?php
                            if ( !empty($settings['highlight_boxes']) ) {
                                foreach ( $settings['highlight_boxes'] as $index => $box ) {
                                    if ( !($index % 2)) {
                                        continue;
                                    }
                                    ?>
                                    <div class="culture-item">
                                        <?php
                                        if ( !empty($box['title']) ) { ?>
                                            <h5 class="item-title"><?php echo esc_html($box['title']) ?></h5>
                                            <?php
                                        }
                                        if ( !empty($box['content']) ) { ?>
                                            <h4 class="item-text"><?php echo esc_html($box['content']) ?></h4>
                                            <?php
                                        }
                                        if ( !empty($box['btn_title']) && function_exists('landpagy_kses_post') ) { ?>
                                            <a  <?php landpagy_Core_Helper()->the_button($box['btn_url']) ?> class="item-link">
                                                <?php echo landpagy_kses_post(nl2br($box['btn_title'])) ?>
                                            </a>
                                            <?php
                                        }
                                        ?>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                        </div>
                        <div class="culture-left">
                            <?php
                            if ( !empty($settings['highlight_boxes']) ) {
                                foreach ( $settings['highlight_boxes'] as $index => $box ) {
                                    if ( ($index % 2) ) {
                                        continue;
                                    }
                                    ?>
                                    <div class="culture-item">
                                        <?php
                                        if ( !empty($box['title']) ) { ?>
                                            <h5 class="item-title"><?php echo esc_html($box['title']) ?></h5>
                                            <?php
                                        }
                                        if ( !empty($box['content']) ) { ?>
                                            <h4 class="item-text"><?php echo esc_html($box['content']) ?></h4>
                                            <?php
                                        }
                                        if ( !empty($box['btn_title']) && function_exists('landpagy_kses_post') ) { ?>
                                            <a <?php landpagy_Core_Helper()->the_button($box['btn_url']) ?> class="item-link">
                                                <?php echo landpagy_kses_post(nl2br($box['btn_title'])) ?>
                                            </a>
                                            <?php
                                        }
                                        ?>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <?php
    }
}