<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Gallery
 * @package LandpagyCore\Widgets
 */
class Illustrations extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_illustrations';
    }

    public function get_title() {
        return __( 'Illustrations', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-photo-library';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    public function get_keywords() {
        return [ 'Image', 'Parallax Image', 'Animated Image', 'Illustrations' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }

    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //================================== Select Style ============================= //
        $this->start_controls_section(
            'select_style', [
                'label' => __( 'Style', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'style', [
                'label' => __( 'Style', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '1'  => __( 'Style 01', 'landpagy-core' ),
                    '2' => __( 'Style 02', 'landpagy-core' ),
                    '3' => __( 'Style 03', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section();


        // ------------------------------  Illustrations Images  ------------------------------ //
        $this->start_controls_section(
            'illustrations_sec', [
                'label' => __( 'Illustrations', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'fimage', [
                'label'        => __('Featured Image', 'landpagy-core'),
                'type'         => Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'obj1', [
                'label'        => __('Object 01', 'landpagy-core'),
                'type'         => Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'obj2', [
                'label'        => __('Object 02', 'landpagy-core'),
                'type'         => Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'obj3', [
                'label'        => __('Object 03', 'landpagy-core'),
                'type'         => Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'obj4', [
                'label'        => __('Object 04', 'landpagy-core'),
                'type'         => Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'obj5', [
                'label'        => __('Object 05', 'landpagy-core'),
                'type'         => Controls_Manager::MEDIA,
                'condition'    => [
                    'style' => [ '1', '3' ]
                ]
            ]
        );

        $this->add_control(
            'alignment', [
                'label' => __( 'Alignment', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => __( 'Left', 'landpagy-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'landpagy-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'flex-end' => [
                        'title' => __( 'Right', 'landpagy-core' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy-illustration' => 'display: flex; justify-content: {{VALUE}};',
                ],
                'default' => 'center',
                'separator' => 'before'
            ]
        );



        $this->end_controls_section(); // End Illustrations Images

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); // extract settings data

        // Include Style
        include "template/illustrations/illustration-{$settings['style']}.php";

    }
}