<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class Image_Box extends Widget_Base {

    public function get_name() {
        return 'landpagy_image_box';
    }

    public function get_title() {
        return __( 'Image Box', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-t-letter';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        $this->start_controls_section(
            'img_box_sec',
            [
                'label' => __( 'Image Box', 'landpagy-core' ),
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Our Mission '
            ]
        );

        $repeater->add_control(
            'image', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA
            ]
        );

        $repeater->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'image_bg_style',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}::before',
            ]
        );

        $this->add_control(
            'image_boxes', [
                'label' => __( 'Add Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
            ]
        );

        $this->end_controls_section();

    }




    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        ?>

	    <div class="soft-counter-area">
            <div class="count-right">
                <div class="right-images">
                    <div class="row">
                        <?php
                        if ( !empty( $settings['image_boxes']) ) {
                            foreach ( $settings['image_boxes'] as $image_box ) {
                                $is_last_key = $image_box == end($settings['image_boxes'] ) ? ' mx-auto' : '';
                                ?>
                                <div class="col-6<?php echo esc_attr($is_last_key) ?>">
                                    <div class="image elementor-repeater-item-<?php echo esc_attr($image_box['_id']) ?>" style="background-image: url(<?php echo esc_url($image_box['image']['url']) ?>)">
                                        <h4><?php echo esc_html($image_box['title']); ?></h4>
                                    </div>
                                </div>
                                <?php
                            }
                        }
                        ?>
                    </div>
                </div>
            </div>
        </div>
        <?php

    }

}
