<?php
namespace LandpagyCore\Widgets;


use Elementor\Controls_Manager;
use Elementor\Widget_Base;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class Images extends Widget_Base {

    public function get_name() {
        return 'landpagy_images';
    }

    public function get_title() {
        return __( 'Image (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-image-rollover';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    public function get_script_depends() {
        return [ 'parallax-scroll' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }

    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //============================== Select Style ===============================//
        $this->start_controls_section(
            'select_style', [
                'label' => __( 'Preset Skins', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Style', 'landpagy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( '01: Image with Social Icon', 'landpagy-core' ),
                    '2' => esc_html__( '02: Multiple Image', 'landpagy-core' ),
                    '3' => esc_html__( '03: Multiple Image', 'landpagy-core' ),
                    '4' => esc_html__( '04: Multiple Image', 'landpagy-core' ),
                    '5' => esc_html__( '05: Multiple Image', 'landpagy-core' ),
                    '6' => esc_html__( '06: Multiple Image', 'landpagy-core' ),
                    '7' => esc_html__( '07: Multiple Image', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section(); //End Style


        //============= Image Overlay Hover =================//
        $this->start_controls_section(
            'img_box_sec', [
                'label' => __( 'Featured Images', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'fimage', [
                'label' => __( 'Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'fimage2', [
                'label' => __( 'Image 01', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->end_controls_section(); //End Image Overlay Hover

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============= Shape Images =================//
        $this->start_controls_section(
            'shape_images_sec', [
                'label' => __( 'Shape Images', 'landpagy-core' ),
                'condition' => [
                    'style' => [ '2', '3', '4', '5', '6', '7' ]
                ]
            ]
        );

        $this->add_control(
            'shape1', [
                'label' => __( 'Shape', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape2', [
                'label' => __( 'Shape 2', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '2', '3', '4', '6', '7' ],
                    'style!' => '5'
                ]
            ]
        );

        $this->add_control(
            'shape3', [
                'label' => __( 'Shape 3', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '3', '4', '6', '7' ],
                    'style!' => '5'
                ]
            ]
        );

        //===== Repeater Shape Images
        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'align_items', [
                'label' => esc_html__( 'Title', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HIDDEN,
            ]
        );

        $repeater->add_control(
            'shape', [
                'label' => esc_html__( 'Shape', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $repeater->add_control(
            'x_number', [
                'label' => esc_html__( 'X Number', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => '20'
            ]
        );

        $repeater->add_control(
            'y_number', [
                'label' => esc_html__( 'Y Number', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => '20'
            ]
        );

        $this->add_control(
            'shape_images', [
                'label' => esc_html__( 'Add Shape', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ align_items }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '5'
                ]
            ]
        );

        $this->end_controls_section(); //End Shape Images
    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        //Include Templating Files
        include "template/images/image-{$settings['style']}.php";
    }

}
