<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Info_Boxes extends Widget_Base {
    public function get_name() {
        return 'landpagy_info_boxes';
    }

    public function get_title() {
        return __( 'Info Box (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-person';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //============================== Info Boxes ===============================//
        $this->start_controls_section(
            'team_sec', [
                'label' => __( 'Team', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'image', [
                'label' => __( 'Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Landpagy Careers'
            ]
        );

        $this->add_control(
            'subtitle', [
                'label' => __( 'Subtitle', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Landpagy Careers'
            ]
        );

        $this->add_control(
            'btn_label', [
                'label' => __( 'Button Label', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Landpagy Careers'
            ]
        );

        $this->add_control(
            'btn_url', [
                'label' => __( 'Button URL', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ]
            ]
        );

        $this->end_controls_section(); //End Info Boxes

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        ?>
        <div class="landpagy-info-box">
            <div class="follow-item text-center">
                <?php
                if ( !empty($image['id']) ) { ?>
                    <div class="item-icon">
                        <?php echo wp_get_attachment_image($image['id'], 'full') ?>
                    </div>
                    <?php
                }
                if ( !empty($title) ) { ?>
                    <a <?php \Landpagy_Core_Helper()->the_button($btn_url) ?>>
                        <h3 class="item-title"><?php echo esc_html($title) ?></h3>
                    </a>
                    <?php
                }
                if ( !empty($subtitle) ) { ?>
                    <p class="item-para"><?php echo esc_html($subtitle) ?></p>
                    <?php
                }
                if ( !empty($btn_label) ) { ?>
                    <a <?php \Landpagy_Core_Helper()->the_button($btn_url) ?> class="item-link">
                        <?php echo esc_html($btn_label) ?>
                        <i class="arrow_right"></i>
                    </a>
                    <?php
                }
                ?>
            </div>
        </div>
        <?php

    }
}