<?php

namespace LandpagyCore\Widgets;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use WP_Query;

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Jobs extends Widget_Base {

    public function get_name() {
        return 'bjl_jobs';
    }

    public function get_title() {
        return __('Jobs (Theme)', 'landpagy-core');
    }

    public function get_icon() {
        return 'eicon-document-file';
    }

    public function get_categories() {
        return ['landpagy-elements'];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //=============================== Select Style =================================//
        $this->start_controls_section(
            'select_style', [
                'label' => __('Style', 'landpagy-core'),
            ]
        );

        $this->add_control(
            'style', [
                'label' => __('Style', 'landpagy-core'),
                'type' => Controls_Manager::SELECT,
                'default' => '1',
                'options' => [
                    '1' => __('01: Job List', 'landpagy-core'),
                    '2' => __('02: Featured Job', 'landpagy-core'),
                    '3' => __('03: Category Job Filter', 'landpagy-core'),
                ],
            ]
        );

        $this->end_controls_section(); // End Style


        //============================= Filter Options ================================//
        $this->start_controls_section(
            'filter_sec', [
                'label' => __('Filter', 'landpagy-core'),
            ]
        );

        $this->add_control(
            'cats', [
                'label' => esc_html__('Category', 'landpagy-core'),
                'description' => esc_html__('Display job by categories', 'landpagy-core'),
                'type' => Controls_Manager::SELECT2,
                'options' => Landpagy_Core_Helper()->get_the_categories('bjl_category'),
                'multiple' => true,
                'label_block' => true,
                'condition' => [
                    'style' => ['1', '2']
                ]
            ]
        );

        $this->add_control(
            'show_count', [
                'label' => esc_html__('Show Posts Count', 'landpagy-core'),
                'type' => Controls_Manager::NUMBER,
                'default' => 4
            ]
        );

        $this->add_control(
            'order', [
                'label' => esc_html__('Order', 'landpagy-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => 'ASC',
                    'DESC' => 'DESC'
                ],
                'default' => 'ASC'
            ]
        );

        $this->add_control(
            'orderby', [
                'label' => esc_html__('Order By', 'landpagy-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'none' => 'None',
                    'ID' => 'ID',
                    'author' => 'Author',
                    'title' => 'Title',
                    'name' => 'Name (by post slug)',
                    'date' => 'Date',
                    'rand' => 'Random',
                ],
                'default' => 'none'
            ]
        );

        $this->add_control(
            'title_length', [
                'label' => esc_html__('Excerpt Word Length', 'landpagy-core'),
                'type' => Controls_Manager::NUMBER,
                'default' => 6,
            ]
        );

        $this->add_control(
            'excerpt_length', [
                'label' => esc_html__('Excerpt Word Length', 'landpagy-core'),
                'type' => Controls_Manager::NUMBER,
            ]
        );

        $this->add_control(
            'exclude', [
                'label' => esc_html__('Exclude Job', 'landpagy-core'),
                'description' => esc_html__('Enter the job post IDs to hide/exclude. Input the multiple ID with comma separated', 'landpagy-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        // View Button
        $this->add_control(
            'btn_title', [
                'label' => esc_html__('Button Title', 'landpagy-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Apply Now',
            ]
        );

        $this->end_controls_section(); // End Job Filters

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control()
    {


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to Variable Conversation

        $args = [
            'post_type' => 'bjl_post',
            'post_status' => 'publish',
        ];
        if (!empty($show_count)) {
            $args['posts_per_page'] = $show_count;
        }
        if (!empty($order)) {
            $args['order'] = $order;
        }
        if (!empty($orderby)) {
            $args['orderby'] = $orderby;
        }
        if (!empty($exclude)) {
            $args['post__not_in'] = $exclude;
        }
        if (!empty($cats)) {
            $args['tax_query'] = [
                [
                    'taxonomy' => 'bjl_category',
                    'field' => 'slug',
                    'terms' => $cats

                ]
            ];
        }

        if ( $style == '2' ) {
            $args['meta_query'] = [
                [
                    'key' => 'featured',
                    'value' => 'yes',
                    'compare' => '='
                ]
            ];
        }

        $job_cats = get_terms( array(
            'taxonomy' => 'bjl_category',
            'hide_empty' => true,
        ));

        $job_location = get_terms( array(
            'taxonomy' => 'bjl_location',
            'hide_empty' => true,
        ));


        $jobs = new WP_Query($args);

        // Include File Path
        include_once "template/jobs/job-{$settings['style']}.php";

    }
}