<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Locations extends Widget_Base {
    public function get_name() {
        return 'landpagy_locations';
    }

    public function get_title() {
        return __( 'Locations', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-google-maps';
    }

    public function get_script_depends() {
        return [ 'tippy' ];
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //============================== Map Image ===============================//
        $this->start_controls_section(
            'images', [
                'label' => __( 'Map Image', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'map_image', [
                'label' => __( 'Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->end_controls_section(); // End Map Image


        //============================== Locations ===============================//
        $this->start_controls_section(
            'locations_sec', [
                'label' => __( 'Locations', 'plugin-name' ),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'country_flag', [
                'label' => __( 'Country Flag', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'country_name', [
                'label' => __( 'Country Name', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'United States'
            ]
        );

        $repeater->add_control(
            'street_name', [
                'label' => __( 'Street Name', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => '102 street 1234 Don'
            ]
        );


        $repeater->add_responsive_control(
            'hr_position', [
                'label' => esc_html__( 'Horizontal Position', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .marking-point' => 'left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $repeater->add_responsive_control(
            'vr_position', [
                'label' => esc_html__( 'Vertical Position', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .marking-point' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'locations', [
                'label' => __( 'Add Location', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ country_name }}}',
                'prevent_empty' => false
            ]
        );

        $this->end_controls_section();

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============================= Section Background ============================== //
        $this->start_controls_section(
            'sec_bg_style', [
                'label' => __( 'Section Background', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} ._landpagy_sec' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} ._landpagy_sec' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sec_background',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} ._landpagy_sec',
            ]
        );

        $this->end_controls_section(); //End Section Background


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>
        <section class="map-area _landpagy_sec">
            <div class="container">
                <div class="row">
                    <div class="col-12">
                        <div class="map">
                            <?php
                            if ( !empty($settings['map_image']['id']) ) {
                                ?>
                                <div class="map-image">
                                    <?php echo wp_get_attachment_image( $settings['map_image']['id'], 'full' ); ?>
                                </div>
                                <?php
                            }

                            if ( !empty($settings['locations']) ) {
                                foreach ( $settings['locations'] as $location ) {
                                    ?>
                                    <div class="map-marking-item elementor-repeater-item-<?php echo esc_attr($location['_id']) ?>">
                                        <div class="map-marking-point">
                                            <div data-placement="top" class="tippy-box map-address">
                                                <div class="tippy-content d-flex align-items-center">
                                                    <?php 
                                                    if ( !empty($location['country_flag']['id']) ) {
                                                        ?>
                                                        <div class="flag">
                                                            <?php echo wp_get_attachment_image( $location['country_flag']['id'], 'full' ); ?>
                                                        </div>
                                                        <?php
                                                    }
                                                    ?>
                                                    <div class="address-info">
                                                        <?php
                                                        echo !empty($location['country_name']) ? '<h6>'.esc_html($location['country_name']).'</h6>' : '';
                                                        echo !empty($location['street_name']) ? '<span>'.esc_html($location['street_name']).'</span>' : '';
                                                        ?>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="marking-point"></div>
                                        </div>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <?php
    }
}