<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Mailchimp extends Widget_Base {
    public function get_name() {
        return 'landpagy_mailchimp';
    }

    public function get_title() {
        return __( 'Mailchimp Form', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-mailchimp';
    }

    public function get_script_depends() {
        return [ 'ajax-chimp', 'parallax-scroll' ];
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    public function get_keywords() {
        return [ 'Subscriber', 'Mailchimp', 'Form' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //========================== Select Preset ===========================//
        $this->start_controls_section(
            'style_sec', [
                'label' => esc_html__( 'Preset Skins', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Style', 'landpagy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( '01: Subscriber', 'landpagy-core' ),
                    '2' => esc_html__( '02: Subscriber', 'landpagy-core' ),
                    '3' => esc_html__( '03: Subscriber', 'landpagy-core' ),
                    '4' => esc_html__( '04: Subscriber', 'landpagy-core' ),
                    '5' => esc_html__( '05: Subscriber', 'landpagy-core' ),
                    '6' => esc_html__( '06: Subscriber', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section();//End Select Style


        //=========================== Contents =================================//
        $this->start_controls_section(
            'contents_sec', [
                'label' => __( 'Contents', 'landpagy-core' ),
                'condition' => [
                    'style' => [ '2', '3' ]
                ]
            ]
        );

        $this->add_control(
            'title', [
                'label' => esc_html__( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Get free for 14 Days',
            ]
        );

        $this->add_control(
            'subtitle', [
                'label' => esc_html__( 'Subtitle', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $this->end_controls_section(); //End Contents


        // ------------------------------ MailChimp form ------------------------------
        $this->start_controls_section(
            'form_settings', [
                'label' => __( 'Form settings', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'email_placeholder', [
                'label' => esc_html__( 'Email Placeholder', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Email Address',
            ]
        );

        $this->add_control(
            'action_url', [
                'label' => esc_html__( 'Action URL', 'landpagy-core' ),
                'description' => __( 'Enter here your MailChimp action URL. <a href="#" target="_blank"> How to </a>', 'landpagy-core' ),
                'type' => Controls_Manager::TEXTAREA,
            ]
        );

        $this->add_control(
            'submit_btn', [
                'label' => esc_html__( 'Submit Button', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Subscribe',
                'condition' => [
                    'style' => [ '1', '2', '3', '4', '6' ]
                ]
            ]
        );

        $this->add_control(
            'icon', [
                'label' => esc_html__( 'Icon', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-circle',
                    'library' => 'fa-solid',
                ],
                'condition' => [
                    'style' => '5'
                ]
            ]
        );

        $this->end_controls_section(); //End Mailchimp

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============================= Call to Action Contents Style ============================== //
        $this->start_controls_section(
            'c2a_contents_style', [
                'label' => __( 'Contents', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '2', '3' ]
                ]
            ]
        );

        // Title Options
        $this->add_control(
            'title_options', [
                'label' => esc_html__( 'Title Options', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'title_typo',
                'selector' => '{{WRAPPER}} .section-title-center h2',
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => esc_html__( 'Text Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title-center h2' => 'color: {{VALUE}}',
                ],
            ]
        );

        // Subtitle Options
        $this->add_control(
            'subtitle_options', [
                'label' => esc_html__( 'Subtitle Options', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'subtitle_typo',
                'selector' => '{{WRAPPER}} .subtitle',
            ]
        );

        $this->add_control(
            'subtitle_color', [
                'label' => esc_html__( 'Text Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .subtitle' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section(); // Contents

        //================================== Shape Images ==========================//
        $this->start_controls_section(
            'shape_images', [
                'label' => __( 'Shapes', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => '3'
                ]
            ]
        );

        $this->add_control(
            'shape', [
                'label' => __( 'Shape', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_section(); // End Shape Images


        //================================== Form Style ===================== //
        $this->start_controls_section(
            'form_style_sec', [
                'label' => __( 'Form Styling', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'form_padding',
            [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy_subscribe .form-control' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'form_border_radius',
            [
                'label' => __( 'Border Radius', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy_subscribe .form-control' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'form_border',
                'label' => __( 'Border', 'landpagy-core' ),
                'selector' => '{{WRAPPER}} .landpagy_subscribe .form-control',
            ]
        );

        $this->add_control(
            'form_hover_text_color', [
                'label' => __( 'Hover Border Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .landpagy_subscribe .form-control:hover' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'border_border!' => '',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'form_bg_color',
                'label' => esc_html__( 'Background', 'plugin-name' ),
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image'],
                'fields_options' => [
                    'background' => [
                        'default' => 'classic',
                    ],
                    'color' => [
                        'dynamic' => [],
                    ],
                    'color_b' => [
                        'dynamic' => [],
                    ],
                ],
                'selector' => '{{WRAPPER}} .landpagy_subscribe .form-control',
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'spacing_btn_bottom', [
                'label' => esc_html__( 'Space', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '10',
                ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy_subscribe .form-group' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'separator' => 'before',
                'condition' => [
                    'style' => '4'
                ]
            ]
        );

        $this->end_controls_section(); //End form Style


        //====================== Submit Button Style ========================//
        $this->start_controls_section(
            'submit_btn_style', [
                'label' => __( 'Submit Button', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'btn_typo',
                'selector' => '{{WRAPPER}} .subscribe_btn',
            ]
        );

        $this->start_controls_tabs( 'btn_style_tabs' );

        //Normal Tabs
        $this->start_controls_tab(
            'btn_normal_tabs', [
                'label' => __( 'Normal', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'btn_normal_text_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .subscribe_btn' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'btn_normal_bg_color',
                'label' => esc_html__( 'Background', 'plugin-name' ),
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image'],
                'fields_options' => [
                    'background' => [
                        'default' => 'classic',
                    ],
                    'color' => [
                        'dynamic' => [],
                    ],
                    'color_b' => [
                        'dynamic' => [],
                    ],
                ],
                'selector' => '{{WRAPPER}} .subscribe_btn',
            ]
        );

        $this->add_control(
            'btn_normal_border_color', [
                'label' => __( 'Border Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .subscribe_btn' => 'border-color: {{VALUE}};',
                ]
            ]
        );

        $this->end_controls_tab(); // End Normal Tabs

        //Hover Tabs
        $this->start_controls_tab(
            'btn_hover_tabs', [
                'label' => __( 'Hover', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'btn_hover_text_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .subscribe_btn:hover' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'btn_hover_bg_color',
                'label' => esc_html__( 'Background', 'plugin-name' ),
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image'],
                'fields_options' => [
                    'background' => [
                        'default' => 'classic',
                    ],
                    'color' => [
                        'dynamic' => [],
                    ],
                    'color_b' => [
                        'dynamic' => [],
                    ],
                ],
                'selector' => '{{WRAPPER}} .subscribe_btn:hover',
            ]
        );

        $this->add_control(
            'btn_hover_border_color', [
                'label' => __( 'Border Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .subscribe_btn:hover' => 'border-color: {{VALUE}};',
                ]
            ]
        );

        $this->end_controls_tab();//End Hover Tabs
        $this->end_controls_tabs(); // End Button Tabs


        $this->add_responsive_control(
            'btn_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .subscribe_btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'btn_padding',
            [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .subscribe_btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'after',
            ]
        );

        $this->add_responsive_control(
            'btn_border_radius', [
                'label' => __( 'Border Radius', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .subscribe_btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(), [
                'name' => 'btn_border',
                'label' => __( 'Border', 'landpagy-core' ),
                'selector' => '{{WRAPPER}} .subscribe_btn',
            ]
        );

        $this->add_control(
            'btn_height', [
                'label' => esc_html__( 'Height', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .subscribe_btn' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section(); //End submit button style


        //============================= Section Background ============================== //
        $this->start_controls_section(
            'sec_bg_style', [
                'label' => __( 'Section Background', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '3' ],
                ]
            ]
        );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy_sec' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy_sec' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sec_background',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .landpagy_sec',
            ]
        );

        $this->end_controls_section(); //End Section Background

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();


        //======= Template Files
        include "template/mailchimp/subscriber-{$settings['style']}.php";

    }
}