<?php
namespace LandpagyCore\Widgets;

// Exit if accessed directly
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Mega_Menu extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_mega_menu';
    }

    public function get_title() {
        return __( 'Mega Menu (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-nav-menu';
    }

    public function get_keywords() {
        return [ 'menu', 'nav', 'header', 'navbar' ];
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //========================= Menu Layout ==========================//
        $this->start_controls_section(
            'menu_sections', [
                'label' => __( 'Menu', 'landpagy-core' ),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'tab_title', [
                'label' => __( 'Tab Category', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'separator' => 'after'
            ]
        );

        $repeater->add_control(
            'menu_img', [
                'label' => esc_html__( 'Image', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $repeater->add_control(
            'menu_item', [
                'label' => __( 'Menu Item', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true
            ]
        );

        $repeater->add_control(
            'menu_item_url', [
                'label' => __( 'Menu Item URL', 'landpagy-core' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ]
            ]
        );

        $repeater->add_control(
            'menu_description', [
                'label' => __( 'Menu Description', 'landpagy-core' ),
                'type' => Controls_Manager::TEXTAREA,
            ]
        );

        $this->add_control(
            'tab_menu_items', [
                'label' => esc_html__( 'Add Menu Item', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ tab_title }}}',
            ]
        );

        $this->end_controls_section(); //End Logo Section



    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        $tab_menu_items = $settings['tab_menu_items'];
        $cats       = array_column( $tab_menu_items, 'tab_title' );
        $getCats    = array_unique( $cats );
        $menu_data  = return_tab_data( $getCats , $tab_menu_items );

        ?>
        <section class="hover_tab_mega_menu">

            <div class="column menu_categories">
                <ul class="nav">
                    <?php
                    if ( is_array( $tab_menu_items ) && count( $tab_menu_items ) > 0 ){
                        $i      = 0;
                        foreach ( $getCats as $cat ) {
                            $catForFilter = sanitize_title_with_dashes( $cat );
                            $catForFilter = str_replace( '-', '', $catForFilter );
                            $i++;
                            $active = $i == 1 ? ' active' : '';
                            $aria_selected = $i==1 ? 'true' : 'false';
                            ?>
                            <li class="nav-item">
                                <a href="javascript:void(0)" class="nav-link <?php echo $active ?>" id="<?php echo esc_attr($catForFilter) ?>-tab" data-bs-toggle="tab"
                                    data-bs-target="#<?php echo esc_attr($catForFilter) ?>" role="tab" aria-controls="<?php echo esc_attr($catForFilter); ?>"
                                    aria-selected="<?php esc_attr($aria_selected) ?>">
                                    <span><?php echo esc_html($cat) ?></span>
                                    <i class="fa fa-chevron-right"></i>
                                </a>
                            </li>
                            <?php
                            $i++;
                        }
                    }
                    ?>
                </ul>

            </div>

            <div class="column menu_items">
                <div class="tab-content" id="myTabContent">
                    <?php
                    if ( !empty( $menu_data ) ) {
                        $i = 0;
                        foreach ($menu_data as $key => $value) {
                            $tagforfilter = sanitize_title_with_dashes($key);
                            $catForFilter = str_replace( '-', '', $tagforfilter );
                            $i++;
                            $show_active = $i == 1 ? ' show active' : '';
                            ?>
                            <div class="tab-pane fade <?php echo $show_active ?>" id="<?php echo esc_attr($catForFilter); ?>" role="tabpanel" aria-labelledby="<?php echo esc_attr($catForFilter) ?>-tab">
                                <?php
                                foreach ( $value as $table_item ) {
                                    ?>
                                    <a <?php Landpagy_Core_Helper()->the_button($table_item['menu_item_url']) ?> class="hover_tab_content">
                                        <div class="icon">
                                            <?php echo wp_get_attachment_image($table_item['menu_img']['id'], 'landpagy_80x80') ?>
                                        </div>
                                        <div class="content">
                                            <div class="heading"><?php echo esc_html($table_item['menu_item']) ?></div>
                                            <div class="description"><?php echo esc_html($table_item['menu_description']) ?></div>
                                        </div>
                                    </a>
                                    <?php
                                }
                                ?>
                            </div>
                            <?php
                            $i++;
                        }
                    }
                    ?>
                </div>
            </div>

        </section>

        <script>
            ;(function($){
                "use strict";
                $(document).ready(function () {

                    /*$('#example-tabs > li').on('mouseenter', function() {
                        let menu_name = $(this).find('a');
                        $(this).find('a').click()
                    });*/

                });
            })(jQuery)
        </script>
        <?php

    }

}