<?php
namespace LandpagyCore\Widgets;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Nav_Menu extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_nav_menu';
    }

    public function get_title() {
        return __( 'Nav Menu (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-nav-menu';
    }

    public function get_keywords() {
        return [ 'menu', 'nav', 'header', 'navbar' ];
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //========================= Menu Layout ==========================//
        $this->start_controls_section(
            'menu_sections', [
                'label' => __( 'Menu', 'landpagy-core' ),
            ]
        );

        $menus = $this->get_menus();

        if ( ! empty( $menus ) ) {
            $this->add_control(
                'landpagy_menus', [
                    'label'        => __( 'Select Menu', 'landpagy-core' ),
                    'type'         => \Elementor\Controls_Manager::SELECT,
                    'options'      => $menus,
                    'default'      => array_keys( $menus )[0],
                    'save_default' => true,
                    'separator'    => 'after',
                    'description'  => sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to manage your menus.', 'landpagy-core' ), admin_url( 'nav-menus.php' ) ),
                ]
            );
        } else {
            $this->add_control(
                'menus_alert', [
                    'type'            => \Elementor\Controls_Manager::RAW_HTML,
                    'raw'             => sprintf( __( '<strong>There are no menus in your site.</strong><br>Go to the <a href="%s" target="_blank">Menus screen</a> to create one.', 'landpagy-core' ), admin_url( 'nav-menus.php?action=edit&menu=0' ) ),
                    'separator'       => 'after',
                    'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
                ]
            );
        }

        $this->add_control(
            'style', [
                'label'   => __( 'Style', 'landpagy-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '1'     => __( '01: Simple Menu', 'landpagy-core' ),
                    '2'     => __( '02: Classic Menu', 'landpagy-core' ),
                ],
                'default' => '2',
            ]
        );

        $this->add_control(
            'menu_absolute', [
                'label'        => __( 'Menu Absolute', 'landpagy-core' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'landpagy-core' ),
                'label_off'    => __( 'No', 'landpagy-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
                'separator'    => 'before',
            ]
        );

        $this->add_control(
            'menu_sticky', [
                'label' => __( 'Menu Sticky?', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Yes', 'landpagy-core' ),
                'label_off' => __( 'No', 'landpagy-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        //=========== Menu Alignment
        $this->add_responsive_control(
            'menu_alignment', [
                'label' => __( 'Alignment', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'mr-auto' => [
                        'title' => __( 'Left', 'landpagy-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'm-auto' => [
                        'title' => __( 'Center', 'landpagy-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'ml-auto' => [
                        'title' => __( 'Right', 'landpagy-core' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'm-auto',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'menu_width_layout', [
                'label'   => __( 'Layout', 'landpagy-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'container'     => __( 'Box', 'landpagy-core' ),
                    'container-fluid'    => __( 'Full', 'landpagy-core' ),
                ],
                'default' => 'container',
            ]
        );

        $this->end_controls_section(); // End Menu Layout


        //=================================== Logo =========================================//
        $this->start_controls_section(
            'logo_sec', [
                'label' => __( 'Logo', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'use_custom_logo', [
                'label' => __( 'Use a Custom Logo?', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Yes', 'landpagy-core' ),
                'label_off' => __( 'No', 'landpagy-core' ),
                'return_value' => 'yes',
                'default' => '',
            ]
        );

        $this->add_control(
            'main_logo', [
                'label' => __( 'Upload Logo', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'use_custom_logo' => ['yes'],
                ]
            ]
        );

        $this->add_control(
            'retina_main_logo', [
                'label' => __( 'Retina Logo', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'use_custom_logo' => ['yes'],
                ]
            ]
        );

        $this->add_control(
            'sticky_logo', [
                'label' => __( 'Sticky Logo', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'use_custom_logo' => ['yes'],
                ]
            ]
        );

        $this->add_control(
            'retina_sticky_logo', [
                'label' => __( 'Retina Sticky Logo', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'use_custom_logo' => ['yes'],
                ]
            ]
        );

        $this->add_control(
            'logo_url', [
                'label' => __( 'Site Link', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ],
                'separator' => 'before',
                'condition' => [
                    'use_custom_logo' => ['yes'],
                ]
            ]
        );

        $this->add_responsive_control(
            'logo_max_width', [
                'label' => __( 'Max Width', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .navbar-brand img' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'use_custom_logo' => ['yes'],
                ],
                'separator' => 'before'
            ]
        );


        $this->add_responsive_control(
            'logo_width', [
                'label' => __( 'Width', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => '',
                ],
                'condition' => [
                    'use_custom_logo' => ['yes'],
                ],
                'selectors' => [
                    '{{WRAPPER}}  .navbar-brand img' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'logo_height', [
                'label' => __( 'Height', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => '',
                ],
                'condition' => [
                    'use_custom_logo' => ['yes'],
                ],
                'selectors' => [
                    '{{WRAPPER}} .navbar-brand img' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section(); //End Logo Section


        //=================================== Buttons  =========================================//
        $this->start_controls_section(
            'buttons_sec', [
                'label' => __( 'Buttons', 'landpagy-core' ),
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $button = new \Elementor\Repeater();
        $button->add_control(
            'btn_title', [
                'label' => esc_html__( 'Button Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Sign In',
            ]
        );

        $button->add_control(
            'btn_url', [
                'label' => esc_html__( 'Button URL', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ]
            ]
        );

        $button->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'btn_typo',
                'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
                'separator' => 'before'
            ]
        );

        //=== Button Style Normal Menu
        $button->add_control(
            'btn_normal_heading', [
                'label' => __( 'Normal Menu', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $button->start_controls_tabs('btn_style_tabs');

        //=== Normal Color
        $button->start_controls_tab(
            'btn_normal_style', [
                'label' => __( 'Normal', 'landpagy-core' ),
            ]
        );

        $button->add_control(
            'btn_text_normal_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'color: {{VALUE}}',
                ],
            ]
        );

        $button->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'btn_bg_normal_color',
                'label' => __( 'Background Color', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
            ]
        );

        $button->add_control(
            'btn_border_normal_color', [
                'label' => __( 'Border Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $button->end_controls_tab();

        //=== Hover Color
        $button->start_controls_tab(
            'btn_hover_style', [
                'label' => __( 'Hover', 'landpagy-core' ),
            ]
        );

        $button->add_control(
            'btn_text_hover_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $button->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'btn_bg_hover_color',
                'label' => __( 'Background Color', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}:hover',
            ]
        );

        $button->add_control(
            'btn_border_hover_color', [
                'label' => __( 'Border Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}:hover' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $button->end_controls_tab();

        $button->end_controls_tabs(); // End Button Style Tabs

        //=== Button Style Sticky Menu
        $button->add_control(
            'btn_sticky_heading', [
                'label' => __( 'Sticky Menu', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $button->start_controls_tabs('btn_style_sticky_tabs');

        //=== Normal Color
        $button->start_controls_tab(
            'sticky_btn_normal_style', [
                'label' => __( 'Normal', 'landpagy-core' ),
            ]
        );

        $button->add_control(
            'sticky_btn_text_normal_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .navbar_fixed {{CURRENT_ITEM}}' => 'color: {{VALUE}}',
                ],
            ]
        );

        $button->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sticky_btn_bg_normal_color',
                'label' => __( 'Background Color', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .navbar_fixed {{CURRENT_ITEM}}',
            ]
        );

        $button->add_control(
            'sticky_btn_border_normal_color', [
                'label' => __( 'Border Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .navbar_fixed {{CURRENT_ITEM}}' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $button->end_controls_tab();

        //=== Hover Color
        $button->start_controls_tab(
            'sticky_btn_hover_style', [
                'label' => __( 'Hover', 'landpagy-core' ),
            ]
        );

        $button->add_control(
            'sticky_btn_text_hover_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .navbar_fixed {{CURRENT_ITEM}}:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $button->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sticky_btn_bg_hover_color',
                'label' => __( 'Background Color', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .navbar_fixed {{CURRENT_ITEM}}:hover',
            ]
        );

        $button->add_control(
            'sticky_btn_border_hover_color', [
                'label' => __( 'Border Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .navbar_fixed {{CURRENT_ITEM}}:hover' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $button->end_controls_tab();

        $button->end_controls_tabs(); // End Button Style Tabs

        $button->add_control(
            'btn_divider', [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );

        $button->add_group_control(
            \Elementor\Group_Control_Border::get_type(), [
                'name' => 'btn_border',
                'label' => __( 'Border', 'landpagy-core' ),
                'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
            ]
        );

        $button->add_responsive_control(
            'btn_border_radius', [
                'label' => __( 'Border Radius', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $button->add_responsive_control(
            'btn_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_control(
            'buttons', [
                'label' => esc_html__( 'Create Button', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $button->get_controls(),
                'title_field' => '{{{ btn_title }}}',
                'prevent_empty' => false,
            ]
        );

        $this->add_responsive_control(
            'btn_spacing', [
                'label' => __( 'Button Spacing', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}:first-child' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section(); //End Buttons

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //===================================== Style Main Menu ===================================//
        $this->start_controls_section(
            'main_menu_style', [
                'label' => __( 'Main Menu', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'menu_item_typo',
                'selector' => '
                    {{WRAPPER}} .menu > .nav-item > .nav-link
                ',
            ]
        );

        $this->add_control(
            'menu_item_color_normal', [
                'label' => __( 'Item Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu > .nav-item > .nav-link' => 'color: {{VALUE}}',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'menu_item_color_hover', [
                'label' => __( 'Item Hover/Active Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu > .nav-item > .nav-link:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .menu > .nav-item:hover > .nav-link::before' => 'background: {{VALUE}}',
                    '{{WRAPPER}} .menu > .nav-item > .nav-link::before' => 'background: {{VALUE}}',
                    '{{WRAPPER}} .menu > .current-menu-parent.nav-item .nav-link' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'menu_item_padding', [
                'label' => __( 'Item Padding', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .menu > .nav-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'menu_item_margin', [
                'label' => __( 'Item Spacing', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .menu > .nav-item + .nav-item' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'menu_item_spacing', [
                'label' => __( 'Menu Spacing', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => -50,
                        'max' => 50,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy_header .navbar-nav' => 'margin-left: {{SIZE}}{{UNIT}}; margin-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section(); //End Main Menu Style


        //================================= Style Sticky Menu ===============================//
        $this->start_controls_section(
            'style_sticky_menu', [
                'label' => __( 'Sticky Menu', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'sticky_menu_normal_color', [
                'label' => __( 'Item color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .navbar_fixed .menu > .nav-item > .nav-link' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sticky_menu_color_hover', [
                'label' => __( 'Item Hover/Active color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .navbar_fixed .menu > .nav-item:hover > .nav-link' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .navbar_fixed .menu > .nav-item.active > .nav-link' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sticky_menu_background',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient'],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .landpagy_header .navbar.navbar_fixed',
                'separator' => 'before'
            ]
        );

        $this->end_controls_section(); // End Sticky Menu


        //===================================== Sub menu style =========================================//
        $this->start_controls_section(
            'style_sub_menu_item', [
                'label' => __( 'Sub Menu', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'sub_item_typo',
                'selector' => '{{WRAPPER}} .landpagy_header .menu .nav-item .submenu_dropdown .nav-item .nav-link',
            ]
        );

        $this->add_control(
            'sub_menu_normal_color', [
                'label' => __( 'Item color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .landpagy_header .menu .nav-item .submenu_dropdown .nav-item .nav-link' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .menu > .nav-item.submenu .dropdown-menu .nav-item .nav-link' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'sub_menu_hover_color', [
                'label' => __( 'Hover/Active color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    //'{{WRAPPER}} .landpagy_header .menu .nav-item .submenu_dropdown .nav-item:hover .nav-link' => 'color: {{VALUE}}',
                    //'{{WRAPPER}} .landpagy_header .menu .nav-item .submenu_dropdown .nav-item.active .nav-link' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .menu > .nav-item.submenu .dropdown-menu .nav-item.active > .nav-link' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .menu > .nav-item.submenu .dropdown-menu .nav-item:hover > .nav-link' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .menu > .nav-item.submenu .dropdown-menu .nav-item .nav-link:before' => 'background-color: {{VALUE}}',

                ],
                'separator' => 'after'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'sub_menu_background',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient'],
                'selector' => '{{WRAPPER}} .menu .nav-item.submenu .submenu_dropdown',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'sub_menu_shadow',
                'label' => __( 'Box Shadow', 'landpagy-core' ),
                'selector' => '{{WRAPPER}} .menu .nav-item.submenu .submenu_dropdown',
            ]
        );

        $this->end_controls_section(); // End Sub Menu Style


        //================================ Section Background ===========================//
        $this->start_controls_section(
            'sec_bg_style', [
                'label' => __( 'Background', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy_header .navbar' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy_header .navbar' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'after'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'main_menu_bg_color',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient'],
                'exclude' => [ 'image' ],
                'selector' => '
                    {{WRAPPER}} .landpagy_header .navbar
                ',
            ]
        );

        $this->end_controls_section(); //End Section Background







        //===================================== Style Mobile Menu ===================================//
        $this->start_controls_section(
            'mobile_menu_style', [
                'label' => __( 'Mobile Menu', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'mobile_menu_item_typo',
                'selector' => '
                    {{WRAPPER}} .mobile_menu .menu > .nav-item > .nav-link
                ',
            ]
        );

        $this->add_control(
            'mobile_menu_item_color_normal', [
                'label' => __( 'Item Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mobile_menu .menu > .nav-item > .nav-link' => 'color: {{VALUE}}',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'mobile_menu_item_color_hover', [
                'label' => __( 'Item Hover/Active Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    //'{{WRAPPER}} .menu > .current-menu-parent.nav-item .nav-link' => 'color: {{VALUE}}',
                    //'{{WRAPPER}} .menu > .nav-item:hover .nav-link, .menu > .active.nav-item .nav-link' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'hamburger_menu_item_color', [
                'label' => __( 'Hamburger Menu Icon Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mobile_menu .menu_toggle .hamburger span' => 'background: {{VALUE}}',
                    '{{WRAPPER}} .mobile_menu .menu_toggle .hamburger-cross span' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section(); //End Main Menu Style


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        $menu_alignment = $settings['menu_alignment'];
        $menu_container = $settings['menu_width_layout'] == 'container' ? 'container' : 'container-fluid';
        $menu_absolute = $settings['menu_absolute'] == 'yes' ? ' position-absolute' : '';
        $menu_sticky = $settings['menu_sticky'] == 'yes' ? ' sticky_nav' : '';


        $args = [
            'echo' => false,
            'menu' => $settings['landpagy_menus'],
            'menu_class' => 'navbar-nav menu mx-auto',
            'fallback_cb' => '__return_empty_string',
            'container' => '',
            'walker' => new \Landpagy_Nav_Walker(),
        ];

        $menu_html = wp_nav_menu( $args );

        include( "template/nav-menu/menu-{$settings['style']}.php" );

    }


    // Get Menus
    private function get_menus() {
        $menus = wp_get_nav_menus();
        $options = [];
        foreach ( $menus as $menu ) {
            $options[ $menu->name] = $menu->name;
        }
        return $options;
    }

}