<?php
namespace LandpagyCore\Widgets;

use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Gallery
 * @package LandpagyCore\Widgets
 */
class Parallax extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_parallax';
    }

    public function get_title() {
        return __( 'Landpagy Parallax Effect', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-parallax';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    public function get_script_depends() {
        return [ 'parallax','parallax-scroll' ];
    }

    public function get_keywords() {
        return [ 'Image', 'Parallax Image', 'Animated Image' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        // ------------------------------  Animation Circle  ------------------------------ //
        $this->start_controls_section(
            'animation_circle_sec', [
                'label' => __( 'Parallax Image', 'landpagy-core' ),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'align_items', [
                'label' => __( 'Align Items', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::HIDDEN,
            ]
        );

        $repeater->add_control(
            'is_parallax', [
                'label' => __( 'Parallax Effect', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Yes', 'landpagy-core' ),
                'label_off' => __( 'No', 'landpagy-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $repeater->add_control(
            'image', [
                'label' => __( 'Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'separator' => 'after',
            ]
        );

        $repeater->add_responsive_control(
            'img_width', [
                'label' => __( 'Width', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} img' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $repeater->add_responsive_control(
            'img_max_width', [
                'label' => __( 'Max-Width', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} img' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $repeater->add_responsive_control(
            'img_height', [
                'label' => __( 'Height', 'landpagy-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} img' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        //=========== Offset
        $repeater->add_control(
            'image_offset', [
                'label'        => __('Offset', 'landpagy-core'),
                'type'         => Controls_Manager::POPOVER_TOGGLE,
                'label_on'     => __('Custom', 'landpagy-core'),
                'label_off'    => __('None', 'landpagy-core'),
                'return_value' => 'yes',
                'separator' => 'before'
            ]
        );

        $repeater->start_popover();

        $repeater->add_responsive_control(
            'image_offset_x', [
                'label'       => __('Offset Horizontal', 'landpagy-core'),
                'type'        => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'left: {{SIZE}}{{UNIT}}',
                ],
                'condition'   => [
                    'image_offset' => 'yes',
                ],
            ]
        );

        $repeater->add_responsive_control(
            'image_offset_y',
            [
                'label'      => __('Offset Vertical', 'landpagy-core'),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'top: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'image_offset' => 'yes',
                ],
            ]
        );

        $repeater->end_popover(); // End Offset


        //=========== Data Dept
        $repeater->add_control(
            'data_depth', [
                'label' => __( 'Data Depth', 'landpagy-core' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'step' => 0.1,
                'default' => '0.5',
            ]
        );

        $repeater->add_responsive_control(
            'z_index', [
                'label' => __( 'Z-Index', 'landpagy-core' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'step' => 1,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'z-index: {{VALUE}};',
                ],
            ]
        );

        $repeater->add_control(
            'is_absolute', [
                'label' => __( 'Position Absolute', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Yes', 'landpagy-core' ),
                'label_off' => __( 'No', 'landpagy-core' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $repeater->add_responsive_control(
            'align', [
                'label' => __( 'Alignment', 'elementor' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'elementor' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'elementor' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'elementor' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'text-align: {{VALUE}};',
                ],
                'default' => 'left',
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'parallax_images', [
                'label' => __( 'Add Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ align_items }}}',
                'prevent_empty' => false,
            ]
        );

        $this->end_controls_section();

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); // extract settings data
        ?>
        <section class="parallax_image_effect">
            <?php
            if ( is_array($parallax_images) ) {
                foreach ( $parallax_images as $image ) {
                    $data_depth = !empty($image['data_depth']) ? 'data-depth='.$image['data_depth'].'' : '';
                    ?>
                    <div class="<?php echo esc_attr( $image['is_absolute'] == 'yes' ) ? 'absolute ' : ''; ?><?php echo esc_attr( $image['is_parallax'] == 'yes' ) ? 'layer layer2 ' : ''  ?>elementor-repeater-item-<?php echo esc_attr($image['_id'])?>" <?php echo esc_attr($data_depth) ?>>
                        <?php echo wp_get_attachment_image( $image['image']['id'], 'full' ); ?>
                    </div>
                    <?php
                }
            }
            ?>
        </section>
        <?php
    }
}