<?php
namespace LandpagyCore\Widgets;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class Portfolio extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_portfolio';
    }

    public function get_title() {
        return __( 'Filterable Portfolio (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-gallery-grid';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    public function get_script_depends() {
        return [ 'isotope' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }

    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //================================ Query Filter ============================//
        $this->start_controls_section(
            'portfolio_filter', [
                'label' => __( 'Filter', 'landpagy-core' ),
            ]
        );
        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Portfolio Style', 'landpagy-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( '01: Portfolio', 'landpagy-core' ),
                    '2' => esc_html__( '02: Portfolio', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->add_control(
            'all_label', [
                'label' => esc_html__( 'All filter label', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'All'
            ]
        );

        $this->add_control(
            'cats', [
                'label' => esc_html__( 'Categories', 'landpagy-core' ),
                'description' => esc_html__( 'Display portfolios by categories', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'options' => Landpagy_Core_Helper()->get_the_categories('portfolio_cat'),
                'label_block' => true,
                'multiple' => true,
            ]
        );

        $this->add_control(
            'show_count', [
                'label' => esc_html__( 'Show count', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 9
            ]
        );

        $this->add_control(
            'order', [
                'label' => esc_html__( 'Order', 'landpagy-core' ),
                'description' => esc_html__( '‘ASC‘ – ascending order from lowest to highest values (1, 2, 3; a, b, c). ‘DESC‘ – descending order from highest to lowest values (3, 2, 1; c, b, a).', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'ASC' => 'ASC',
                    'DESC' => 'DESC'
                ],
                'default' => 'ASC'
            ]
        );

        $this->add_control(
            'orderby', [
                'label' => esc_html__( 'Order By', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'none' => 'None',
                    'ID' => 'ID',
                    'author' => 'Author',
                    'title' => 'Title',
                    'name' => 'Name (by post slug)',
                    'date' => 'Date',
                    'rand' => 'Random',
                    'comment_count' => 'Comment Count',
                ],
                'default' => 'none'
            ]
        );

        $this->add_control(
            'exclude', [
                'label' => esc_html__( 'Exclude Portfolio', 'landpagy-core' ),
                'description' => esc_html__( 'Enter the portfolio post ID to hide. Input the multiple ID with comma separated', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
            ]
        );

        $this->end_controls_section(); //End Query filter


        //================================ Buttons ============================//
        $this->start_controls_section(
            'sec_button', [
                'label' => __( 'Button', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'btn_label', [
                'label' => esc_html__( 'Button label', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'View Details'
            ]
        );

        $this->end_controls_section(); //End Buttons

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {

        // -------------------------------------------- Filtering [ STYLE ]
        $this->start_controls_section(
            'portfolio_color', [
                'label' => __( 'Filter', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'filter_color', [
                'label' => __( 'Filter Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .software-titles li' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'typography_filter',
                'label'    => esc_html__( 'Filter Typography', 'landpagy-core' ),
                'selector' => '{{WRAPPER}} .software-titles li',
            ]
        );

        $this->add_control(
            'filter_active_color', [
                'label' => __( 'Active Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .software-titles li.active' => 'color: {{VALUE}}'
                ],
                'separator'     => 'before'
            ]
        );

        $this->add_control(
            'filter_active_bgcolor', [
                'label' => __( 'Active Background Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .software-titles li.active' => 'background-color: {{VALUE}}'
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'typography_filter_active',
                'label'    => esc_html__( 'Active Typography', 'landpagy-core' ),
                'selector' => '{{WRAPPER}} .software-titles li.active',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'portfolio_content_color', [
                'label' => __( 'Content', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'base_color', [
                'label' => __( 'Base Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .software-item .new-text' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'base_bgcolor', [
                'label' => __( 'Base Background Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .software-item .new-text' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'typography_base',
                'label'    => esc_html__( 'Base Typography', 'landpagy-core' ),
                'selector' => '{{WRAPPER}} .software-item .new-text',
            ]
        );

        $this->add_control(
            'btn_color', [
                'label' => __( 'Button Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .software-item .item-link' => 'color: {{VALUE}}'
                ],
                'separator'     => 'before'
            ]
        );

        $this->add_control(
            'btn_bgcolor', [
                'label' => __( 'Button Background Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .software-item .item-link' => 'background-image: none;background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'typography_btns',
                'label'    => esc_html__( 'Button Typography', 'landpagy-core' ),
                'selector' => '{{WRAPPER}} .software-item .item-link',
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => __( 'Title Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .software-item .item-title, .items-title' => 'color: {{VALUE}}'
                ],
                'separator'     => 'before'
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'typography_title',
                'label'    => esc_html__( 'Typography', 'landpagy-core' ),
                'selector' => '{{WRAPPER}} .software-item .items-title',
            ]
        );
        $this->add_control(
            'category_color', [
                'label' => __( 'Category Color', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .software-item .__category' => 'color: {{VALUE}}'
                ],
                'separator'     => 'before'
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'typography_category',
                'label'    => esc_html__( 'Typography', 'landpagy-core' ),
                'selector' => '{{WRAPPER}} .software-item .__category',
            ]
        );

        $this->end_controls_section();
    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable

        $args = array(
            'post_type' => 'portfolio',
            'post_status' => 'publish',
        );
        if ( !empty($show_count) ) {
            $args['posts_per_page'] = $show_count;
        }
        if ( !empty($order) ) {
            $args['order'] = $order;
        }
        if ( !empty($orderby) ) {
            $args['orderby'] = $orderby;
        }
        if ( !empty($exclude) ) {
            $args['post__not_in'] = $exclude;
        }
        if ( !empty($cats) ) {
            $args['tax_query'] = [
                [
                    'taxonomy' => 'portfolio_cat',
                    'field' => 'id',
                    'terms' => $cats,
                ],
            ];
        }

        $portfolios = new \WP_Query($args);

        //============ Include Template part
        include( "template/portfolio/portfolio-{$settings['style']}.php" );

    }
}