<?php
namespace LandpagyCore\Widgets;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Processes
 * @package LandpagyCore\Widgets
 */
class Processes extends Widget_Base {

    public function get_name() {
        return 'landpagy_processes';
    }

    public function get_title() {
        return __( 'Processes', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-device-desktop';
    }

    public function get_script_depends() {
        return [ 'counterup', 'waypoints' ];
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //============================= Style ================================//
        $this->start_controls_section(
            'select_style', [
                'label' => __('Style', 'banca-core'),
            ]
        );

        $this->add_control(
            'style', [
                'label' => __( 'Style', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '1'  => __( 'Style 01', 'banca-core' ),
                    '2'  => __( 'Style 02', 'banca-core' ),
                    '3'  => __( 'Style 03', 'banca-core' ),
                    '4'  => __( 'Style 04', 'banca-core' ),
                    '5'  => __( 'Style 05', 'banca-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section(); //End Style


        //========================== Processes ===========================//
        $this->start_controls_section(
            'processes_sec', [
                'label' => __( 'Processes', 'banca-core' ),
            ]
        );

        $process_1 = new \Elementor\Repeater();

        //== Left Contents
        $process_1->add_control(
            'left_contents_heading', [
                'label' => __( 'Left Contents', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $process_1->add_control(
            'step_text', [
                'label' => __( 'Step Text', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Step',
            ]
        );

        $process_1->add_control(
            'step_no', [
                'label' => __( 'Step Number', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '1',
            ]
        );

        $process_1->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Language and Personality',
            ]
        );

        $process_1->add_control(
            'contents', [
                'label' => __( 'Contents', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        //== Right Contents
        $process_1->add_control(
            'right_contents_heading', [
                'label' => __( 'Right Contents', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $process_1->add_control(
            'icon', [
                'label' => __( 'Icon', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $process_1->add_control(
            'count_num', [
                'label' => __( 'Count Number', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => '26.4',
            ]
        );

        $process_1->add_control(
            'count_text', [
                'label' => __( 'Count Text', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'of applicants pass',
            ]
        );

        $this->add_control(
            'processes_1', [
                'label' => __( 'Add Steps', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $process_1->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '1'
                ]
            ]
        ); //End Process Style 01



        //================ Process Style 02
        $process_2 = new \Elementor\Repeater();
        $process_2->add_control(
            'serial_no', [
                'label' => __( 'Serial Number', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '01',
            ]
        );

        $process_2->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Define your goals',
            ]
        );

        $process_2->add_control(
            'contents', [
                'label' => __( 'Contents', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
            ]
        );

        $process_2->add_control(
            'image_style', [
                'label' => __( 'Image Preset', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '1'  => __( 'Design 01', 'banca-core' ),
                    '2'  => __( 'Design 02', 'banca-core' ),
                    '3'  => __( 'Design 03', 'banca-core' ),
                    '4'  => __( 'Design 04', 'banca-core' ),
                ],
                'default' => '1',
                'separator' => 'before'
            ]
        );

        $process_2->add_control(
            'image1', [
                'label' => __( 'Image 01', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'image_style' => [ '1', '2', '3', '4' ]
                ]
            ]
        );

        $process_2->add_control(
            'image2', [
                'label' => __( 'Image 02', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'image_style' => [ '1', '2', '3', '4' ]
                ]
            ]
        );

        $process_2->add_control(
            'image3', [
                'label' => __( 'Image 03', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'image_style' => [ '1', '2', '3', '4' ]
                ]
            ]
        );

        $process_2->add_control(
            'image4', [
                'label' => __( 'Image 04', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'image_style' => [ '2', '3', '4' ]
                ]
            ]
        );

        $process_2->add_control(
            'image5', [
                'label' => __( 'Image 05', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'image_style' => [ '2', '3', '4' ]
                ]
            ]
        );

        $process_2->add_control(
            'image6', [
                'label' => __( 'Image 06', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'image_style' => [ '3', '4' ]
                ]
            ]
        );

        $this->add_control(
            'processes_2', [
                'label' => __( 'Add Steps', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $process_2->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '2'
                ]
            ]
        );//End Process Style 02


        //============== Process Style 03
        $process_3 = new \Elementor\Repeater();
        $process_3->add_control(
            'count_num', [
                'label' => __( 'Count Number', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '20.1'
            ]
        );

        $process_3->add_control(
            'count_text', [
                'label' => __( 'Count Text', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'pass rate'
            ]
        );

        $process_3->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Excellent technical communication',
            ]
        );

        $process_3->add_control(
            'contents', [
                'label' => __( 'Contents', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
            ]
        );

        $this->add_control(
            'processes_3', [
                'label' => __( 'Add Steps', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $process_3->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '3'
                ]
            ]
        );//End Process Style 03

        //============== Process Style 04
        $process_4 = new \Elementor\Repeater();
        $process_4->add_control(
            'step_no', [
                'label' => __( 'Step Number', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '1'
            ]
        );

        $process_4->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Talk to Our Industry Experts',
            ]
        );

        $process_4->add_control(
            'contents', [
                'label' => __( 'Contents', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $process_4->add_control(
            'step_shape', [
                'label' => __( 'Shape Line', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'processes_4', [
                'label' => __( 'Add Steps', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $process_4->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '4'
                ]
            ]
        );//End Process Style 04


        //============== Process Style 05
        $process_5 = new \Elementor\Repeater();
        $process_5->add_control(
            'icon', [
                'label' => esc_html__( 'Icon', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );

        $process_5->add_control(
            'line_image', [
                'label' => __( 'Shape Line', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $process_5->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Design',
                'separator' => 'before'
            ]
        );

        $process_5->add_control(
            'contents', [
                'label' => __( 'Contents', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
            ]
        );

        $this->add_control(
            'processes_5', [
                'label' => __( 'Add Steps', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $process_5->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '5'
                ]
            ]
        );//End Process Style 05

        $this->add_control(
            'step_shape', [
                'label' => __( 'Shape', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '2', '3', '4' ]
                ]
            ]
        );

        $this->end_controls_section(); // End Processes



    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============================= Section Background ============================== //
        $this->start_controls_section(
            'sec_bg_style', [
                'label' => __( 'Section Background', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy-process' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy-process' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sec_background',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .landpagy-process',
            ]
        );

        $this->end_controls_section(); //End Section Background

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation



        //============= Template Parts
        include( "template/processes/processes-{$settings['style']}.php" );

    }
}