<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Promotional_Offer extends Widget_Base {
    public function get_name() {
        return 'landpagy_promotional_offer';
    }

    public function get_title() {
        return __( 'Promotional Offer', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-posts-ticker';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //============================== Title ===============================//
        $this->start_controls_section(
            'sec_title', [
                'label' => __( 'Title', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'title', [
                'label' => __( 'Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => '<span>Mega</span> Sale'
            ]
        );

        $this->end_controls_section(); // End Title


        //============================== Subtitle ===============================//
        $this->start_controls_section(
            'sec_discount', [
                'label' => __( 'Discount', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'discount', [
                'label' => __( 'Discount', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => 'Up to <span>50%</span> Off'
            ]
        );

        $this->end_controls_section(); // End Title

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============================= Style Title  ============================= //
        $this->start_controls_section(
            'style_title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => esc_html__( 'Text Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'title_typo',
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->end_controls_section(); //End Style Title


        //============================= Shape Images ============================= //
        $this->start_controls_section(
            'shape_images', [
                'label' => __( 'Shape Images', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'shape1', [
                'label' => __( 'Shape 01', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape2', [
                'label' => __( 'Shape 02', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape3', [
                'label' => __( 'Shape 03', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape4', [
                'label' => __( 'Shape 04', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape5', [
                'label' => __( 'Shape 05', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape6', [
                'label' => __( 'Shape 06', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape7', [
                'label' => __( 'Shape 07', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape8', [
                'label' => __( 'Shape 08', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape9', [
                'label' => __( 'Shape 09', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape10', [
                'label' => __( 'Shape 10', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_section(); //End Shape Images

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>
        <section class="banner-area pricing-banner">
            <div class="container">
                <div class="row">
                    <div class="col-12">
                        <div class="section-title-center">
                            <?php
                            if ( !empty( $settings['title']) ) { ?>
                                <h1 class="title"><?php echo Landpagy_Core_Helper()->kses_post($settings['title']) ?></h1>
                                <?php
                            }
                            if ( !empty( $settings['discount']) ) { ?>
                                <h2 class="discount"><?php echo Landpagy_Core_Helper()->kses_post($settings['discount']) ?></h2>
                                <?php
                            }
                            ?>
                        </div>
                    </div>
                </div>
            </div>
            <span class="banner-shapes wow animate__animated animate__fadeInDown"></span>
            <?php

            landpagy_el_image( $settings['shape1'], 'Shape Image', 'pricing-shape-4 wow animate__animated animate__fadeInRight' );
            landpagy_el_image($settings['shape2'], 'Shape Image', 'pricing-shape-3' );

            echo wp_get_attachment_image( $settings['shape3']['id'], 'full', false,
                array(
                    'class' => 'pricing-shape-5 object-element',
                    'data-paroller-factor' => '0.05',
                    'data-paroller-type' => 'foreground',
                    'data-paroller-transition' => 'transform .2s linear',
                )
            );

            echo wp_get_attachment_image( $settings['shape4']['id'], 'full', false,
                array(
                    'class' => 'pricing-shape-12 object-element',
                    'data-paroller-factor' => '-0.05',
                    'data-paroller-type' => 'foreground',
                    'data-paroller-transition' => 'transform .2s linear',
                )
            );
            landpagy_el_image($settings['shape5'], 'Shape Image', 'pricing-shape-6' );
            landpagy_el_image($settings['shape6'], 'Shape Image', 'pricing-shape-7' );
            landpagy_el_image($settings['shape7'], 'Shape Image', 'pricing-shape-8' );
            landpagy_el_image($settings['shape8'], 'Shape Image', 'pricing-shape-9 animate__animated wow animate__fadeInTopRight animate__slow' );
            landpagy_el_image($settings['shape9'], 'Shape Image', 'pricing-shape-10' );

            echo wp_get_attachment_image( $settings['shape10']['id'], 'full', false,
                array(
                    'class' => 'pricing-shape-11 object-element',
                    'data-paroller-factor' => '0.05',
                    'data-paroller-type' => 'foreground',
                    'data-paroller-direction' => 'horizontal',
                    'data-paroller-transition' => 'transform .2s linear',
                )
            );
            ?>
        </section>
        <?php
    }
}