<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Screen_features extends Widget_Base {

    public function get_name() {
        return 'landpagy_screen_features';
    }

    public function get_title() {
        return __( 'Screen Features', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-featured-image';
    }

    public function get_style_depends() {
        return ['nice-select'];
    }

    public function get_script_depends() {
        return ['nice-select'];
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //============================== Section Title  ===============================//
        $this->start_controls_section(
            'sec_title', [
                'label' => __('Title', 'landpagy-core'),
            ]
        );

        $this->add_control(
            'title', [
                'label' => __('Title', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
            ]
        );

        $this->add_control(
            'highlighted_text', [
                'label' => __('highlighted Title', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
            ]
        );

        $this->add_control(
            'highlighted_img', [
                'label' => __('highlighted Image', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_section(); // End Section Title


        //============================== Screen Features ===============================//
        $this->start_controls_section(
            'features_sec', [
                'label' => __('Screen Features', 'landpagy-core'),
            ]
        );

        //================ Testimonials 01
        $features = new \Elementor\Repeater();
        $features->add_control(
            'title', [
                'label' => __('Title', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => '1. Install the App'
            ]
        );

        $features->add_control(
            'image', [
                'label' => __('Screen Image', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $features->add_control(
            'contents', [
                'label' => __('Contents', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
            ]
        );

        $this->add_control(
            'features', [
                'label' => __('Add Feature', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $features->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
            ]
        );

        $this->end_controls_section(); //End Screen Features

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============================== Shape Images ===============================//
        $this->start_controls_section(
            'shape_images', [
                'label' => __('Shape Images', 'landpagy-core'),
            ]
        );

        $this->add_control(
            'shape1', [
                'label' => __('Shape', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape2', [
                'label' => __('Shape 2', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape3', [
                'label' => __('Shape 3', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_section(); //End Shape Images

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        ?>
        <!--==========<Desktop>==========-->
        <section id="how_it_works_desktop" class="app-how-works-area vertical_slideshow_desktop">
            <div class="container box pt-140">
                <div class="row align-items-center">
                    <div class="col-lg-4 offset-lg-1 col-md-7">
                        <h2 class="section-title cloud-heading-2 mb-65">
                            <?php echo esc_html($settings['title']) ?>
                            <span>
                                <?php echo esc_html($settings['highlighted_text']) ?>
                                <?php echo wp_get_attachment_image($settings['highlighted_img']['id'], 'full', '', array( 'class' => 'border-shape' )) ?>
                            </span>
                        </h2>
                        <?php
                        $i = 1;
                        if ( !empty($settings['features']) ) {
                            foreach ( $settings['features'] as $key => $feature ) {
                                $align_class = $key == 0 ? '' : ' scroll_disable';
                                ?>
                                <div id="slideshow<?php echo esc_attr($i++) ?>" class="app-how-item scroll_box<?php echo esc_attr($align_class) ?>">
                                    <h4 class="title"><?php echo esc_html($feature['title']) ?></h4>
                                    <div class="message">
                                        <?php echo Landpagy_Core_Helper()->kses_post(wpautop($feature['contents'])) ?>
                                    </div>
                                </div>
                                <?php
                            }

                        }
                        ?>
                    </div>
                    <div class="col-md-4 offset-lg-2 col-md-4">
                        <div class="app-how-images">
                            <div class="bg-shapes">
                                <div class="shape"></div>
                                <div class="shape"></div>
                                <div class="shape"></div>
                                <?php
                                if ( !empty($settings['shape1']['id']) ) { ?>
                                    <div class="shape">
                                        <?php echo wp_get_attachment_image($settings['shape1']['id'], 'full' ) ?>
                                    </div>
                                    <?php
                                }
                                if ( !empty($settings['shape2']['id']) ) { ?>
                                    <div class="shape">
                                        <<?php echo wp_get_attachment_image($settings['shape2']['id'], 'full' ) ?>
                                    </div>
                                    <?php
                                }
                                if ( !empty($settings['shape3']['id']) ) { ?>
                                    <div class="shape">
                                        <?php echo wp_get_attachment_image($settings['shape3']['id'], 'full' ) ?>
                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                            <?php
                            $i = 1;
                            if ( !empty($settings['features']) ) {
                                foreach ( $settings['features'] as $feature ) {
                                    echo wp_get_attachment_image($feature['image']['id'], 'full', '', array( 'id' => 'slideshow_img'.$i++.'' ));
                                }
                            }
                            ?>
                        </div>
                    </div>

                    <div class="col-md-1">
                        <div class="pagination">
                            <span class="pagination-bullet1"></span>
                            <span class="pagination-bullet2"></span>
                            <span class="pagination-bullet3"></span>
                        </div>
                    </div>
                </div>
            </div>
        </section>

        <!--==========<MOBILE>==========-->
        <section id="how_it_works_mobile" class="app-how-works-area pt-80 pb-80">
            <div class="container">
                <div class="row">
                    <div class="col-lg-12">
                        <h2 class="section-title cloud-heading-2 mb-45">
                            <?php echo esc_html($settings['title']) ?>
                            <span>
                                <?php echo esc_html($settings['highlighted_text']) ?>
                                <?php echo wp_get_attachment_image($settings['highlighted_img']['id'], 'full', '', array( 'class' => 'border-shape' )) ?>
                            </span>
                        </h2>
                        <?php
                        if ( !empty($settings['features']) ) {
                            foreach ( $settings['features'] as $feature ) {
                                ?>
                                <div class="app-how-item">
                                    <h4 class="title"><?php echo esc_html($feature['title']) ?></h4>
                                    <div class="message">
                                        <?php echo Landpagy_Core_Helper()->kses_post(wpautop($feature['contents'])) ?>
                                    </div>
                                    <?php echo wp_get_attachment_image($feature['image']['id'], 'full', '', array( 'class' => 'mb-40 mt-30' )); ?>
                                </div>
                                <?php
                            }
                        }
                        ?>
                    </div>
                </div>
            </div>
        </section>
        <?php

    }
}