<?php
namespace LandpagyCore\Widgets;

use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Gallery
 * @package LandpagyCore\Widgets
 */
class Search_form extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_search_form';
    }

    public function get_title() {
        return __( 'Search Form (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-search-results';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //============================ Contents =====================================//
        $this->start_controls_section(
            'features_content', [
                'label' => __( 'Features Content', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'How can we help you?',
            ]
        );

        $this->add_control(
            'category_title', [
                'label' => __( 'Category Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Popular help articles:',
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'cats', [
                'label' => esc_html__('Category', 'banca-core'),
                'description' => esc_html__( 'Display blog by categories', 'banca-core' ),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'options' => Landpagy_Core_Helper()->get_the_categories(),
                'multiple' => true,
                'label_block' => true,
            ]
        );

        $this->end_controls_section(); // Contents

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control() {

        // =========================== Shape Images ============================ //
        $this->start_controls_section(
            'shape_images_sec', [
                'label' => __( 'Shape Images', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'shape1', [
                'label' => __( 'Shape 01', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape2', [
                'label' => __( 'Shape 02', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape3', [
                'label' => __( 'Shape 03', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape4', [
                'label' => __( 'Shape 04', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape5', [
                'label' => __( 'Shape 05', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_section(); //End Shape Images


        //============================= Section Background ============================== //
        $this->start_controls_section(
            'sec_bg_style', [
                'label' => __( 'Section Background', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy-search' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy-search' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sec_background',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .landpagy-search',
            ]
        );

        $this->end_controls_section(); //End Section Background

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to Variable conversation
        $value = get_search_query() ? get_search_query() : '';

        ?>
        <section class="banner-area help-page-banner landpagy-search">
            <div class="container">
                <div class="row">
                    <div class="col-12 text-center">
                        <div class="banner-left">
                            <?php
                            if ( !empty($settings['title']) ) { ?>
                                <h1><?php echo esc_html($settings['title']) ?></h1>
                                <?php
                            }
                            ?>
                            <form action="<?php echo esc_url(home_url('/')) ?>" class="form-group">
                                <input type="search" name="s" placeholder="<?php esc_attr_e('Search...', 'landpagy-core'); ?>" value="<?php echo esc_attr($value) ?>" />
                                <button type="submit" class="btn btn-red">
                                    <i class="fas fa-search"></i>
                                </button>
                            </form>
                            <ul class="popular-article">
                                <li class="mr-1"><?php echo esc_html($settings['category_title']) ?></li>
                                <?php
                                if ( is_array($cats) ) {
                                    foreach ($cats as $cat) {
                                        $category = get_term( $cat );
                                        ?>
                                        <li>
                                            <a href="<?php echo get_category_link($cat) ?>">
                                                <?php echo esc_html($category->name) ?>
                                            </a>
                                        </li>
                                        <?php
                                    }
                                }
                                ?>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
            <?php
            echo !empty($settings['shape1']['id']) ? wp_get_attachment_image($settings['shape1']['id'], 'full', '', array( 'class' => 'help-center-shape' )) : '';
            echo !empty($settings['shape2']['id']) ? wp_get_attachment_image($settings['shape2']['id'], 'full', '', array( 'class' => 'help-center-shape2' )) : '';
            echo !empty($settings['shape3']['id']) ? wp_get_attachment_image($settings['shape3']['id'], 'full', '', array( 'class' => 'help-center-shape3' )) : '';
            echo !empty($settings['shape4']['id']) ? wp_get_attachment_image($settings['shape4']['id'], 'full', '', array( 'class' => 'help-center-shape4' )) : '';
            echo !empty($settings['shape5']['id']) ? wp_get_attachment_image($settings['shape5']['id'], 'full', '', array( 'class' => 'shape16 animate__animated wow animate__fadeInTopLeft animate__slow' )) : '';
            ?>
        </section>
        <?php

    }


}