<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class SignIn
 * @package LandpagyCore\Widgets
 */
class SignIn extends Widget_Base {

    public function get_name() {
        return 'landpagy_signin';
    }

    public function get_title() {
        return __( 'Sign In', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-person';
    }

    public function get_script_depends() {
        return  [ 'parallax-scroll' ];
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //======================== Section Contents ==========================//
        $this->start_controls_section(
            'sec_contents', [
                'label' => __( 'Contents', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'title', [
                'label' => esc_html__( 'Title', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Sign in to Landpagy'
            ]
        );

        $this->end_controls_section(); // End Contents


        //======================== Forms Settings ==========================//
        $this->start_controls_section(
            'form_settings', [
                'label' => __( 'Form Settings', 'landpagy-core' ),
            ]
        );

        //===== Sign In Button
        $this->add_control(
            'signup_btn_heading', [
                'label' => esc_html__( 'Sign In Button', 'landpagy-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'signup_btn', [
                'label' => esc_html__( 'Button Title', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Sign in'
            ]
        );

        $this->add_control(
            'signup_btn_url', [
                'label' => esc_html__( 'Button URL', 'landpagy-core' ),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ]
            ]
        );

        $this->end_controls_section(); // End Form Settings


        //======================== Featured Images ==========================//
        $this->start_controls_section(
            'featured_images', [
                'label' => __( 'Featured Images', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'fimage', [
                'label' => esc_html__( 'Featured Image', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape1', [
                'label' => esc_html__( 'Shape', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape2', [
                'label' => esc_html__( 'Shape 2', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape3', [
                'label' => esc_html__( 'Shape 3', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_section(); // End Featured Images


    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation


        $user_login = ( ! empty( $_POST['user_login'] ) ) ? sanitize_text_field( $_POST['user_login'] ) : '';
        $email = ( ! empty( $_POST['user_email'] ) ) ? sanitize_text_field( $_POST['user_email'] ) : '';
        $password = ( ! empty( $_POST['user_pwd'] ) ) ? $_POST['user_pwd'] : '';

        if ( is_user_logged_in() ) {
            $current_user = wp_get_current_user();
            ?>
            <section class="sign-up-wrapper">
                <div class="container">
                    <h2 class="text-center signup_title"> <?php esc_html_e( 'Welcome', 'landpagy-core' ) ?> <?php echo $current_user->display_name; ?> </h2>
                    <div class="signup-login-form">
                        <p> <?php esc_html_e( 'You are logged in', 'landpagy-core' ) ?> </p>
                        <p> <?php esc_html_e( 'You can logout from', 'landpagy-core' ) ?>
                            <a href="<?php echo esc_url(wp_logout_url(home_url( '/'))) ?>"> <?php esc_html_e( 'here', 'landpagy-core' ) ?> </a>
                        </p>
                        <p> <?php esc_html_e( 'Or navigate to the website', 'landpagy-core' ) ?>
                            <a href="<?php echo esc_url(home_url( '/')) ?>"> <?php esc_html_e( 'Homepage', 'landpagy-core' ) ?> </a>
                        </p>
                    </div>
                </div>
            </section>
            <?php
        }
        else {
            ?>
            <section class="sign-up-wrapper">
                <div class="container">
                    <div class="sign-up-box">
                        <div class="bg-shapes">
                            <?php
                            if ( !empty($settings['shape1']['id']) ) { ?>
                                <div class="shape">
                                    <?php echo wp_get_attachment_image($settings['shape1']['id'], 'full'); ?>
                                </div>
                                <?php
                            }
                            if ( !empty($settings['shape2']['id']) ) { ?>
                                <div class="shape" data-parallax='{"x":-30, "y": 0, "rotateY":0}'>
                                    <?php echo wp_get_attachment_image($settings['shape2']['id'], 'full'); ?>
                                </div>
                                <?php
                            }
                            if ( !empty($settings['shape3']['id']) ) { ?>
                                <div class="shape">
                                    <?php echo wp_get_attachment_image($settings['shape3']['id'], 'full'); ?>
                                </div>
                                <?php
                            }
                            ?>
                        </div>
                        <div class="row">
                            <div class="col-lg-6">
                                <div class="form-images d-lg-block d-none">
                                    <div class="shapes object-element" data-paroller-factor="0.1" data-paroller-type="foreground" data-paroller-direction="horizontal" data-paroller-transition="transform .2s linear"></div>
                                    <div class="shapes object-element"></div>
                                    <div class="shapes object-element" data-paroller-factor="0.05" data-paroller-type="foreground" data-paroller-direction="horizontal" data-paroller-transition="transform .2s linear"></div>
                                    <div class="shapes object-element" data-paroller-factor="0.05" data-paroller-type="foreground" data-paroller-transition="transform .2s linear"></div>
                                    <div class="shapes object-element" data-paroller-type="foreground" data-paroller-factor="0.1" data-paroller-transition="transform .2s linear"></div>
                                    <?php
                                    if ( !empty($settings['fimage']['id']) ) { ?>
                                        <div class="shapes">
                                            <?php echo wp_get_attachment_image($settings['fimage']['id'], 'full'); ?>
                                        </div>
                                        <?php
                                    }
                                    ?>
                                </div>
                            </div>
                            <div class="col-lg-6">
                                <div class="form-wrapper">
                                    <div class="text-center mb-50">
                                        <?php
                                        if ( !empty($title) ) { ?>
                                            <h2 class="heading-3"><?php echo esc_html($title) ?></h2>
                                            <?php
                                        }
                                        ?>
                                    </div>
                                    <form action="<?php echo esc_url(home_url( '/')) ?>wp-login.php?action=register" name="registerform" id="registerform" class="sign-up-form" method="post">
                                        <div class="row">
                                            <div class="col-md-12">
                                                <input type="text" name="username" id="username" value="<?php echo esc_attr($user_login) ?>" placeholder="<?php esc_attr_e('username*', 'landpagy-core'); ?>" />
                                            </div>
                                            <div class="col-md-12 mt-20">
                                                <input type="password" name="password" id="password" value="<?php echo esc_attr($email) ?>" placeholder="<?php esc_attr_e('password*', 'landpagy-core'); ?>" />
                                            </div>

                                            <div class="col-6">
                                                <input type="checkbox" id="remember" />
                                                <label class="check-text" for="remember"><?php esc_html_e('Remember me', 'landpagy-core'); ?></label>
                                            </div>
                                            <div class="col-6">
                                                <a class="forgot-link float-end" href="<?php echo esc_url(home_url( '/')) . '/wp-login.php?action=lostpassword'; ?>">
                                                    <?php esc_html_e('Forgot Password?', 'landpagy-core'); ?>
                                                </a>
                                            </div>
                                            <div class="col-md-12 mt-30">
                                                <input class="btn btn-red" type="submit" name="submit" value="<?php esc_attr_e('Sign In', 'landpagy-core'); ?>" />
                                            </div>
                                            <div class="col-md-12">
                                                <p class="form-text mt-20">
                                                    <?php esc_html_e('Don’t have an account?', 'landpagy-core'); ?>
                                                    <br>
                                                    <a <?php Landpagy_Core_Helper()->the_button($signup_btn_url) ?>>
                                                        <?php echo esc_html($signup_btn) ?>
                                                    </a>
                                                </p>
                                            </div>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </section>
            <?php
        }

    }
}