<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;



// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}



/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class States_Features extends Widget_Base {

    public function get_name() {
        return 'landpagy_States_Features';
    }

    public function get_title() {
        return __( 'States Feature', 'landpagy-hero' );
    }

    public function get_icon() {
        return 'eicon-gallery-grid';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        // -------------------------------------------- Filtering [ CONTENT ]
        $this->start_controls_section(
            'states_features', [
                'label' => __( 'States Features', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'features_thumbnail', [
                'label' => __( 'Feature Image', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA
            ]
        );

        $this->add_control(
            'features_one', [
                'label' => __( 'Feature One', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block'           => true
            ]
        );
        $this->add_control(
            'features_two', [
                'label' => __( 'Feature Two', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block'           => true
            ]
        );
        $this->add_control(
            'features_three', [
                'label' => __( 'Feature Three', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block'           => true
            ]
        );
        $this->add_control(
            'features_four', [
                'label' => __( 'Feature Four', 'landpagy-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block'           => true
            ]
        );

        $this->end_controls_section();

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {

        $this->start_controls_section(
            'states_feature_style', [
                'label' => __( 'States Features', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'feature_color', [
                'label' => __( 'Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .solution-list li' => 'color: {{VALUE}}',
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'typography_feature',
                'label'    => esc_html__( 'Typography', 'landpagy-core' ),
                'selector' => '{{WRAPPER}} .solution-list li',
            ]
        );

        $this->end_controls_section();


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {

        $settings = $this->get_settings();

        ?>

        <div class="solution-wrapp">

        <ul class="solution-list">

            <?php if( !empty($settings['features_one']) ) : ?>
                <li> <?php echo  esc_html($settings['features_one']); ?> </li>
            <?php endif; ?>

		    <?php if( !empty($settings['features_two']) ) : ?>
                <li> <?php echo  esc_html($settings['features_two']); ?> </li>
	         <?php endif; ?>

            <?php if( !empty($settings['features_three']) ) : ?>
                <li> <?php echo  esc_html($settings['features_three']); ?> </li>
            <?php endif; ?>

            <?php if( !empty($settings['features_four']) ) : ?>
                <li> <?php echo  esc_html($settings['features_four']); ?> </li>
            <?php endif; ?>

        </ul>

        <div class="center">
            <div class="circle">
                <svg width="442" height="442" viewBox="0 0 442 442" fill="none" xmlns="http://www.w3.org/2000/svg">

                    <path class="path svg-fadein one" d="M134.082 44.1647C129.483 46.441 123.958 45.5885 120.33 41.9589C114.571 36.1988 116.173 26.4863 123.471 22.8694C152.991 8.23772 186.218 0 221.336 0C256.453 0 289.68 8.23772 319.2 22.8683C326.497 26.4863 328.099 36.1988 322.34 41.9589C318.712 45.5874 313.188 46.441 308.588 44.1647C282.265 31.1349 252.641 23.8017 221.336 23.8017C190.03 23.8017 160.405 31.1349 134.082 44.1647Z" fill="#9558EC">

                    </path>
                    <path class="path svg-fadein two" d="M397.835 134.238C395.559 129.639 396.411 124.114 400.041 120.486C405.801 114.727 415.514 116.329 419.131 123.627C433.762 153.147 442 186.374 442 221.492C442 256.609 433.762 289.836 419.132 319.356C415.514 326.653 405.801 328.255 400.041 322.496C396.413 318.868 395.559 313.344 397.835 308.744C410.865 282.421 418.198 252.797 418.198 221.492C418.198 190.186 410.865 160.561 397.835 134.238Z" fill="#9558EC">

                    </path>
                    <path class="path svg-fadein three" d="M134.082 397.835C129.483 395.559 123.958 396.411 120.33 400.041C114.571 405.801 116.173 415.514 123.471 419.131C152.991 433.762 186.218 442 221.336 442C256.453 442 289.68 433.762 319.2 419.132C326.497 415.514 328.099 405.801 322.34 400.041C318.712 396.413 313.188 395.559 308.588 397.835C282.265 410.865 252.641 418.198 221.336 418.198C190.03 418.198 160.405 410.865 134.082 397.835Z" fill="#9558EC">

                    </path>
                    <path class="path svg-fadein four" d="M44.1647 134.238C46.441 129.639 45.5885 124.114 41.9589 120.486C36.1988 114.727 26.4863 116.329 22.8694 123.627C8.23772 153.147 -3.03244e-06 186.374 -4.5675e-06 221.492C-6.10251e-06 256.609 8.23771 289.836 22.8683 319.356C26.4863 326.653 36.1988 328.255 41.9589 322.496C45.5874 318.868 46.441 313.344 44.1647 308.744C31.1349 282.421 23.8017 252.797 23.8017 221.492C23.8017 190.186 31.1349 160.561 44.1647 134.238Z" fill="#9558EC">

                    </path>

                </svg>
            </div>
            <?php echo wp_get_attachment_image( $settings['features_thumbnail']['id'], 'landpagy_78x84' ,false )?>
        </div>
        </div>


        <?php
    }
}