<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Table_Content extends Widget_Base {
    public function get_name() {
        return 'landpagy_table_contents';
    }

    public function get_title() {
        return __( 'Table Of Contents (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-price-table';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //============================ Table Of Contents ==========================//
        $this->start_controls_section(
            'table_contents_sec', [
                'label' => esc_html__( 'Table Of Contents', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'tab_title', [
                'label'       => esc_html__( 'Tab Title', 'landpagy-core' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => 'Device Security',
            ]
        );

        $this->add_control(
            'is_rowspan_tab_title', [
                'label' => esc_html__( 'Row Span', 'landpagy-core' ),
                'type'  => Controls_Manager::NUMBER,
                'min'  => 1,
                'max'  => 30,
                'default' => 5,
                'separator'   => 'after'
            ]
        );

        $table = new \Elementor\Repeater();
        $table->add_control(
            'row1_title', [
                'label'       => esc_html__( 'Row 01 Title', 'landpagy-core' ),
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__( 'Number of devices', 'landpagy-core' ),
                'label_block' => true,
            ]
        );

        $table->add_control(
            'row1_contents', [
                'label'       => esc_html__( 'Row 01 Content', 'landpagy-core' ),
                'type'        => \Elementor\Controls_Manager::WYSIWYG,
            ]
        );

        //Row 02 Content Style
        $table->add_control(
            'is_row2_style', [
                'label' => esc_html__( 'Row 02 (Content/Icon)', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'content'  => esc_html__( 'Content', 'plugin-name' ),
                    'icon' => esc_html__( 'Icon', 'plugin-name' ),
                ],
                'default' => 'content',
            ]
        );

        $table->add_control(
            'row2_contents', [
                'label'       => esc_html__( 'Row 02 Content', 'landpagy-core' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'condition' => [
                    'is_row2_style' => 'content'
                ]
            ]
        );

        $table->add_control(
            'row2_icon', [
                'label' => esc_html__( 'Icon', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon_check',
                    'library' => 'ElegantIcons',
                ],
                'condition' => [
                    'is_row2_style' => 'icon'
                ]
            ]
        );

        //Row 03 Content Style
        $table->add_control(
            'is_row3_style', [
                'label' => esc_html__( 'Row 03 (Content/Icon)', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'content'  => esc_html__( 'Content', 'plugin-name' ),
                    'icon' => esc_html__( 'Icon', 'plugin-name' ),
                ],
                'default' => 'content',
            ]
        );


        $table->add_control(
            'row3_contents', [
                'label'       => esc_html__( 'Row 03 Content', 'landpagy-core' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'condition' => [
                    'is_row3_style' => 'content'
                ]
            ]
        );

        $table->add_control(
            'row3_icon', [
                'label' => esc_html__( 'Icon', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'icon_check',
                    'library' => 'ElegantIcons',
                ],
                'condition' => [
                    'is_row3_style' => 'icon'
                ]
            ]
        );

        $table->add_control(
            'is_row_border_bottom', [
                'label' => esc_html__( 'Row Border Bottom ON/OFF', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'your-plugin' ),
                'label_off' => esc_html__( 'Hide', 'your-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'separator' => 'before'
            ]
        );

        $table->add_control(
            'is_border_bottom', [
                'label' => esc_html__( 'Border Bottom ON/OFF', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'your-plugin' ),
                'label_off' => esc_html__( 'Hide', 'your-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'table_contents', [
                'label'       => esc_html__( 'Add Table Content', 'landpagy-core' ),
                'type'        => \Elementor\Controls_Manager::REPEATER,
                'fields'      => $table->get_controls(),
                'title_field' => '{{{ row1_title }}}',
                'prevent_empty' => false,
            ]
        );

        $this->end_controls_section(); //End Table Of Contents //Bangladesh

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //=============================== Table Contents ===================================//
        $this->start_controls_section(
            'table_content_style', [
                'label' => esc_html__( 'Table Contents', 'landpagy-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        // Title Options
        $this->add_control(
            'title_options', [
                'label' => esc_html__( 'Title Options', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'title_typo',
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => esc_html__( 'Text Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section(); //End Section Contents

    }



    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        $table_contents = !empty($settings['table_contents']) ? $settings['table_contents'] : '';
        ?>
        <div class="pricing-compare-table">
            <table>
                <tbody>
                    <?php
                    $i = 1;
                    if ( is_array( $table_contents ) ) {
                        foreach ($table_contents as $index => $table_content ) {
                            $border_top = $index == 0 ? ' red-top' : '';
                            $border_bottom = !empty($table_content['is_border_bottom'] == 'yes' ) ? ' red-bottom' : '';
                            $row_border_bottom = !empty($table_content['is_row_border_bottom'] == 'yes' ) ? ' gray-bottom' : '';
                            ?>
                            <tr class="feature-row<?php echo esc_attr($border_top .$border_bottom) ?>">
                                <?php
                                if ( $index == 0 ) {
                                    ?>
                                    <th rowspan="<?php echo esc_attr($settings['is_rowspan_tab_title']) ?>" class="feature-type">
                                        <span class="section-text nowrap"><?php echo esc_html($settings['tab_title']) ?></span>
                                    </th>
                                    <?php
                                }
                                ?>
                                <td class="feature-title table-title-bg<?php echo esc_attr($row_border_bottom) ?>">

                                    <button class="feature-btn collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#feature-<?php echo esc_attr($i) ?>" aria-expanded="false">
                                        <?php echo esc_html($table_content['row1_title']) ?>
                                    </button>

                                    <div id="feature-<?php echo esc_attr($i) ?>" class="accordion-collapse collapse">
                                        <div class="feature-body">
                                            <?php echo Landpagy_Core_Helper()->kses_post(wpautop($table_content['row1_contents'])) ?>
                                        </div>
                                    </div>

                                </td>

                                <td class="feature table-bg<?php echo esc_attr($row_border_bottom) ?>">
                                    <div class="feature-text">
                                        <?php
                                        if ( !empty($table_content['is_row2_style'] == 'content' ) ) {
                                            ?>
                                            <p><?php echo esc_html($table_content['row2_contents']) ?></p>
                                            <?php
                                        }
                                        if ( !empty($table_content['is_row2_style'] == 'icon' )) {
                                            \Elementor\Icons_Manager::render_icon( $table_content['row2_icon'] );
                                        }
                                        ?>
                                    </div>
                                </td>
                                <td class="feature table-bg2<?php echo esc_attr($row_border_bottom) ?>">
                                    <div class="feature-text">
                                        <?php
                                        if ( !empty($table_content['is_row3_style'] == 'content' ) ) {
                                            ?>
                                            <p><?php echo esc_html($table_content['row3_contents']) ?></p>
                                            <?php
                                        }
                                        if ( !empty($table_content['is_row2_style'] == 'icon' )) {
                                            \Elementor\Icons_Manager::render_icon( $table_content['row3_icon'] );
                                        }
                                        ?>
                                    </div>
                                </td>
                            </tr>
                            <?php
                            ++$i;
                        }
                    }
                    ?>
                </tbody>
            </table>
            </div>
        <?php

    }

}