<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Tabs extends Widget_Base {
    public function get_name() {
        return 'landpagy_tabs';
    }

    public function get_title() {
        return __( 'Tabs (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-tabs';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //===================== Select Preset ===========================//
        $this->start_controls_section(
            'style_sec', [
                'label' => esc_html__( 'Preset Skins', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Style', 'landpagy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( '01: Horizontal Tabs', 'landpagy-core' ),
                    '2' => esc_html__( '02: Vertical Tabs', 'landpagy-core' ),
                    '3' => esc_html__( '03: Vertical Tabs', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section(); //End Preset


        //============================== Horizontal Tabs ===============================//
        $this->start_controls_section(
            'tabs_sec', [
                'label' => __( 'Tabs', 'plugin-name' ),
            ]
        );

        //==== Horizontal Tabs style 01,
        $tabs1 = new \Elementor\Repeater();
        $tabs1->add_control(
            'tab_title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Carbon' , 'landpagy-core' ),
                'label_block' => true,
            ]
        );

        $tabs1->add_control(
            'tab_img', [
                'label' => __( 'Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'tabs', [
                'label' => __( 'Add Item', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $tabs1->get_controls(),
                'title_field' => '{{{ tab_title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '1'
                ]
            ]
        ); //End Horizontal Tabs


        //==== Vertical Tabs style 02,
        $tabs2 = new \Elementor\Repeater();
        $tabs2->add_control(
            'icon', [
                'label' => __( 'Icon', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $tabs2->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Track key events',
                'label_block' => true,
            ]
        );

        $tabs2->add_control(
            'contents', [
                'label' => __( 'Contents', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $tabs2->add_control(
            'image', [
                'label' => __( 'Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'separator' => 'before'
            ]
        );

        $tabs2->add_control(
            'image2', [
                'label' => __( 'Image 2', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'tabs2', [
                'label' => __( 'Add Item', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $tabs2->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '2'
                ]
            ]
        ); //End Horizontal Tabs



        //==== Vertical Tabs style 03,
        $tabs3 = new \Elementor\Repeater();
        $tabs3->add_control(
            'title', [
                'label' => __( 'Title', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Track key events',
                'label_block' => true,
            ]
        );

        $tabs3->add_control(
            'image', [
                'label' => __( 'Image', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'tabs3', [
                'label' => __( 'Add Item', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $tabs3->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '3'
                ]
            ]
        ); //End Vertical Tabs 03

        $this->end_controls_section(); //End Tabs

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control() {


        //===================== Shape Images ===========================//
        $this->start_controls_section(
            'shape_images_sec', [
                'label' => esc_html__( 'Shapes', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'shape1', [
                'label' => __( 'Shape', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'shape2', [
                'label' => __( 'Shape 2', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_section(); //End Shape Images

        $this->start_controls_section(
			'style_section',
			[
				'label' => esc_html__( 'Text Style', 'textdomain' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
			'title_style',
			[
				'label' => esc_html__( 'Title Style', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .__title' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .__title',
			]
		);

        $this->add_control(
			'content_style',
			[
				'label' => esc_html__( 'Content Style', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        
        $this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .__content' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'selector' => '{{WRAPPER}} .__content',
			]
		);


		$this->end_controls_section();


    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        $tabs = $this->get_settings_for_display( 'tabs' );
        $id_int = substr( $this->get_id_int(), 0, 1 );


        //Include Template parts
        include "template/tabs/tab-{$settings['style']}.php";

    }

}