<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Testimonials extends Widget_Base {
    public function get_name() {
        return 'landpagy_testimonials';
    }

    public function get_title() {
        return __( 'Testimonials (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-testimonial';
    }

    public function get_style_depends() {
        return [ 'slick','slick-theme', 'fancybox', 'landpagy-swiper' ];
    }

    public function get_script_depends() {
        return [ 'ScrollMagic', 'TweenMax', 'parallax-scroll', 'addIndicators', 'animation-gsap', 'slick', 'fancybox', 'landpagy-swiper' ];
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //============================== Select Style ===============================//
        $this->start_controls_section(
            'select_style', [
                'label' => __('Preset', 'landpagy-core'),
            ]
        );

        $this->add_control(
            'style', [
                'label' => __('Style', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    '1' => [
                        'title' => __( '01: Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_1',
                    ],
                    '2' => [
                        'title' => __( '02: Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_2',
                    ],
                    '3' => [
                        'title' => __( '03: Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_3',
                    ],
                    '4' => [
                        'title' => __( '04: Testimonials with Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_4',
                    ],
                    '5' => [
                        'title' => __( '05: Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_5',
                    ],
                    '6' => [
                        'title' => __( '06: Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_6',
                    ],
                    '7' => [
                        'title' => __( '07: Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_7',
                    ],
                    '8' => [
                        'title' => __( '08: Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_8',
                    ],
                    '9' => [
                        'title' => __( '09: Testimonials with Ratting', 'landpagy-core' ),
                        'icon' => 'testimonial_9',
                    ],
                    '10' => [
                        'title' => __( '10: Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_10',
                    ],
                    '11' => [
                        'title' => __( '11: Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_11',
                    ],
                    '12' => [
                        'title' => __( '12: Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_12',
                    ],
                    '13' => [
                        'title' => __( '13: Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_13',
                    ],
                    '14' => [
                        'title' => __( '14: Testimonials', 'landpagy-core' ),
                        'icon' => 'testimonial_14',
                    ],
                ],
                'default' => '1'
            ]
        );

        $this->end_controls_section(); // End Style


        //============================== Section Title  ===============================//
        $this->start_controls_section(
            'sec_title', [
                'label' => __('Title', 'landpagy-core'),
                'condition' => [
                    'style' => [ '1', '2', '12', '14' ]
                ]
            ]
        );

        $this->add_control(
            'title', [
                'label' => __('Title', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $this->add_control(
            'title_tag', [
                'label' => __('Title Tag', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => landpagy_el_title_tags(),
                'default' => 'h2',
                'separator' => 'before'
            ]
        );

        $this->end_controls_section(); // End Section Title


        //============================== Testimonials 01 ===============================//
        $this->start_controls_section(
            'testimonials_sec', [
                'label' => __('Testimonials', 'landpagy-core'),
            ]
        );

        //================ Testimonials 01
        $testimonials1 = new \Elementor\Repeater();
        $testimonials1->add_control(
            'f_image', [
                'label' => __('Featured Image', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $testimonials1->add_control(
            'title', [
                'label' => __('Title', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Plan & Create',
                'label_block' => true
            ]
        );

        $testimonials1->add_control(
            'title_tag', [
                'label' => __('Title Tag', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => landpagy_el_title_tags(),
                'default' => 'h3',
                'separator' => 'after',
            ]
        );

        $testimonials1->add_control(
            'subtitle', [
                'label' => __('Subtitle', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $testimonials1->add_control(
            'content', [
                'label' => __('Content', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $testimonials1->add_control(
            'testimonials_divider', [
                'label' => __('Testimonials Text', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $testimonials1->add_control(
            'author_img', [
                'label' => __('Author Image', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $testimonials1->add_control(
            'author_name', [
                'label' => __('Author Name', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Arif Rahamn', 'landpagy-core'),
            ]
        );

        $testimonials1->add_control(
            'designation', [
                'label' => __('Designation', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Web Developer', 'landpagy-core'),
            ]
        );

        $testimonials1->add_control(
            'quote', [
                'label' => __('Quote Text', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
            ]
        );

        $testimonials1->add_control(
            'icon', [
                'label' => __('Icon', 'text-domain'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-quote-left',
                    'library' => 'solid',
                ],
            ]
        );

        $this->add_control(
            'testimonials', [
                'label' => __('Add Testimonial', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $testimonials1->get_controls(),
                'title_field' => '{{{ author_name }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '1',
                ]
            ]
        );

        //================ Testimonials 02, 03, 06, 07
        $testimonials2 = new \Elementor\Repeater();
        $testimonials2->add_control(
            'author_img', [
                'label' => __('Author Image', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $testimonials2->add_control(
            'author_name', [
                'label' => __('Author Name', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Arif Rahman', 'landpagy-core'),
            ]
        );

        $testimonials2->add_control(
            'designation', [
                'label' => __('Designation', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Web Developer', 'landpagy-core'),
            ]
        );

        $testimonials2->add_control(
            'quote', [
                'label' => __('Quote Text', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
            ]
        );

        $testimonials2->add_control(
            'icon', [
                'label' => __('Icon', 'text-domain'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-quote-left',
                    'library' => 'solid',
                ],
            ]
        );

        $this->add_control(
            'testimonials2', [
                'label' => __('Add Testimonial', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $testimonials2->get_controls(),
                'title_field' => '{{{ author_name }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => ['2', '3', '6', '7']
                ]
            ]
        );


        //================ Testimonials 04
        $testimonials_4 = new \Elementor\Repeater();
        $testimonials_4->add_control(
            'author_img', [
                'label' => __('Author Image', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $testimonials_4->add_control(
            'title', [
                'label' => __('Title', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Plan & Create',
                'label_block' => true
            ]
        );

        $testimonials_4->add_control(
            'title_tag', [
                'label' => __('Title Tag', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => landpagy_el_title_tags(),
                'default' => 'h3',
                'separator' => 'after',
            ]
        );

        $testimonials_4->add_control(
            'author_name', [
                'label' => __('Author Name', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Arif Rahman', 'landpagy-core'),
            ]
        );

        $testimonials_4->add_control(
            'designation', [
                'label' => __('Designation', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Web Developer',
            ]
        );

        $testimonials_4->add_control(
            'content', [
                'label' => __('Content', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
            ]
        );

        $testimonials_4->add_control(
            'rating', [
                'label' => __('Rating', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => landpagy_el_ratting_options(),
                'default' => '5'
            ]
        );

        $testimonials_4->add_control(
            'icon', [
                'label' => __('Icon', 'text-domain'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-quote-left',
                    'library' => 'solid',
                ],
            ]
        );

        $this->add_control(
            'testimonials4', [
                'label' => __('Add Testimonial', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $testimonials_4->get_controls(),
                'title_field' => '{{{ author_name }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '4'
                ]
            ]
        );


        //================ Testimonials 05
        $testimonials5 = new \Elementor\Repeater();
        $testimonials5->add_control(
            'author_img', [
                'label' => __('Author Image', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $testimonials5->add_control(
            'author_name', [
                'label' => __('Author Name', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' =>  'Arif Rahman',
                'label_block' => true
            ]
        );

        $testimonials5->add_control(
            'location', [
                'label' => __('Location', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT
            ]
        );

        $testimonials5->add_control(
            'quote', [
                'label' => __('Quote', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
            ]
        );

        $testimonials5->add_control(
            'video_url', [
                'label' => __('Video URL', 'text-domain'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => '#'
            ]
        );

        $this->add_control(
            'testimonials5', [
                'label' => __('Add Testimonial', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $testimonials5->get_controls(),
                'title_field' => '{{{ author_name }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '5'
                ]
            ]
        );

        //================ Testimonials 08, 10, 11, 12
        $testimonial_6 = new \Elementor\Repeater();
        $testimonial_6->add_control(
            'author_img', [
                'label' => __('Author Image', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $testimonial_6->add_control(
            'author_name', [
                'label' => __('Author Name', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Arif Rahman'
            ]
        );

        $testimonial_6->add_control(
            'designation', [
                'label' => __('Designation', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Web Developer'
            ]
        );

        $testimonial_6->add_control(
            'quote', [
                'label' => __('Quote', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $this->add_control(
            'testimonials6', [
                'label' => __('Add Testimonial', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $testimonial_6->get_controls(),
                'title_field' => '{{{ author_name }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => [ '8', '10', '11', '12', '14' ]
                ]
            ]
        );//End Testimonials style 08, 10, 11, 12

        //======= Style 12
        $this->add_control(
            'quote_img', [
                'label' => __('Quote Image', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '12'
                ]
            ]
        );


        //================ Testimonials 09
        $testimonials7 = new \Elementor\Repeater();
        $testimonials7->add_control(
            'author_img', [
                'label' => __('Author Image', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $testimonials7->add_control(
            'author_name', [
                'label' => __('Author Name', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Arif Rahman', 'landpagy-core'),
            ]
        );

        $testimonials7->add_control(
            'designation', [
                'label' => __('Designation', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Web Developer', 'landpagy-core'),
            ]
        );

        $testimonials7->add_control(
            'quote', [
                'label' => __('Quote Text', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
            ]
        );

        $testimonials7->add_control(
            'rating', [
                'label' => __('Rating', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => landpagy_el_ratting_options(),
                'default' => '5'
            ]
        );


        $this->add_control(
            'testimonials7', [
                'label' => __('Add Testimonial', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $testimonials7->get_controls(),
                'title_field' => '{{{ author_name }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '9'
                ]
            ]
        );//End Style 09



        //================ Testimonials 13
        $testimonials8 = new \Elementor\Repeater();
        $testimonials8->add_control(
            'author_img', [
                'label' => __('Author Image', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $testimonials8->add_control(
            'author_name', [
                'label' => __('Author Name', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Arif Rahman', 'landpagy-core'),
            ]
        );

        $testimonials8->add_control(
            'quote', [
                'label' => __('Quote Text', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
            ]
        );

        $this->add_control(
            'testimonials8', [
                'label' => __('Add Testimonial', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $testimonials8->get_controls(),
                'title_field' => '{{{ author_name }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '13'
                ]
            ]
        );

        $this->end_controls_section(); // End Testimonials Style

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {


        //============================ Title =================================//
        $this->start_controls_section(
            'sec_title_style', [
                'label' => __( 'Title', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '1', '2', '12', '14' ],
                ]
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->end_controls_section(); // End title


        //============================ Subtitle Style =============================//
        $this->start_controls_section(
            'subtitle_style', [
                'label' => __( 'Subtitle', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_control(
            'subtitle_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .subtitle' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'subtitle_typo',
                'selector' => '{{WRAPPER}} .subtitle',
            ]
        );

        $this->end_controls_section(); // End subtitle Style


        //============================ Style Content =============================//
        $this->start_controls_section(
            'content_style', [
                'label' => __( 'Content', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_control(
            'content_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .content' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'content_typo',
                'selector' => '{{WRAPPER}} .content',
            ]
        );

        $this->end_controls_section(); // End Content


        //============================ Style Author Name =============================//
        $this->start_controls_section(
            'author_name_style', [
                'label' => __( 'Author Section', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '1', '2', '3' , '7' ]
                ]
            ]
        );

        //==================== Author Name
        $this->add_control(
            'author_name_divider', [
                'label' => __( 'Author Name', 'landpagy-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'author_name_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .name' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'author_name_typo',
                'selector' => '{{WRAPPER}} .name',
            ]
        );


        //============== Designation
        $this->add_control(
            'designation_divider', [
                'label' => __( 'Designation', 'landpagy-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'designation_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .designation' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'designation_typo',
                'selector' => '{{WRAPPER}} .designation',
            ]
        );

        $this->end_controls_section(); // End author name section


        //============================ Style Quote Area =============================//
        $this->start_controls_section(
            'quote_style', [
                'label' => __( 'Quote Section', 'landpagy-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '1', '2', '3', '7' ]
                ]
            ]
        );

        //==================== Icon
        $this->add_control(
            'icon_divider', [
                'label' => __( 'Icon', 'landpagy-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'icon_color', [
                'label' => __( 'Icon Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-review i' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_control(
            'icon_size', [
                'label' => __( 'Icon Size', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-review i' => 'color: {{VALUE}};',
                ]
            ]
        );

        //============== Quote
        $this->add_control(
            'quote_divider', [
                'label' => __( 'Quote', 'landpagy-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'quote_color', [
                'label' => __( 'Text Color', 'landpagy-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-review p' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'quote_typo',
                'selector' => '{{WRAPPER}} .testimonial-review p',
            ]
        );

        $this->end_controls_section(); // End author name section


        //=========================== Start Shape Images ==============================//
        $this->start_controls_section(
            'style_shapes', [
                'label' => __( 'Shapes', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '2', '8', '11' ]
                ]
            ]
        );

        $this->add_responsive_control(
            'shape1', [
                'label' => __( 'Shape', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '2', '8', '11' ]
                ]
            ]
        );

        $this->add_responsive_control(
            'shape2', [
                'label' => __( 'Shape 2', 'landpagy-core' ),
                'type' => Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->end_controls_section(); //End Shape Images


        //=========================== Section Background ==============================//
        $this->start_controls_section(
            'style_background', [
                'label' => __( 'Background', 'landpagy-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '2', '8', '11', '12', '14' ]
                ]
            ]
        );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => __( 'Margin', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy_testimonial' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Padding', 'landpagy-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .landpagy_testimonial' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'sec_bg_color',
                'label' => __( 'Background', 'landpagy-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .landpagy_testimonial',
            ]
        );

        $this->end_controls_section(); //End Section Background

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); // Array to Variable Conversation

        $title = !empty( $settings['title'] ) ? $settings['title'] : '';
        $title_tag = !empty( $settings['title_tag'] ) ? $settings['title_tag'] : '';

        // Include Style
        include "template/testimonials/testimonial-{$settings['style']}.php";

    }

}