<?php
namespace LandpagyCore\Widgets;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Testimonials_Carousel extends \Elementor\Widget_Base {
    public function get_name() {
        return 'landpagy_testimonials_carousel';
    }

    public function get_title() {
        return __( 'Testimonials Carousel (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-testimonial-carousel';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }

    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {


        //============================== Testimonials 01 ===============================//
        $this->start_controls_section(
            'testimonials_sec', [
                'label' => __('Testimonials', 'landpagy-core'),
            ]
        );

        //================ Testimonials 01
        $testimonials1 = new \Elementor\Repeater();
        $testimonials1->add_control(
            'image', [
                'label' => __('Image', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $testimonials1->add_control(
            'title', [
                'label' => __('Title', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Marcus Levin, Designer'
            ]
        );

        $testimonials1->add_control(
            'content', [
                'label' => __('Content', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $this->add_control(
            'testimonials1', [
                'label' => __('Add Testimonial', 'landpagy-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $testimonials1->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
            ]
        );

        $this->end_controls_section(); // End Testimonials Sections

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {

    }



    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); // Array to Variable Conversation

        $testimonials_1 = $this->get_settings_for_display( 'testimonials1' );
        $id_int = substr( $this->get_id_int(), 0, 1 );

        // Include Style
        include "template/testimonials-carousel/testimonials-1.php";
    }


}