<?php
namespace LandpagyCore\Widgets;

use Elementor\Widget_Base;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class Timeline extends Widget_Base {
    public function get_name() {
        return 'landpagy_timeline';
    }

    public function get_title() {
        return __( 'Timeline (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-time-line';
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }


    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //============================== Locations ===============================//
        $this->start_controls_section(
            'timelines_sec', [
                'label' => __( 'Locations', 'plugin-name' ),
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'title', [
                'label' => __( 'Country Name', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Our first customer'
            ]
        );

        $repeater->add_control(
            'date', [
                'label' => __( 'Date', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Jun 2016.'
            ]
        );

        $repeater->add_control(
            'contents', [
                'label' => __( 'Content', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $this->add_control(
            'timelines', [
                'label' => __( 'Add Timeline', 'landpagy-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false
            ]
        );

        $this->end_controls_section();

    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {

        //============================== Contents Style  ===============================//
        $this->start_controls_section(
			'content_style',
			[
				'label' => esc_html__( 'Contents', 'textdomain' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

        // === Title Options
		$this->add_control(
			'title_options',
			[
				'label' => esc_html__( 'Title Options', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typo',
				'selector' => '{{WRAPPER}} .story-info-meta h5',
			]
		);

        $this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .story-info-meta h5' => 'color: {{VALUE}}',
				],
			]
		); //End Title Options


         // === Contents Options
		$this->add_control(
			'content_options',
			[
				'label' => esc_html__( 'Content Options', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'contents_typo',
				'selector' => '{{WRAPPER}} .story-timeline p',
			]
		);

        $this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Text Color', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .story-timeline p' => 'color: {{VALUE}}',
				],
			]
		); //End Content Options

        // === Meta Options
		$this->add_control(
			'meta_options',
			[
				'label' => esc_html__( 'Meta Options', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'meta_typo',
				'selector' => '{{WRAPPER}} .story-info-meta span',
			]
		);

        $this->add_control(
			'meta_color',
			[
				'label' => esc_html__( 'Text Color', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .story-info-meta span' => 'color: {{VALUE}}',
				],
			]
		); //End Title Options

        $this->end_controls_section(); // End Contents Style

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();

        if ( !empty($settings['timelines']) ) {
            foreach ( $settings['timelines'] as $timeline ) {
                ?>
                <div class="story-timeline">
                    <div class="story-info-meta">
                        <h5><?php echo esc_html($timeline['title']) ?></h5>
                        <span><?php echo esc_html($timeline['date']) ?></span>
                    </div>
                    <p><?php echo esc_html($timeline['contents']) ?></p>
                </div>
                <?php
            }
        }

    }
}