<?php
namespace LandpagyCore\Widgets;

// Exit if accessed directly
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class Image_hover
 * @package LandpagyCore\Widgets
 */
class WPML extends \Elementor\Widget_Base {

    public function get_name() {
        return 'landpagy_wpml';
    }

    public function get_title() {
        return __( 'Select Language (Theme)', 'landpagy-core' );
    }

    public function get_icon() {
        return 'eicon-device-desktop';
    }

    public function get_style_depends() {
        return [ 'nice-select' ];
    }

    public function get_script_depends() {
        return [ 'nice-select' ];
    }

    public function get_categories() {
        return [ 'landpagy-elements' ];
    }



    /**
     * Name: register_controls()
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function register_controls() {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }


    /**
     * Name: elementor_content_control()
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_content_control() {

        //===================== Select Preset ===========================//
        $this->start_controls_section(
            'style_sec', [
                'label' => esc_html__( 'Preset Skins', 'landpagy-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label'   => esc_html__( 'Style', 'landpagy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( 'Style 01', 'landpagy-core' ),
                    '2' => esc_html__( 'Style 02', 'landpagy-core' ),
                ],
                'default' => '1',
            ]
        );

        //============= Alignment ======================//
        $this->add_responsive_control(
            'alignment', [
                'label' => __( 'Alignment', 'elementor' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'elementor' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'elementor' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'elementor' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .footer-copyright' => 'text-align: {{VALUE}};',
                ],
                'default' => 'left',
                'separator' => 'before'
            ]
        );

        $this->end_controls_section();//End Select Style


    }


    /**
     * Name: elementor_style_control()
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    public function elementor_style_control () {

        //================== WPML ====================//
        $this->start_controls_section(
            'lang_style', [
                'label' => esc_html__( 'Language', 'plugin-name' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'lang_typo',
                'selector' => '{{WRAPPER}} select',
            ]
        );

        $this->add_control(
            'lang_text_color', [
                'label' => esc_html__( 'Text Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} select' => 'color: {{VALUE}}',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'lang_bg_color', [
                'label' => esc_html__( 'Background Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} select' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'lang_border_color', [
                'label' => esc_html__( 'Border Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} select' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

    }


    /**
     * Name: elementor_render()
     * Desc: Render widget output on the frontend.
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: spider-themes
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation


        //====== Template Parts
        include "template/wpml/wpml-{$settings['style']}.php";

    }
}